@@ -34,7 +34,7 @@
 #include "hgfsProto.h"
 #include "conf.h"
 #include "str.h"
-#include "vmtools.h"
+#include "vmware/tools/utils.h"
 
 #include "hgfsclient_version.h"
 #include "embed_version.h"
@@ -316,21 +316,15 @@ static Bool
 HgfsClient_Init(void)
 {
    Bool success = FALSE;
-   gchar *confFile;
-   GKeyFile *conf;
-
-   confFile = VMTools_GetToolsConfFile();
-   conf = VMTools_LoadConfig(confFile, G_KEY_FILE_NONE, FALSE);
+   GKeyFile *conf = NULL;
 
+   VMTools_LoadConfig(NULL, G_KEY_FILE_NONE, &conf, NULL);
+   VMTools_ConfigLogging("hgfsclient", conf, FALSE, FALSE);
    if (conf != NULL) {
-      VMTools_ConfigLogging(conf);
       g_key_file_free(conf);
       conf = NULL;
    }
 
-   g_free(confFile);
-   confFile = NULL;
-
    if (!VmCheck_IsVirtualWorld()) {
       Warning("This application must be run in a Virtual Machine.\n");
       goto out;
