@@ -31,6 +31,7 @@
 
 #include "vmware.h"
 #include "vm_version.h"
+#include "codeset.h"
 #include "posix.h"
 #include "auth.h"
 #include "str.h"
@@ -111,7 +112,9 @@ AuthLoadPAM(void)
        * XXX do we even try to configure the pam libraries?
        * potential nightmare on all the possible guest OSes
        */
+
       Log("System PAM libraries are unusable: %s\n", dlerror());
+
       return FALSE;
 #else
       char *liblocation;
@@ -120,6 +123,7 @@ AuthLoadPAM(void)
       libdir = LocalConfig_GetPathName(DEFAULT_LIBDIRECTORY, CONFIG_VMWAREDIR);
       if (!libdir) {
          Log("System PAM library unusable and bundled one not found.\n");
+
          return FALSE;
       }
       liblocation = Str_SafeAsprintf(NULL, "%s/lib/%s/%s", libdir,
@@ -131,6 +135,7 @@ AuthLoadPAM(void)
          Log("Neither system nor bundled (%s) PAM libraries usable: %s\n",
              liblocation, dlerror());
          free(liblocation);
+
          return FALSE;
       }
       free(liblocation);
@@ -138,14 +143,20 @@ AuthLoadPAM(void)
    }
    for (i = 0; i < ARRAYSIZE(authPAMImported); i++) {
       void *symbol = dlsym(pam_library, authPAMImported[i].procname);
+
       if (!symbol) {
-         Log("PAM library does not contain required function: %s\n", dlerror());
+         Log("PAM library does not contain required function: %s\n",
+             dlerror());
+
          return FALSE;
       }
+
       *(authPAMImported[i].procaddr) = symbol;
    }
+
    authPamLibraryHandle = pam_library;
    Log("PAM up and running.\n");
+
    return TRUE;
 }
 
@@ -153,12 +164,13 @@ AuthLoadPAM(void)
 static const char *PAM_username;
 static const char *PAM_password;
 
-static int PAM_conv (int num_msg,
-		     const struct pam_message **msg,
-		     struct pam_response **resp,
-		     void *appdata_ptr) {
+static int PAM_conv (int num_msg,                     // IN:
+		     const struct pam_message **msg,  // IN:
+		     struct pam_response **resp,      // OUT:
+		     void *appdata_ptr) {             // IN:
    int count;
    struct pam_response *reply = calloc(num_msg, sizeof(struct pam_response));
+
    if (!reply) {
       return PAM_CONV_ERR;
    }
@@ -189,11 +201,13 @@ static int PAM_conv (int num_msg,
             free(reply[count].resp);
          }
          free(reply);
+
          return PAM_CONV_ERR;
       }
    }
    
    *resp = reply;
+
    return PAM_SUCCESS;
 }
 
@@ -223,8 +237,8 @@ static struct pam_conv PAM_conversation = {
  */
 
 AuthToken
-Auth_AuthenticateUser(const char *user,       //IN
-                      const char *pass)       //IN
+Auth_AuthenticateUser(const char *user,  // IN:
+                      const char *pass)  // IN:
 {
    struct passwd *pwd;
 
@@ -233,28 +247,43 @@ Auth_AuthenticateUser(const char *user,       //IN
    int pam_error;
 #endif
 
+   if (!CodeSet_Validate(user, strlen(user), "UTF-8")) {
+      Log("User not in UTF-8\n");
+      return NULL;
+   }
+   if (!CodeSet_Validate(pass, strlen(pass), "UTF-8")) {
+      Log("Password not in UTF-8\n");                                                     
+      return NULL;
+   }
+
 #ifdef USE_PAM
 #ifdef ACCEPT_XXX_PASS
-   if(strcmp("XXX", pass) != 0) {
+   if (strcmp("XXX", pass) != 0) {
 #endif
       if (!AuthLoadPAM()) {
          return NULL;
       }
+
       /*
        * XXX PAM can blow away our syslog level settings so we need
        * to call Log_Init() again before doing any more Log()s
        */
+
 #define PAM_BAIL if (pam_error != PAM_SUCCESS) { \
                   dlpam_end(pamh, pam_error); \
                   return NULL; \
                  }
       PAM_username = user;
       PAM_password = pass;
+
 #if defined(VMX86_TOOLS)
-      pam_error = dlpam_start("vmtoolsd", PAM_username, &PAM_conversation, &pamh);
+      pam_error = dlpam_start("vmtoolsd", PAM_username, &PAM_conversation,
+                              &pamh);
 #else
-      pam_error = dlpam_start("vmware-authd", PAM_username, &PAM_conversation, &pamh);
+      pam_error = dlpam_start("vmware-authd", PAM_username, &PAM_conversation,
+                              &pamh);
 #endif
+
       PAM_BAIL;
       pam_error = dlpam_authenticate(pamh, 0);
       PAM_BAIL;
@@ -263,6 +292,7 @@ Auth_AuthenticateUser(const char *user,       //IN
       pam_error = dlpam_setcred(pamh, PAM_ESTABLISH_CRED);
       PAM_BAIL;
       dlpam_end(pamh, PAM_SUCCESS);
+
 #if ACCEPT_XXX_PASS
    }
 #endif
@@ -288,6 +318,7 @@ Auth_AuthenticateUser(const char *user,       //IN
 
    if (*pwd->pw_passwd != '\0') {
       char *namep = (char *) crypt(pass, pwd->pw_passwd);
+
       if (strcmp(namep, pwd->pw_passwd)
 #ifdef ACCEPT_XXX_PASS
           && strcmp("XXX", pass) != 0
@@ -322,7 +353,7 @@ Auth_AuthenticateUser(const char *user,       //IN
  */
 
 void
-Auth_CloseToken(AuthToken token)       //IN
+Auth_CloseToken(AuthToken token)  // IN:
 {
 }
 
