@@ -76,6 +76,14 @@ Backdoor_InOut(Backdoor_proto *myBp) // IN/OUT
    uint64 dummy;
 
    __asm__ __volatile__(
+#ifdef __APPLE__
+        /*
+         * Save %rbx on the stack because the Mac OS GCC doesn't want us to
+         * clobber it - it erroneously thinks %rbx is the PIC register.
+         * (Radar bug 7304232)
+         */
+        "pushq %%rbx"           "\n\t"
+#endif
         "pushq %%rax"           "\n\t"
         "movq 40(%%rax), %%rdi" "\n\t"
         "movq 32(%%rax), %%rsi" "\n\t"
@@ -90,14 +98,22 @@ Backdoor_InOut(Backdoor_proto *myBp) // IN/OUT
         "movq %%rdx, 24(%%rax)" "\n\t"
         "movq %%rcx, 16(%%rax)" "\n\t"
         "movq %%rbx,  8(%%rax)" "\n\t"
-        "popq          (%%rax)"
+        "popq          (%%rax)" "\n\t"
+#ifdef __APPLE__
+        "popq %%rbx"            "\n\t"
+#endif
       : "=a" (dummy)
       : "0" (myBp)
       /*
        * vmware can modify the whole VM state without the compiler knowing
        * it. So far it does not modify EFLAGS. --hpreg
        */
-      : "rbx", "rcx", "rdx", "rsi", "rdi", "memory"
+      :
+#ifndef __APPLE__
+      /* %rbx is unchanged at the end of the function on Mac OS. */
+      "rbx",
+#endif
+      "rcx", "rdx", "rsi", "rdi", "memory"
    );
 }
 
@@ -127,7 +143,14 @@ BackdoorHbIn(Backdoor_proto_hb *myBp) // IN/OUT
 
    __asm__ __volatile__(
         "pushq %%rbp"           "\n\t"
-
+#ifdef __APPLE__
+        /*
+         * Save %rbx on the stack because the Mac OS GCC doesn't want us to
+         * clobber it - it erroneously thinks %rbx is the PIC register.
+         * (Radar bug 7304232)
+         */
+        "pushq %%rbx"           "\n\t"
+#endif
         "pushq %%rax"           "\n\t"
         "movq 48(%%rax), %%rbp" "\n\t"
         "movq 40(%%rax), %%rdi" "\n\t"
@@ -146,7 +169,9 @@ BackdoorHbIn(Backdoor_proto_hb *myBp) // IN/OUT
         "movq %%rcx, 16(%%rax)" "\n\t"
         "movq %%rbx,  8(%%rax)" "\n\t"
         "popq          (%%rax)" "\n\t"
-
+#ifdef __APPLE__
+        "popq %%rbx"            "\n\t"
+#endif
         "popq %%rbp"
       : "=a" (dummy)
       : "0" (myBp)
@@ -154,7 +179,12 @@ BackdoorHbIn(Backdoor_proto_hb *myBp) // IN/OUT
        * vmware can modify the whole VM state without the compiler knowing
        * it. --hpreg
        */
-      : "rbx", "rcx", "rdx", "rsi", "rdi", "memory", "cc"
+      :
+#ifndef __APPLE__
+      /* %rbx is unchanged at the end of the function on Mac OS. */
+      "rbx",
+#endif
+      "rcx", "rdx", "rsi", "rdi", "memory", "cc"
    );
 }
 
@@ -166,7 +196,14 @@ BackdoorHbOut(Backdoor_proto_hb *myBp) // IN/OUT
 
    __asm__ __volatile__(
         "pushq %%rbp"           "\n\t"
-
+#ifdef __APPLE__
+        /*
+         * Save %rbx on the stack because the Mac OS GCC doesn't want us to
+         * clobber it - it erroneously thinks %rbx is the PIC register.
+         * (Radar bug 7304232)
+         */
+        "pushq %%rbx"           "\n\t"
+#endif
         "pushq %%rax"           "\n\t"
         "movq 48(%%rax), %%rbp" "\n\t"
         "movq 40(%%rax), %%rdi" "\n\t"
@@ -185,11 +222,18 @@ BackdoorHbOut(Backdoor_proto_hb *myBp) // IN/OUT
         "movq %%rcx, 16(%%rax)" "\n\t"
         "movq %%rbx,  8(%%rax)" "\n\t"
         "popq          (%%rax)" "\n\t"
-
+#ifdef __APPLE__
+        "popq %%rbx"            "\n\t"
+#endif
         "popq %%rbp"
       : "=a" (dummy)
       : "0" (myBp)
-      : "rbx", "rcx", "rdx", "rsi", "rdi", "memory", "cc"
+      :
+#ifndef __APPLE__
+      /* %rbx is unchanged at the end of the function on Mac OS. */
+      "rbx",
+#endif
+      "rcx", "rdx", "rsi", "rdi", "memory", "cc"
    );
 }
 
