@@ -306,8 +306,8 @@ HgfsBd_Enabled(RpcOut *out,         // IN: RPCI Channel
                char *requestPacket) // IN: Buffer (obtained from HgfsBd_GetBuf)
 {
    char const *replyPacket; // Buffer returned by HgfsBd_Dispatch
-   size_t packetSize;
-   int error;
+   size_t replyLen;
+   Bool success;
 
    /*
     * Send a bogus (empty) request to the VMX. If hgfs is disabled on
@@ -316,16 +316,14 @@ HgfsBd_Enabled(RpcOut *out,         // IN: RPCI Channel
     * (it will be an error packet because our request was malformed,
     * but we just discard it anyway).
     */
-   packetSize = 0;
-   error = HgfsBd_Dispatch(out,
-                           requestPacket,
-                           &packetSize,
-                           &replyPacket);
-   if (error < 0) {
-      return FALSE;
+   success = RpcOut_send(out, requestPacket - HGFS_CLIENT_CMD_LEN,
+                         HGFS_CLIENT_CMD_LEN,
+                         &replyPacket, &replyLen);
+   if (success == TRUE) {
+      ASSERT(replyLen <= HGFS_LARGE_PACKET_MAX);
    }
 
-   return TRUE;
+   return success;
 }
 
 
