@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2009-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2009 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -23,13 +23,11 @@
  */
 
 #include <stdio.h>
+#include <errno.h>
 
 #include "vmware.h"
 #include "vm_basic_types.h"
 
-#include "hgfsProto.h"
-#include "hgfsServer.h"
-#include "hgfsUtil.h"
 #include "hgfsDirNotify.h"
 
 
@@ -38,10 +36,10 @@
  *
  * HgfsNotify_Init --
  *
- *    Initialization for the notification component.
+ *    One time initialization of the library.
  *
  * Results:
- *    Invalid value error.
+ *    0 if success, error code otherwise.
  *
  * Side effects:
  *    None.
@@ -49,19 +47,19 @@
  *-----------------------------------------------------------------------------
  */
 
-HgfsInternalStatus
+uint32
 HgfsNotify_Init(void)
 {
-   return HGFS_ERROR_NOT_SUPPORTED;
+   return EINVAL;
 }
 
 
 /*
  *-----------------------------------------------------------------------------
  *
- * HgfsNotify_Exit --
+ * HgfsNotify_Shutdown --
  *
- *    Exit for the notification component.
+ *    Performs nesessary cleanup.
  *
  * Results:
  *    None.
@@ -73,51 +71,7 @@ HgfsNotify_Init(void)
  */
 
 void
-HgfsNotify_Exit(void)
-{
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * HgfsNotify_Deactivate --
- *
- *    Deactivates generating file system change notifications.
- *
- * Results:
- *    None.
- *
- * Side effects:
- *    None.
- *
- *-----------------------------------------------------------------------------
- */
-
-void
-HgfsNotify_Deactivate(HgfsNotifyActivateReason reason) // IN: reason unused
-{
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * HgfsNotify_Activate --
- *
- *    Activates generating file system change notifications.
- *
- * Results:
- *    None.
- *
- * Side effects:
- *    None.
- *
- *-----------------------------------------------------------------------------
- */
-
-void
-HgfsNotify_Activate(HgfsNotifyActivateReason reason) // IN: reason unused
+HgfsNotify_Shutdown(void)
 {
 }
 
@@ -130,7 +84,7 @@ HgfsNotify_Activate(HgfsNotifyActivateReason reason) // IN: reason unused
  *    Allocates memory and initializes new shared folder structure.
  *
  * Results:
- *    Opaque subscriber handle for the new subscriber or HGFS_INVALID_FOLDER_HANDLE
+ *    Opaque subscriber handle for the new subscriber or INVALID_OBJECT_HANDLE
  *    if adding shared folder fails.
  *
  * Side effects:
@@ -139,11 +93,10 @@ HgfsNotify_Activate(HgfsNotifyActivateReason reason) // IN: reason unused
  *-----------------------------------------------------------------------------
  */
 
-HgfsSharedFolderHandle
-HgfsNotify_AddSharedFolder(const char *path,       // IN: path in the host
-                           const char *shareName)  // IN: name of the shared folder
+SharedFolderHandle
+HgfsNotify_AddSharedFolder(const char* path) // IN
 {
-   return HGFS_INVALID_FOLDER_HANDLE;
+   return INVALID_OBJECT_HANDLE;
 }
 
 
@@ -156,7 +109,7 @@ HgfsNotify_AddSharedFolder(const char *path,       // IN: path in the host
  *    Inserts allocated subscriber into corrspondent array.
  *
  * Results:
- *    Opaque subscriber handle for the new subscriber or HGFS_INVALID_SUBSCRIBER_HANDLE
+ *    Opaque subscriber handle for the new subscriber or INVALID_OBJECT_HANDLE
  *    if adding subscriber fails.
  *
  * Side effects:
@@ -165,15 +118,13 @@ HgfsNotify_AddSharedFolder(const char *path,       // IN: path in the host
  *-----------------------------------------------------------------------------
  */
 
-HgfsSubscriberHandle
-HgfsNotify_AddSubscriber(HgfsSharedFolderHandle sharedFolder, // IN: shared folder handle
-                         const char *path,                    // IN: relative path
-                         uint32 eventFilter,                  // IN: event filter
-                         uint32 recursive,                    // IN: look in subfolders
-                         HgfsNotifyEventReceiveCb eventCb,    // IN notification callback
-                         struct HgfsSessionInfo *session)     // IN: server context
+SubscriberHandle
+HgfsNotify_AddSubscriber(SharedFolderHandle sharedFolder, // IN
+              const char *path,                // IN path relative to shared folder
+              uint32 eventFilter,              // IN
+              uint32 recursive)                // IN TRUE if look in subdirectories
 {
-   return HGFS_INVALID_SUBSCRIBER_HANDLE;
+   return INVALID_OBJECT_HANDLE;
 }
 
 /*
@@ -185,7 +136,7 @@ HgfsNotify_AddSubscriber(HgfsSharedFolderHandle sharedFolder, // IN: shared fold
  *    Also deletes all subscribers that are defined for the shared folder.
  *
  * Results:
- *    FALSE.
+ *    0 if success, error code otherwise.
  *
  * Side effects:
  *    Removes all subscribers that correspond to the shared folder and invalidates
@@ -194,10 +145,10 @@ HgfsNotify_AddSubscriber(HgfsSharedFolderHandle sharedFolder, // IN: shared fold
  *-----------------------------------------------------------------------------
  */
 
-Bool
-HgfsNotify_RemoveSharedFolder(HgfsSharedFolderHandle sharedFolder) // IN
+uint32
+HgfsNotify_RemoveSharedFolder(SharedFolderHandle sharedFolder) // IN
 {
-   return FALSE;
+   return EINVAL;
 }
 
 
@@ -209,7 +160,7 @@ HgfsNotify_RemoveSharedFolder(HgfsSharedFolderHandle sharedFolder) // IN
  *    Deallcates memory used by NotificationSubscriber and performs necessary cleanup.
  *
  * Results:
- *    FALSE.
+ *    0 if success, error code otherwise.
  *
  * Side effects:
  *    None.
@@ -217,30 +168,8 @@ HgfsNotify_RemoveSharedFolder(HgfsSharedFolderHandle sharedFolder) // IN
  *-----------------------------------------------------------------------------
  */
 
-Bool
-HgfsNotify_RemoveSubscriber(HgfsSubscriberHandle subscriber) // IN
-{
-   return FALSE;
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * HgfsNotify_RemoveSessionSubscribers --
- *
- *    Removes all entries that are related to a particular session.
- *
- * Results:
- *    None.
- *
- * Side effects:
- *    None.
- *
- *-----------------------------------------------------------------------------
- */
-
-void
-HgfsNotify_RemoveSessionSubscribers(struct HgfsSessionInfo *session) // IN
+uint32
+HgfsNotify_RemoveSubscriber(SubscriberHandle subscriber) // IN
 {
+   return EINVAL;
 }
