@@ -50,7 +50,7 @@
       uint64 d_off;
       uint16 d_reclen;
       uint8  d_type;
-      int8   d_name[256];
+      char   d_name[256];
    } DirectoryEntry;
 #  else
 #    include <dirent.h>
@@ -73,7 +73,31 @@
 #include "cpName.h"     // for HgfsNameStatus
 #include "hgfsServerPolicy.h"
 #include "hgfsUtil.h"   // for HgfsInternalStatus
-#include "syncMutex.h"
+#include "vm_atomic.h"
+
+/*
+ * Locking: if requested, use glib's locking functions to avoid more bora
+ * dependencies. In other builds, stick with bora/lib/lock.
+ */
+
+#if defined(VMTOOLS_USE_GLIB)
+#  include <glib.h>
+
+   typedef GMutex HgfsLock;
+#  define HGFS_LOCK_NEW(name)       g_mutex_new()
+#  define HGFS_LOCK_ACQUIRE(lock)   g_mutex_lock(lock)
+#  define HGFS_LOCK_RELEASE(lock)   g_mutex_unlock(lock)
+#  define HGFS_LOCK_DESTROY(lock)   g_mutex_free(lock)
+#else /* !VMTOOLS_USE_GLIB */
+#  include "userlock.h"
+
+   typedef MXUserExclLock HgfsLock;
+#  define HGFS_LOCK_NEW(name)       MXUser_CreateExclLock(name, RANK_UNRANKED)
+#  define HGFS_LOCK_ACQUIRE(lock)   MXUser_AcquireExclLock(lock)
+#  define HGFS_LOCK_RELEASE(lock)   MXUser_ReleaseExclLock(lock)
+#  define HGFS_LOCK_DESTROY(lock)   MXUser_DestroyExclLock(lock)
+#endif
+
 
 /*
  * Does this platform have oplock support? We define it here to avoid long
@@ -285,7 +309,7 @@ typedef struct HgfsSessionInfo {
    HgfsSessionSendFunc *send;
 
    /* Lock to ensure some fileIO requests are atomic for a handle. */
-   SyncMutex fileIOLock;
+   HgfsLock *fileIOLock;
 
    Atomic_uint32 refCount;    /* Reference count for session. */
 
@@ -295,7 +319,7 @@ typedef struct HgfsSessionInfo {
     * Lock for the following 6 fields: the node array,
     * counters and lists for this session.
     */
-   SyncMutex nodeArrayLock;
+   HgfsLock *nodeArrayLock;
 
    /* Open file nodes of this session. */
    HgfsFileNode *nodeArray;
@@ -322,7 +346,7 @@ typedef struct HgfsSessionInfo {
     * Lock for the following three fields: for the search array
     * and it's counter and list, for this session.
     */
-   SyncMutex searchArrayLock;
+   HgfsLock *searchArrayLock;
 
    /* Directory entry cache for this session. */
    HgfsSearch *searchArray;
@@ -596,41 +620,45 @@ HgfsUnpackGetattrRequest(char const *packetIn,       // IN: request packet
                          char **cpName,              // OUT: cpName
                          size_t *cpNameSize,         // OUT: cpName size
                          HgfsHandle *file,           // OUT: file handle
-			 uint32 *caseFlags);         // OUT: case-sensitivity flags
+                         uint32 *caseFlags);         // OUT: case-sensitivity flags
 
 Bool
 HgfsUnpackDeleteRequest(char const *packetIn,       // IN: request packet
                         size_t packetSize,          // IN: request packet size
+                        HgfsOp *op,                 // OUT: requested operation
                         char **cpName,              // OUT: cpName
                         size_t *cpNameSize,         // OUT: cpName size
                         HgfsDeleteHint *hints,      // OUT: delete hints
                         HgfsHandle *file,           // OUT: file handle
-			uint32 *caseFlags);         // OUT: case-sensitivity flags
+                        uint32 *caseFlags);         // OUT: case-sensitivity flags
 
 Bool
 HgfsPackDeleteReply(char const *packetIn,          // IN: incoming packet
                     HgfsInternalStatus status,     // IN: reply status
+                    HgfsOp op,                     // IN: requested operation
                     char **packetOut,              // OUT: outgoing packet
                     size_t *packetSize);           // OUT: size of packet
 
 Bool
 HgfsUnpackRenameRequest(char const *packetIn,       // IN: request packet
                         size_t packetSize,          // IN: request packet size
+                        HgfsOp *op,                 // OUT: requested operation
                         char **cpOldName,           // OUT: rename src
-                        uint32 *cpOldNameLen,       // OUT: rename src size
+                        size_t *cpOldNameLen,       // OUT: rename src size
                         char **cpNewName,           // OUT: rename dst
-                        uint32 *cpNewNameLen,       // OUT: rename dst size
+                        size_t *cpNewNameLen,       // OUT: rename dst size
                         HgfsRenameHint *hints,      // OUT: rename hints
                         HgfsHandle *srcFile,        // OUT: src file handle
                         HgfsHandle *targetFile,     // OUT: target file handle
-			uint32 *oldCaseFlags,       // OUT: old case-sensitivity flags
-			uint32 *newCaseFlags);      // OUT: new case-sensitivity flags
+                        uint32 *oldCaseFlags,       // OUT: old case-sensitivity flags
+                        uint32 *newCaseFlags);      // OUT: new case-sensitivity flags
 
 Bool
-HgfsPackRenameReply(char const *packetIn,       // IN: incoming packet
-                    HgfsInternalStatus status,  // IN: reply status
-                    char **packetOut,           // OUT: outgoing packet
-                    size_t *packetSize);        // OUT: size of packet
+HgfsPackRenameReply(char const *packetIn,      // IN: incoming packet
+                    HgfsInternalStatus status, // IN: reply status
+                    HgfsOp op,                 // IN: requested operation
+                    char **packetOut,          // OUT: outgoing packet
+                    size_t *packetSize);       // OUT: size of packet
 
 Bool
 HgfsPackGetattrReply(char const *packetIn,       // IN: incoming packet
@@ -665,11 +693,12 @@ HgfsUnpackSetattrRequest(char const *packetIn,            // IN: request packet
                          char **cpName,                   // OUT: cpName
                          size_t *cpNameSize,              // OUT: cpName size
                          HgfsHandle *file,                // OUT: server file ID
-			 uint32 *caseFlags);              // OUT: case-sensitivity flags
+                         uint32 *caseFlags);              // OUT: case-sensitivity flags
 
 Bool
 HgfsPackSetattrReply(char const *packetIn,       // IN: setattrOp operation version
                      HgfsInternalStatus status,  // IN: reply status
+                     HgfsOp op,                  // IN: request type
                      char **packetOut,           // OUT: outgoing packet
                      size_t *packetSize);        // OUT: size of packet
 
@@ -682,23 +711,48 @@ HgfsUnpackCreateDirRequest(char const *packetIn,     // IN: incoming packet
 Bool
 HgfsPackCreateDirReply(char const *packetIn,      // IN: incoming packet
                        HgfsInternalStatus status, // IN: reply status
+                       HgfsOp op,                 // IN: request type
                        char **packetOut,          // OUT: outgoing packet
                        size_t *packetSize);       // OUT: size of packet
 
 Bool
 HgfsUnpackWriteWin32StreamRequest(char const *packetIn, // IN: incoming packet
-				  size_t packetSize,    // IN: size of packet
-				  HgfsHandle *file,     // OUT: file to write to
-				  char **payload,       // OUT: data to write
-				  size_t *requiredSize, // OUT: size of data
-				  Bool *doSecurity);    // OUT: restore sec.str.
+                                  size_t packetSize,    // IN: size of packet
+                                  HgfsOp *op,           // OUT: request type
+                                  HgfsHandle *file,     // OUT: file to write to
+                                  char **payload,       // OUT: data to write
+                                  size_t *requiredSize, // OUT: size of data
+                                  Bool *doSecurity);    // OUT: restore sec.str.
 
 Bool
 HgfsPackWriteWin32StreamReply(char const *packetIn,      // IN: incoming packet
-			      HgfsInternalStatus status, // IN: reply status
-			      uint32 actualSize,         // IN: amount written
-			      char **packetOut,          // OUT: outgoing packet
-			      size_t *packetSize);       // OUT: size of packet
+                              HgfsInternalStatus status, // IN: reply status
+                              HgfsOp op,                 // IN: request type
+                              uint32 actualSize,         // IN: amount written
+                              char **packetOut,          // OUT: outgoing packet
+                              size_t *packetSize);       // OUT: size of packet
+Bool
+HgfsUnpackCloseRequest(char const *packetIn,        // IN: request packet
+                       size_t packetSize,           // IN: request packet size
+                       HgfsOp *op,                  // OUT: request type
+                       HgfsHandle *file);           // OUT: Handle to close
+Bool
+HgfsPackCloseReply(char const *packetIn,      // IN: incoming packet
+                  HgfsInternalStatus status,  // IN: reply status
+                  HgfsOp op,                  // IN: request type
+                  char **packetOut,           // OUT: outgoing packet
+                  size_t *packetSize);        // OUT: size of packet
+Bool
+HgfsUnpackSearchCloseRequest(char const *packetIn,        // IN: request packet
+                             size_t packetSize,           // IN: request packet size
+                             HgfsOp *op,                  // OUT: request type
+                             HgfsHandle *file);           // OUT: Handle to close
+Bool
+HgfsPackSearchCloseReply(char const *packetIn,      // IN: incoming packet
+                         HgfsInternalStatus status,  // IN: reply status
+                         HgfsOp op,                  // IN: request type
+                         char **packetOut,           // OUT: outgoing packet
+                         size_t *packetSize);        // OUT: size of packet
 
 /* Node cache functions. */
 
