@@ -44,7 +44,7 @@
 
 #define INCLUDE_ALLOW_MODULE
 #define INCLUDE_ALLOW_USERLEVEL
-#define INCLUDE_ALLOW_VMMEXT
+
 #define INCLUDE_ALLOW_VMCORE
 #define INCLUDE_ALLOW_VMKERNEL
 #include "includeCheck.h"
@@ -137,7 +137,12 @@
 #define BDOOR_CMD_XPMODE                62
 #define BDOOR_CMD_NESTING_CONTROL       63
 #define BDOOR_CMD_FIRMWARE_INIT         64
-#define BDOOR_CMD_MAX                   65
+#define BDOOR_CMD_FIRMWARE_ACPI_SERVICES 65
+#  define BDOOR_CMD_FAS_GET_TABLE_SIZE    0
+#  define BDOOR_CMD_FAS_GET_TABLE_DATA    1
+#  define BDOOR_CMD_FAS_GET_PLATFORM_NAME 2
+#define BDOOR_CMD_SENDPSHAREHINTS       66
+#define BDOOR_CMD_MAX                   67
 
 
 /* 
@@ -149,10 +154,10 @@
 
 /* Nesting control operations */
 
-#define NESTING_CONTROL_ENTER_VMM        0
-#define NESTING_CONTROL_EXIT_VMM         1
-#define NESTING_CONTROL_QUERY            2
-#define NESTING_CONTROL_MAX              2
+#define NESTING_CONTROL_RESTRICT_BACKDOOR 0
+#define NESTING_CONTROL_OPEN_BACKDOOR     1
+#define NESTING_CONTROL_QUERY             2
+#define NESTING_CONTROL_MAX               2
 
 /* High-bandwidth backdoor port. --hpreg */
 
