@@ -105,25 +105,6 @@ typedef struct _DiskInfo {
    PPartitionEntry partitionList;
 } GuestDiskInfo, *PGuestDiskInfo;
 
-
-
-/*
- * Global functions
- *
- * XXX These belong in a bora-vmsoft header.
- */
-
-#ifndef N_PLAT_NLM
-extern Bool GuestInfo_GetFqdn(int outBufLen, char fqdn[]);
-extern Bool GuestInfo_GetNicInfo(NicInfoV3 **nicInfo);
-extern void GuestInfo_FreeNicInfo(NicInfoV3 *nicInfo);
-extern Bool GuestInfo_GetDiskInfo(PGuestDiskInfo di);
-extern Bool GuestInfo_GetOSName(unsigned int outBufFullLen,
-                                unsigned int outBufLen, char *osNameFull,
-                                char *osName);
-extern int GuestInfo_GetSystemBitness(void);
-#endif // #ifndef N_PLAT_NLM
-
 /**
  * @}
  */
