@@ -86,6 +86,7 @@ typedef enum GuestOSType {
    GUEST_OS_WINSEVEN_64         = GUEST_OS_BASE + 48, // Windows 7
    GUEST_OS_WIN2008R2           = GUEST_OS_BASE + 49, // Server 2008 R2
    GUEST_OS_WIN2008R2_64        = GUEST_OS_BASE + 50, // Server 2008 R2
+   GUEST_OS_ECOMSTATION         = GUEST_OS_BASE + 51, // OS/2 variant
 } GuestOSType;
 
 
@@ -164,6 +165,8 @@ typedef enum GuestOSFamilyType {
                          BS(SOLARIS10_64) | BS(FREEBSD_64) | \
                          ALLDARWIN64 | BS(OTHER_64) | BS(VMKERNEL))
 
+#define ALLOS2          (BS(OS2) | BS(ECOMSTATION))
+
 
 /*
  * These constants are generated by GuestInfoGetOSName which is in
@@ -179,6 +182,7 @@ typedef enum GuestOSFamilyType {
 #define STR_OS_AUROX               "Aurox" 
 #define STR_OS_ASIANUX             "asianux" 
 #define STR_OS_BLACKCAT            "BlackCat" 
+#define STR_OS_CENTOS              "centos"
 #define STR_OS_COBALT              "Cobalt" 
 #define STR_OS_CONECTIVA           "Conectiva" 
 #define STR_OS_DEBIAN              "Debian"
@@ -197,6 +201,7 @@ typedef enum GuestOSFamilyType {
 #define STR_OS_MKLINUX            "MkLinux"    
 #define STR_OS_NOVELL             "nld9"    
 #define STR_OS_NOVELL_FULL        "Novell Linux Desktop 9" 
+#define STR_OS_ORACLE             "oraclelinux"
 #define STR_OS_OTHER              "otherlinux"    
 #define STR_OS_OTHER_24           "other24xlinux"    
 #define STR_OS_OTHER_24_FULL      "Other Linux 2.4.x kernel" 
@@ -233,6 +238,7 @@ typedef enum GuestOSFamilyType {
 #define STR_OS_UNITEDLINUX        "UnitedLinux" 
 #define STR_OS_VALINUX            "VALinux" 
 #define STR_OS_YELLOW_DOG         "Yellow Dog"
+#define STR_OS_ECOMSTATION        "eComStation"
 
 /* Windows */
 #define STR_OS_WIN_31                   "win31"
