@@ -21,7 +21,7 @@
 
 #define INCLUDE_ALLOW_USERLEVEL
 #define INCLUDE_ALLOW_VMCORE
-#define INCLUDE_ALLOW_VMMEXT
+
 #include "includeCheck.h"
 
 #include <stdarg.h>
@@ -56,13 +56,13 @@ EXTERN Bool Log_InitForApp(const char *fileName, const char *config,
 EXTERN Bool Log_InitEx(const LogInitParams *params);
 EXTERN void Log_Exit(void);
 EXTERN void Log_SetConfigDir(const char *configDir);
-EXTERN void Log_SetLockFunc(void (*f)(Bool locking));
 EXTERN void Log_WriteLogFile(const char *msg);
 
 EXTERN Bool Log_Enabled(void);
 EXTERN const char *Log_GetFileName(void);
 
 EXTERN void Log_Flush(void);
+EXTERN void Log_UseLocking(Bool useLocking);
 EXTERN void Log_SetAlwaysKeep(Bool alwaysKeep);
 EXTERN Bool Log_RemoveFile(Bool alwaysRemove);
 EXTERN void Log_DisableThrottling(void);
@@ -78,6 +78,8 @@ EXTERN void Log_UpdateState(Bool enable, Bool append, unsigned keepOld,
 EXTERN Bool Log_SwitchFile(const char *fileName, const char *config, Bool copy);
 EXTERN Bool Log_CopyFile(const char *fileName);
 
+EXTERN size_t Log_MakeTimeString(Bool millisec, char *buf, size_t max);
+
 /* Logging that uses the custom guest throttling configuration. */
 EXTERN void GuestLog_Init(void);
 EXTERN void GuestLog_Log(const char *fmt, ...) PRINTF_DECL(1, 2);
