@@ -38,6 +38,7 @@
    LOGLEVEL_VAR(vui), \
    LOGLEVEL_VAR(stats), \
    LOGLEVEL_VAR(cpucount), \
+   LOGLEVEL_VAR(ovhdmem), \
    \
    /* user/io */ \
    LOGLEVEL_VAR(disk), \
@@ -68,6 +69,8 @@
    LOGLEVEL_VAR(uhci), \
    LOGLEVEL_VAR(pci_ehci), \
    LOGLEVEL_VAR(ehci), \
+   LOGLEVEL_VAR(pci_xhci), \
+   LOGLEVEL_VAR(xhci), \
    LOGLEVEL_VAR(usb), \
    LOGLEVEL_VAR(vusbmouse), \
    LOGLEVEL_VAR(vusbkeyboard), \
@@ -170,6 +173,7 @@
    LOGLEVEL_VAR(ipc), \
    LOGLEVEL_VAR(smbios), \
    LOGLEVEL_VAR(acpi), \
+   LOGLEVEL_VAR(acpiGPE), \
    LOGLEVEL_VAR(xpmode), \
    LOGLEVEL_VAR(snapshot), \
    LOGLEVEL_VAR(asyncsocket), \
@@ -218,13 +222,16 @@
    LOGLEVEL_VAR(vmnetBridge), \
    LOGLEVEL_VAR(wifi), /* macWireless and wpa_supplicant */ \
    LOGLEVEL_VAR(pvfslib), \
-   LOGLEVEL_VAR(brtalk), /* macWireless and wpa_supplicant */ \
+   LOGLEVEL_VAR(brtalk), \
    LOGLEVEL_VAR(button), \
    LOGLEVEL_VAR(util), \
+   LOGLEVEL_VAR(vmcf), \
    LOGLEVEL_VAR(win32util), \
    LOGLEVEL_VAR(largepage), \
    LOGLEVEL_VAR(guestAppMonitor), \
    LOGLEVEL_VAR(syncWaitQ), \
+   LOGLEVEL_VAR(sg), /* lib/sg */ \
+   LOGLEVEL_VAR(wrapLib),  \
 
 LOGLEVEL_EXTENSION_DECLARE(LOGLEVEL_USER);
 
