@@ -35,12 +35,7 @@
 #include "unicode.h"
 
 uint64 System_Uptime(void);
-Bool System_GetCurrentTime(int64 *secs, int64 *usecs);
-Bool System_AddToCurrentTime(int64 deltaSecs, int64 deltaUsecs);
 Unicode System_GetTimeAsString(void);
-Bool System_EnableTimeSlew(int64 delta, int64 timeSyncPeriod);
-Bool System_DisableTimeSlew(void);
-Bool System_IsTimeSlewEnabled(void);
 Bool System_IsACPI(void);
 void System_Shutdown(Bool reboot);
 Bool System_IsUserAdmin(void);
@@ -49,6 +44,11 @@ char *System_GetEnv(Bool global, const char *valueName);
 int System_SetEnv(Bool global, const char *valueName, const char *value);
 
 #ifdef _WIN32
+typedef enum AeroStateCommand {
+   AeroCommand_Enable,
+   AeroCommand_Disable,
+} AeroStateCommand;
+
 /*
  * Representation of monitors gathered by System_GetMonitors.
  */
@@ -70,7 +70,7 @@ typedef struct MonListNode {
  */
 #define VM_SERVICE_STATE_UNKNOWN 0xffffffff
 
-BOOL System_SetProcessPrivilege(LPCTSTR lpszPrivilege, Bool bEnablePrivilege);
+BOOL System_SetProcessPrivilege(wchar_t *privName, Bool enable);
 int32 System_GetSPVersion(void);
 Bool System_IsLoginScreenActive(void);
 Bool System_IsProcessElevated(void);
@@ -81,6 +81,7 @@ Bool System_DisableAndKillScreenSaver(void);
 DWORD System_GetServiceState(LPCWSTR szServiceName);
 DblLnkLst_Links *System_GetMonitors();
 void System_SetFocusedWindow(HWND windowToFocus, Bool force);
+Bool System_SetAeroState(AeroStateCommand command, AeroStateCommand *oldState);
 #endif
 
 
