@@ -29,7 +29,6 @@
 #define INCLUDE_ALLOW_USERLEVEL
 #define INCLUDE_ALLOW_VMCORE
 #define INCLUDE_ALLOW_VMKERNEL
-#define INCLUDE_ALLOW_VMNIXMOD
 #include "includeCheck.h"
 
 
@@ -152,7 +151,6 @@ typedef enum {
     * Korean encodings
     */
 
-   STRING_ENCODING_EUC_KR,
    STRING_ENCODING_ISO_2022_KR,
 
    /*
@@ -284,9 +282,9 @@ typedef enum {
    STRING_ENCODING_VENTURA_US,
    STRING_ENCODING_VENTURA_INTERNATIONAL,
    STRING_ENCODING_DEC_MCS,
-   STRING_ENCODING_IBM850,
+   STRING_ENCODING_IBM_850,
    STRING_ENCODING_PC8_DANISH_NORWEGIAN,
-   STRING_ENCODING_IBM862,
+   STRING_ENCODING_IBM_862,
    STRING_ENCODING_PC8_TURKISH,
    STRING_ENCODING_IBM_SYMBOLS,
    STRING_ENCODING_IBM_THAI,
@@ -299,44 +297,44 @@ typedef enum {
    STRING_ENCODING_MICROSOFT_PUBLISHING,
    STRING_ENCODING_WINDOWS_31J,
    STRING_ENCODING_MACINTOSH,
-   STRING_ENCODING_IBM037,
-   STRING_ENCODING_IBM038,
-   STRING_ENCODING_IBM273,
-   STRING_ENCODING_IBM274,
-   STRING_ENCODING_IBM275,
-   STRING_ENCODING_IBM277,
-   STRING_ENCODING_IBM278,
-   STRING_ENCODING_IBM280,
-   STRING_ENCODING_IBM281,
-   STRING_ENCODING_IBM284,
-   STRING_ENCODING_IBM285,
-   STRING_ENCODING_IBM290,
-   STRING_ENCODING_IBM297,
-   STRING_ENCODING_IBM420,
-   STRING_ENCODING_IBM423,
-   STRING_ENCODING_IBM424,
-   STRING_ENCODING_IBM437,
-   STRING_ENCODING_IBM500,
-   STRING_ENCODING_IBM851,
-   STRING_ENCODING_IBM852,
-   STRING_ENCODING_IBM855,
-   STRING_ENCODING_IBM857,
-   STRING_ENCODING_IBM860,
-   STRING_ENCODING_IBM861,
-   STRING_ENCODING_IBM863,
-   STRING_ENCODING_IBM864,
-   STRING_ENCODING_IBM865,
-   STRING_ENCODING_IBM868,
-   STRING_ENCODING_IBM869,
-   STRING_ENCODING_IBM870,
-   STRING_ENCODING_IBM871,
-   STRING_ENCODING_IBM880,
-   STRING_ENCODING_IBM891,
-   STRING_ENCODING_IBM903,
-   STRING_ENCODING_IBM904,
-   STRING_ENCODING_IBM905,
-   STRING_ENCODING_IBM918,
-   STRING_ENCODING_IBM1026,
+   STRING_ENCODING_IBM_037,
+   STRING_ENCODING_IBM_038,
+   STRING_ENCODING_IBM_273,
+   STRING_ENCODING_IBM_274,
+   STRING_ENCODING_IBM_275,
+   STRING_ENCODING_IBM_277,
+   STRING_ENCODING_IBM_278,
+   STRING_ENCODING_IBM_280,
+   STRING_ENCODING_IBM_281,
+   STRING_ENCODING_IBM_284,
+   STRING_ENCODING_IBM_285,
+   STRING_ENCODING_IBM_290,
+   STRING_ENCODING_IBM_297,
+   STRING_ENCODING_IBM_420,
+   STRING_ENCODING_IBM_423,
+   STRING_ENCODING_IBM_424,
+   STRING_ENCODING_IBM_437,
+   STRING_ENCODING_IBM_500,
+   STRING_ENCODING_IBM_851,
+   STRING_ENCODING_IBM_852,
+   STRING_ENCODING_IBM_855,
+   STRING_ENCODING_IBM_857,
+   STRING_ENCODING_IBM_860,
+   STRING_ENCODING_IBM_861,
+   STRING_ENCODING_IBM_863,
+   STRING_ENCODING_IBM_864,
+   STRING_ENCODING_IBM_865,
+   STRING_ENCODING_IBM_868,
+   STRING_ENCODING_IBM_869,
+   STRING_ENCODING_IBM_870,
+   STRING_ENCODING_IBM_871,
+   STRING_ENCODING_IBM_880,
+   STRING_ENCODING_IBM_891,
+   STRING_ENCODING_IBM_903,
+   STRING_ENCODING_IBM_904,
+   STRING_ENCODING_IBM_905,
+   STRING_ENCODING_IBM_918,
+   STRING_ENCODING_IBM_1026,
    STRING_ENCODING_EBCDIC_AT_DE,
    STRING_ENCODING_EBCDIC_AT_DE_A,
    STRING_ENCODING_EBCDIC_CA_FR,
@@ -359,22 +357,22 @@ typedef enum {
    STRING_ENCODING_VIQR,
    STRING_ENCODING_KOI8_R,
    STRING_ENCODING_HZ_GB_2312,
-   STRING_ENCODING_IBM866,
-   STRING_ENCODING_IBM775,
+   STRING_ENCODING_IBM_866,
+   STRING_ENCODING_IBM_775,
    STRING_ENCODING_KOI8_U,
-   STRING_ENCODING_IBM00858,
-   STRING_ENCODING_IBM00924,
-   STRING_ENCODING_IBM01140,
-   STRING_ENCODING_IBM01141,
-   STRING_ENCODING_IBM01142,
-   STRING_ENCODING_IBM01143,
-   STRING_ENCODING_IBM01144,
-   STRING_ENCODING_IBM01145,
-   STRING_ENCODING_IBM01146,
-   STRING_ENCODING_IBM01147,
-   STRING_ENCODING_IBM01148,
-   STRING_ENCODING_IBM01149,
-   STRING_ENCODING_IBM1047,
+   STRING_ENCODING_IBM_00858,
+   STRING_ENCODING_IBM_00924,
+   STRING_ENCODING_IBM_01140,
+   STRING_ENCODING_IBM_01141,
+   STRING_ENCODING_IBM_01142,
+   STRING_ENCODING_IBM_01143,
+   STRING_ENCODING_IBM_01144,
+   STRING_ENCODING_IBM_01145,
+   STRING_ENCODING_IBM_01146,
+   STRING_ENCODING_IBM_01147,
+   STRING_ENCODING_IBM_01148,
+   STRING_ENCODING_IBM_01149,
+   STRING_ENCODING_IBM_1047,
    STRING_ENCODING_PTCP154,
    STRING_ENCODING_AMIGA_1251,
    STRING_ENCODING_KOI7_SWITCHED,
@@ -442,6 +440,15 @@ typedef enum {
    STRING_ENCODING_WINDOWS_57009,
    STRING_ENCODING_WINDOWS_57010,
    STRING_ENCODING_WINDOWS_57011,
+   STRING_ENCODING_IBM_813,
+   STRING_ENCODING_IBM_943_P130_1999,
+   STRING_ENCODING_IBM_33722,
+   STRING_ENCODING_WINDOWS_949,
+   STRING_ENCODING_IBM_1363,
+   STRING_ENCODING_IBM_1386,
+   STRING_ENCODING_IBM_1373,
+   STRING_ENCODING_IBM_5471,
+   STRING_ENCODING_IBM_874,
 
    // Add more encodings here.
 
@@ -468,6 +475,8 @@ const char *Unicode_EncodingEnumToName(StringEncoding encoding);
 StringEncoding Unicode_EncodingNameToEnum(const char *encodingName);
 Bool Unicode_IsEncodingValid(StringEncoding encoding);
 void Unicode_Init(int argc, char ***argv, char ***envp);
+void Unicode_InitEx(int argc, char ***argv, char ***envp,
+                    const char *icuDataDir);
 #if defined (_WIN32)
 void Unicode_InitW(int argc, utf16_t **wargv, utf16_t **wenvp,
                    char ***argv, char ***envp);
