@@ -81,6 +81,10 @@ typedef struct UnityVirtualDesktopArray {
 /* Forward reference. */
 typedef struct DesktopSwitchCallbackManager DesktopSwitchCallbackManager;
 
+#ifdef __cplusplus
+extern "C" {
+#endif // __cplusplus
+
 void Unity_Init(GuestApp_Dict *conf,
                 int *blockedWnd,
                 DesktopSwitchCallbackManager *desktopSwitchCallbackMgr);
@@ -98,4 +102,8 @@ void Unity_LocalToUnityPoint(UnityPoint *unityPt, UnityPoint *localPt);
 HWND Unity_GetHwndFromUnityId(UnityWindowId id);
 #endif
 
+#ifdef __cplusplus
+};
+#endif // __cplusplus
+
 #endif
