@@ -45,13 +45,20 @@
 
 #ifdef __APPLE__
    #include <IOKit/IOTypes.h>
+   #include <CoreFoundation/CFData.h>
    #include <CoreFoundation/CFNumber.h>
    #include <CoreFoundation/CFDictionary.h>
+   #include <CoreFoundation/CFArray.h>
+   #include <CoreFoundation/CFString.h>
 #endif
 
 #include "vm_assert.h"
 #include "unicodeTypes.h"
 
+#ifdef __APPLE__
+   #define SYSTEM_VOL_DIR "/Volumes"
+#endif
+
 /*
  * Define the Util_ThreadID type.
  */
@@ -67,17 +74,54 @@ typedef pid_t Util_ThreadID;
 
 #ifdef __APPLE__
 EXTERN char *Util_CFStringToUTF8CString(CFStringRef s);
-EXTERN char *Util_IORegGetStringProperty(io_object_t entry, CFStringRef property);
+EXTERN char *Util_IORegCopyStringProperty(io_object_t entry, CFStringRef property);
 EXTERN Bool Util_IORegGetNumberProperty(io_object_t entry, CFStringRef property,
                                         CFNumberType type, void *val);
 EXTERN Bool Util_IORegGetBooleanProperty(io_object_t entry, CFStringRef property,
                                          Bool *boolVal);
+EXTERN CFDataRef Util_IORegCopyDataProperty(io_object_t entry, CFStringRef property);
+EXTERN CFDictionaryRef Util_IORegCopyDictionaryProperty(io_object_t entry,
+                                                        CFStringRef property);
 EXTERN CFMutableDictionaryRef UtilMacos_CreateCFDictionary(
    unsigned int numPairs, ...);
 EXTERN io_service_t Util_IORegGetDeviceObjectByName(const char *deviceName);
 EXTERN char *Util_GetBSDName(const char *deviceName);
 EXTERN char *Util_IORegGetDriveType(const char *deviceName);
+EXTERN uint64 Util_GetPartitionOffset(const char *bsdDev);
 EXTERN char *Util_GetMacOSDefaultVMPath();
+
+/* 
+ * Mac laptops without a cdrom drive (currently only the Air, but maybe
+ * more in the future) provide a way to use a desktop's cdrom drive
+ * remotely over the network.  These functions enumerate all such
+ * remote disks currently mounted as volumes, and return a list of
+ * volume to bsd name mappings.  The bsd device can be considered a
+ * flat-file representation of the disk contents and can be connected
+ * to our cdrom image backend.  We also include the size, since we must
+ * get that from the IO registry as well, and it doesn't change while
+ * the disk is mounted.
+ * 
+ * FYI, Apple calls this "Remote Disc" not "Remote Disk", so we follow
+ * that convention here too.
+ */
+typedef struct RemoteDiscList {
+   char                  *bsdName;
+   char                  *name;
+   uint64                 size; // In bytes
+   struct RemoteDiscList *next;
+} RemoteDiscList;
+
+EXTERN RemoteDiscList *Util_GetRemoteDiscList(void);
+EXTERN void Util_FreeRemoteDiscList(RemoteDiscList *list);
+
+/*
+ * Additional keys for disk/partition device properties.
+ */
+EXTERN const CFStringRef kUtilMacosDeviceSerialNumberKey;
+EXTERN const CFStringRef kUtilMacosVolumeOffsetKey;
+
+EXTERN CFDictionaryRef UtilMacos_CopyDiskDeviceProperties(const char *bsdDev);
+EXTERN CFArrayRef UtilMacos_CopyDiskDeviceBSDNames(const char *parentDisk);
 #endif // __APPLE__
 
 
@@ -142,10 +186,6 @@ void Util_BacktraceToBuffer(uintptr_t *basePtr,
 
 int Util_CompareDotted(const char *s1, const char *s2);
 
-#if defined(__linux__)
-void Util_PrintLoadedObjects(void *addr_inside_exec);
-#endif
-
 #if defined(VMX86_STATS)
 Bool Util_QueryCStResidency(uint32 *numCpus, uint32 *numCStates,
                             uint64 **transitns, uint64 **residency,
@@ -156,6 +196,7 @@ Bool Util_QueryCStResidency(uint32 *numCpus, uint32 *numCStates,
  * In util_shared.h
  */
 EXTERN Bool Util_Throttle(uint32 count);
+EXTERN uint32 Util_FastRand(uint32 seed);
 
 /*
  *----------------------------------------------------------------------
@@ -268,20 +309,20 @@ EXTERN Bool Util_MakeSureDirExistsAndAccessible(char const *path,
  *--------------------------------------------------------------------------
  */
 
-EXTERN void *Util_SafeInternalMalloc(int bugNumber, size_t size, char *file,
-                                     int lineno);
+EXTERN void *Util_SafeInternalMalloc(int bugNumber, size_t size,
+                                     const char *file, int lineno);
 
 EXTERN void *Util_SafeInternalRealloc(int bugNumber, void *ptr, size_t size,
-                                      char *file, int lineno);
+                                      const char *file, int lineno);
 
 EXTERN void *Util_SafeInternalCalloc(int bugNumber, size_t nmemb,
-                                     size_t size, char *file, int lineno);
+                                     size_t size, const char *file, int lineno);
 
 EXTERN char *Util_SafeInternalStrdup(int bugNumber, const char *s,
-                                     char *file, int lineno);
+                                     const char *file, int lineno);
 
 EXTERN char *Util_SafeInternalStrndup(int bugNumber, const char *s, size_t n,
-                                      char *file, int lineno);
+                                      const char *file, int lineno);
 
 #define Util_SafeMalloc(_size) \
    Util_SafeInternalMalloc(-1, (_size), __FILE__, __LINE__)
@@ -506,4 +547,70 @@ Util_FreeStringList(char **list,      // IN/OUT: the list to free
    Util_FreeList((void **) list, length);
 }
 
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * fls0 --
+ *
+ *      Highest bit set in the 'n', or -1 if all bits are clear.
+ *
+ * Results:
+ *      fls0 (== floor(log2(n)) for n != 0)
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+static INLINE int
+fls0(unsigned int n)
+{
+   if (n) {
+#ifdef _MSC_VER
+#  ifdef VM_X86_64
+      unsigned long idx;
+
+      _BitScanReverse(&idx, n);
+      return idx;
+#  else
+      int idx;
+
+      __asm bsr eax, n
+      __asm mov idx, eax
+      return idx;
+#  endif
+#else
+      int idx;
+
+      __asm__ __volatile__("bsrl %1, %0"
+                           :"=r"(idx)
+                           :"rm"(n)
+                           :"cc");
+      return idx;
+#endif
+   }
+   return -1;
+}
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * Util_Log2 --
+ *
+ *      Compute floor(log2(n)).  Returns -1 for n == 0 (-1 == log2(0.5))
+ *
+ * Results:
+ *      floor(log2(n))
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+#define Util_Log2(n) fls0(n)
+
 #endif /* UTIL_H */
