@@ -214,6 +214,8 @@ enum {
    VIX_E_SNAPSHOT_MEMORY_ON_INDEPENDENT_DISK    = 13018,
    VIX_E_SNAPSHOT_MAXSNAPSHOTS                  = 13019,
    VIX_E_SNAPSHOT_MIN_FREE_SPACE                = 13020,
+   VIX_E_SNAPSHOT_HIERARCHY_TOODEEP             = 13021,
+   VIX_E_SNAPSHOT_RRSUSPEND                     = 13022,
 
    /* Host Errors */
    VIX_E_HOST_DISK_INVALID_VALUE                = 14003,
@@ -316,6 +318,8 @@ enum {
    VIX_E_WRAPPER_VERSION_NOT_FOUND              = 22002,
    VIX_E_WRAPPER_SERVICEPROVIDER_NOT_FOUND      = 22003,
    VIX_E_WRAPPER_PLAYER_NOT_INSTALLED           = 22004,
+   VIX_E_WRAPPER_RUNTIME_NOT_INSTALLED          = 22005,
+   VIX_E_WRAPPER_MULTIPLE_SERVICEPROVIDERS      = 22006,
 
    /* FuseMnt errors*/
    VIX_E_MNTAPI_MOUNTPT_NOT_FOUND               = 24000,
@@ -367,6 +371,20 @@ enum {
    VIX_E_MNTAPI_CREATE_PARTITIONTABLE_ERROR     = 24320,
    VIX_E_MNTAPI_OPEN_FAILURE                    = 24321,
    VIX_E_MNTAPI_VOLUME_NOT_WRITABLE             = 24322,
+
+   /* Network Errors */
+   VIX_E_NET_HTTP_UNSUPPORTED_PROTOCOL     = 30001,
+   VIX_E_NET_HTTP_URL_MALFORMAT            = 30003,
+   VIX_E_NET_HTTP_COULDNT_RESOLVE_PROXY    = 30005,
+   VIX_E_NET_HTTP_COULDNT_RESOLVE_HOST     = 30006,
+   VIX_E_NET_HTTP_COULDNT_CONNECT          = 30007,
+   VIX_E_NET_HTTP_HTTP_RETURNED_ERROR      = 30022,
+   VIX_E_NET_HTTP_OPERATION_TIMEDOUT       = 30028,
+   VIX_E_NET_HTTP_SSL_CONNECT_ERROR        = 30035,
+   VIX_E_NET_HTTP_TOO_MANY_REDIRECTS       = 30047,
+   VIX_E_NET_HTTP_TRANSFER                 = 30200,
+   VIX_E_NET_HTTP_SSL_SECURITY             = 30201,
+   VIX_E_NET_HTTP_GENERIC                  = 30202,
 };
 
 // {{ End VIX_ERROR }}
@@ -419,6 +437,8 @@ enum {
    VIX_PROPERTY_VM_VMTEAM_PATHNAME                    = 105, 
    VIX_PROPERTY_VM_MEMORY_SIZE                        = 106,
    VIX_PROPERTY_VM_READ_ONLY                          = 107,
+   VIX_PROPERTY_VM_NAME                               = 108,
+   VIX_PROPERTY_VM_GUESTOS                            = 109,
    VIX_PROPERTY_VM_IN_VMTEAM                          = 128,
    VIX_PROPERTY_VM_POWER_STATE                        = 129,
    VIX_PROPERTY_VM_TOOLS_STATE                        = 152,
@@ -453,6 +473,7 @@ enum {
    VIX_PROPERTY_JOB_RESULT_SCREEN_IMAGE_DATA          = 3059,
    VIX_PROPERTY_JOB_RESULT_FILE_SIZE                  = 3061,
    VIX_PROPERTY_JOB_RESULT_FILE_MOD_TIME              = 3062,
+   VIX_PROPERTY_JOB_RESULT_EXTRA_ERROR_INFO           = 3084,
 
    /* Event properties; these are sent in the moreEventInfo for some events. */
    VIX_PROPERTY_FOUND_ITEM_LOCATION                   = 4010,
