@@ -95,6 +95,7 @@ enum {
    VIX_REQUESTMSG_RUN_IN_ANY_VMX_STATE                = 0x04,
    VIX_REQUESTMSG_REQUIRES_INTERACTIVE_ENVIRONMENT    = 0x08,
    VIX_REQUESTMSG_INCLUDES_AUTH_DATA_V1               = 0x10,
+   VIX_REQUESTMSG_REQUIRES_VMDB_NOTIFICATION          = 0x20,
 };
 
 
@@ -102,10 +103,11 @@ enum {
  * These are the flags set in responseFlags.
  */
 enum VixResponseFlagsValues {
-   VIX_RESPONSE_SOFT_POWER_OP       = 0x0001,
-   VIX_RESPONSE_EXTENDED_RESULT_V1  = 0x0002,
-   VIX_RESPONSE_TRUNCATED           = 0x0004,
-   VIX_RESPONSE_FSR                 = 0x0008
+   VIX_RESPONSE_SOFT_POWER_OP             = 0x0001,
+   VIX_RESPONSE_EXTENDED_RESULT_V1        = 0x0002,
+   VIX_RESPONSE_TRUNCATED                 = 0x0004,
+   VIX_RESPONSE_FSR                       = 0x0008,
+   VIX_RESPONSE_VMDB_NOTIFICATION_POSTED  = 0x0010,
 };
 
 
@@ -2128,7 +2130,7 @@ VixMsgPauseStateChangedEvent;
 typedef
 #include "vmware_pack_begin.h"
 struct VixMsgWaitForUserActionRequest {
-   VixCommandResponseHeader   header;
+   VixCommandRequestHeader    header;
 
    int32                      userType;
    int32                      userAction;
@@ -2226,6 +2228,14 @@ typedef enum VixCommandSecurityCategory {
     * commands.
     */
    VIX_COMMAND_CATEGORY_PRIVILEGED,
+
+   /*
+    * A command that may or may not be privileged. Usually, extra inspection
+    * of the payload is required to make the determination. This should be
+    * used sparingly, since must always be accompanied by "deep packet
+    * inspection" code in the VMX (mainDispatch.c).
+    */
+   VIX_COMMAND_CATEGORY_MIXED,
 } VixCommandSecurityCategory;
 
 /*
@@ -2611,6 +2621,10 @@ VixError VixMsg_ParseGenericRequestMsg(const VixCommandGenericRequest *request,
                                        int *options,
                                        VixPropertyListImpl *propertyList);
 
+void *VixMsg_MallocClientData(size_t size);
+void *VixMsg_ReallocClientData(void *ptr, size_t size);
+char *VixMsg_StrdupClientData(const char *s, Bool *allocateFailed);
+
 #endif   // VIX_HIDE_FROM_JAVA
 
 
