@@ -70,10 +70,9 @@
 #define _VM_BASIC_TYPES_H_
 
 #define INCLUDE_ALLOW_USERLEVEL
-#define INCLUDE_ALLOW_VMMEXT
+
 #define INCLUDE_ALLOW_MODULE
 #define INCLUDE_ALLOW_VMMON
-#define INCLUDE_ALLOW_VMNIXMOD
 #define INCLUDE_ALLOW_VMKERNEL
 #define INCLUDE_ALLOW_VMKDRIVERS
 #define INCLUDE_ALLOW_VMK_MODULE
@@ -143,25 +142,24 @@ typedef char           Bool;
 
 #include <stdint.h>
 
-typedef uint64_t uint64;
-typedef int64_t int64;
-typedef uint32_t uint32;
-typedef int32_t int32;
-typedef uint16_t uint16;
-typedef int16_t int16;
-typedef uint8_t uint8;
+typedef uint64_t    uint64;
+typedef  int64_t     int64;
+typedef uint32_t    uint32;
+typedef  int32_t     int32;
+typedef uint16_t    uint16;
+typedef  int16_t     int16;
+typedef  uint8_t    uint8;
+typedef   int8_t     int8;
 
 /*
- * XXX: int8_t is defined to be 'signed char' on Mac hosts.
+ * Note: C does not specify whether char is signed or unsigned, and
+ * both gcc and msvc implement processor-specific signedness.  With
+ * three types:
+ * typeof(char) != typeof(signed char) != typeof(unsigned char)
  *
- * Unfortunately, GCC 4.0.1 warns when doing pointer assignment or
- * comparison between signed char * and char * (even if char is
- * signed).
- *
- * If we want to use int8_t to define int8, we need to go through and
- * replace uses of char * with signed char * to prevent warnings.
+ * Be careful here, because gcc (4.0.1 and others) likes to warn about
+ * conversions between signed char * and char *.
  */
-typedef char int8;
 
 #else /* !HAVE_STDINT_H */
 
@@ -192,9 +190,9 @@ typedef unsigned int       uint32;
 typedef unsigned short     uint16;
 typedef unsigned char      uint8;
 
-typedef int       int32;
-typedef short     int16;
-typedef char      int8;
+typedef int                int32;
+typedef short              int16;
+typedef signed char        int8;
 
 #endif /* HAVE_STDINT_H */
 
@@ -255,14 +253,15 @@ typedef char      int8;
 #      endif
 #   else
 #      if !defined(__intptr_t_defined) && !defined(intptr_t)
-#         define __intptr_t_defined
-#         define intptr_t  intptr_t
 #         ifdef VM_I386
+#         define __intptr_t_defined
 #            ifdef VM_X86_64
 typedef int64     intptr_t;
 #            else
 typedef int32     intptr_t;
 #            endif
+#         elif defined(__arm__)
+typedef int32     intptr_t;
 #         endif
 #      endif
 
@@ -273,6 +272,8 @@ typedef uint64    uintptr_t;
 #            else
 typedef uint32    uintptr_t;
 #            endif
+#         elif defined(__arm__)
+typedef uint32    uintptr_t;
 #         endif
 #      endif
 #   endif
@@ -483,13 +484,10 @@ typedef User_CartelID User_CartelGroupID;
 typedef uint32 Worldlet_ID;
 #define INVALID_WORLDLET_ID ((Worldlet_ID)-1)
 
-/* world page number */
-typedef uint32    WPN;
-
 /* The Xserver source compiles with -ansi -pendantic */
 #ifndef __STRICT_ANSI__
-typedef uint64     MA;
-typedef uint32     MPN;
+typedef uint64 MA;
+typedef uint32 MPN;
 #endif
 
 /*
@@ -572,16 +570,16 @@ typedef void * UserVA;
 
 #define INVALID_BPN     ((BPN)0x1fffffff)
 
+#define RESERVED_MPN    ((MPN) 0)
 #define INVALID_MPN     ((MPN)-1)
 #define MEMREF_MPN      ((MPN)-2)
-#define RESERVED_MPN    ((MPN) 0)
+#define RELEASED_MPN    ((MPN)-3)
 #define MAX_MPN         ((MPN)0x7fffffff)  /* 43 bits of address space. */
 
 #define INVALID_LPN     ((LPN)-1)
 #define INVALID_VPN     ((VPN)-1)
 #define INVALID_LPN64   ((LPN64)-1)
 #define INVALID_PAGENUM ((PageNum)-1)
-#define INVALID_WPN     ((WPN) -1)
 
 
 /*
@@ -839,9 +837,6 @@ typedef void * UserVA;
 
 #   ifdef _BSD_SSIZE_T_
 #      undef _BSD_SSIZE_T_
-#      define _SSIZE_T
-#      define __ssize_t_defined
-#      define _SSIZE_T_DECLARED
 #      ifdef VM_I386
 #         ifdef VM_X86_64
              typedef int64 ssize_t;
@@ -853,29 +848,37 @@ typedef void * UserVA;
 
 #else
 #   ifndef _SIZE_T
-#      define _SIZE_T
 #      ifdef VM_I386
+#         define _SIZE_T
 #         ifdef VM_X86_64
              typedef uint64 size_t;
 #         else
              typedef uint32 size_t;
 #         endif
-#      endif /* VM_I386 */
+#      elif defined(__arm__)
+#         define _SIZE_T
+          typedef uint32 size_t;
+#      endif
 #   endif
 
 #   if !defined(FROBOS) && !defined(_SSIZE_T) && !defined(_SSIZE_T_) && \
        !defined(ssize_t) && !defined(__ssize_t_defined) && \
        !defined(_SSIZE_T_DECLARED)
-#      define _SSIZE_T
-#      define __ssize_t_defined
-#      define _SSIZE_T_DECLARED
 #      ifdef VM_I386
+#         define _SSIZE_T
+#         define __ssize_t_defined
+#         define _SSIZE_T_DECLARED
 #         ifdef VM_X86_64
              typedef int64 ssize_t;
 #         else
              typedef int32 ssize_t;
 #         endif
-#      endif /* VM_I386 */
+#      elif defined(__arm__)
+#         define _SSIZE_T
+#         define __ssize_t_defined
+#         define _SSIZE_T_DECLARED
+          typedef int32 ssize_t;
+#      endif
 #   endif
 
 #endif
@@ -952,6 +955,31 @@ typedef void * UserVA;
 #   endif
 #endif
 
+#ifdef __APPLE__
+/*
+ * Format specifier for all these annoying types such as {S,U}Int32
+ * which are 'long' in 32-bit builds
+ *       and  'int' in 64-bit builds.
+ */
+#   ifdef __LP64__
+#      define FMTLI ""
+#   else
+#      define FMTLI "l"
+#   endif
+
+/*
+ * Format specifier for all these annoying types such as NS[U]Integer
+ * which are  'int' in 32-bit builds
+ *       and 'long' in 64-bit builds.
+ */
+#   ifdef __LP64__
+#      define FMTIL "l"
+#   else
+#      define FMTIL ""
+#   endif
+#endif
+
+
 /*
  * Define MXSemaHandle here so both vmmon and vmx see this definition.
  */
@@ -1003,4 +1031,10 @@ typedef struct VMRect {
 } VMRect;
 #endif
 
+/*
+ * ranked locks "everywhere"
+ */
+
+typedef uint32 MX_Rank;
+
 #endif  /* _VM_BASIC_TYPES_H_ */
