@@ -22,10 +22,9 @@
 
 #ifndef RC_INVOKED
 #define INCLUDE_ALLOW_USERLEVEL
-#define INCLUDE_ALLOW_VMMEXT
+
 #define INCLUDE_ALLOW_MODULE
 #define INCLUDE_ALLOW_VMMON
-#define INCLUDE_ALLOW_VMNIXMOD
 #define INCLUDE_ALLOW_VMKERNEL
 #define INCLUDE_ALLOW_VMKDRIVERS
 #define INCLUDE_ALLOW_VMCORE
@@ -879,6 +878,20 @@ typedef uint32 ToolsVersion;
 #define   TOOLS_VERSION_ESX40_RELEASE_V_MNR  0
 #define   TOOLS_VERSION_ESX40_RELEASE_V_BASE 1
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_ESX40_UPDATE1  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_ESX40_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_ESX40_UPDATE1_V_MJR  8
+#define   TOOLS_VERSION_ESX40_UPDATE1_V_MNR  0
+#define   TOOLS_VERSION_ESX40_UPDATE1_V_BASE 2
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_ESX40_UPDATE2  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_ESX40_UPDATE2_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_ESX40_UPDATE2_V_MJR  8
+#define   TOOLS_VERSION_ESX40_UPDATE2_V_MNR  0
+#define   TOOLS_VERSION_ESX40_UPDATE2_V_BASE 3
+
 #ifndef RC_INVOKED
 #define   TOOLS_VERSION_WS70_BETA1  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_WS70_BETA1_V)
 #endif /* RC_INVOKED */
@@ -935,6 +948,13 @@ typedef uint32 ToolsVersion;
 #define   TOOLS_VERSION_FUSION30_RELEASE_V_MNR  2
 #define   TOOLS_VERSION_FUSION30_RELEASE_V_BASE 3
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_FUSION30_UPDATE1   TOOLS_VERSION_TO_UINT(TOOLS_VERSION_FUSION30_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_FUSION30_UPDATE1_V_MJR  8
+#define   TOOLS_VERSION_FUSION30_UPDATE1_V_MNR  2
+#define   TOOLS_VERSION_FUSION30_UPDATE1_V_BASE 4
+
 #ifndef RC_INVOKED
 #define   TOOLS_VERSION_ESX45_BETA1  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_ESX45_BETA1_V)
 #endif /* RC_INVOKED */
@@ -942,10 +962,30 @@ typedef uint32 ToolsVersion;
 #define   TOOLS_VERSION_ESX45_BETA1_V_MNR  3
 #define   TOOLS_VERSION_ESX45_BETA1_V_BASE 0
 
-#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_ESX45_BETA1
-#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_ESX45_BETA1)
-#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_ESX45_BETA1)
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_ESX45_RC1  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_ESX45_RC1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_ESX45_RC1_V_MJR   8
+#define   TOOLS_VERSION_ESX45_RC1_V_MNR   3
+#define   TOOLS_VERSION_ESX45_RC1_V_BASE  1
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_ESX45_RELEASE  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_ESX45_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_ESX45_RELEASE_V_MJR  8
+#define   TOOLS_VERSION_ESX45_RELEASE_V_MNR  3
+#define   TOOLS_VERSION_ESX45_RELEASE_V_BASE 2
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_HOSTED10_BETA1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_HOSTED10_BETA1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_HOSTED10_BETA1_V_MJR  8
+#define   TOOLS_VERSION_HOSTED10_BETA1_V_MNR  4
+#define   TOOLS_VERSION_HOSTED10_BETA1_V_BASE 0
+
+#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_HOSTED10_BETA1
+#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_HOSTED10_BETA1)
+#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_HOSTED10_BETA1)
 
 /*
  * The extended Tools version is the current Tools version with the
