@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2009-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2009 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -40,52 +40,17 @@
 /** TCLO channel name for the HGFS driver. */
 #define TOOLS_HGFS_NAME           "tools-hgfs"
 
-/*
- * The TCLO channel names used by the View Agent Service.
- * vdiagent may register RPC callbacks to be notified of certain events not
- * handled by Tools Service.
- */
-#define TOOLS_VDIAGENT_NAME       "vdiagent"
-
-/** Reply from host when the command is not recognized. */
-#define RPCI_UNKNOWN_COMMAND      "Unknown command"
-
-#define GUESTRPC_TCLO_VSOCK_LISTEN_PORT      975
-#define GUESTRPC_RPCI_VSOCK_LISTEN_PORT      976
 
 /*
  * Tools options.
  */
-
-#define TOOLSOPTION_COPYPASTE                     "copypaste"
-#define TOOLSOPTION_AUTOHIDE                      "autohide"
-#define TOOLSOPTION_BROADCASTIP                   "broadcastIP"
-#define TOOLSOPTION_ENABLEDND                     "enableDnD"
-#define TOOLSOPTION_MAP_ROOT_HGFS_SHARE           "mapRootHgfsShare"
-#define TOOLSOPTION_LINK_ROOT_HGFS_SHARE          "linkRootHgfsShare"
-#define TOOLSOPTION_ENABLE_MESSAGE_BUS_TUNNEL     "enableMessageBusTunnel"
-
-/*
- * Auto-upgrade commands.
- */
-
-#define AUTOUPGRADE_AVAILABLE_CMD   "vmx.capability.tools_is_upgradable"
-#define AUTOUPGRADE_START_CMD       "guest.initiateAutoUpgrade"
-
-/* More upgrader commands. */
-#define GUEST_UPGRADER_SEND_CMD_LINE_ARGS  "guest.upgrader_send_cmd_line_args"
-
-/*
- * Shrink commands.
- */
-
-#define DISK_SHRINK_CMD             "disk.shrink"
-
-/*
- * Auto-lock commands.
- */
-
-#define DESKTOP_AUTOLOCK_CMD        "Autolock_Desktop"
+ 
+#define TOOLSOPTION_COPYPASTE                "copypaste"
+#define TOOLSOPTION_AUTOHIDE                 "autohide"
+#define TOOLSOPTION_BROADCASTIP              "broadcastIP"
+#define TOOLSOPTION_ENABLEDND                "enableDnD"
+#define TOOLSOPTION_MAP_ROOT_HGFS_SHARE      "mapRootHgfsShare"
+#define TOOLSOPTION_LINK_ROOT_HGFS_SHARE     "linkRootHgfsShare"
 
 
 /*
@@ -117,17 +82,6 @@
 /* When set, toolboxes should not show the cursor options page. */
 #define VMWARE_DISABLE_CURSOR_OPTIONS     0x800
 
-#define  RPCIN_TCLO_PING                 0x1
-
-enum {
-   GUESTRPCPKT_TYPE_DATA = 1,
-   GUESTRPCPKT_TYPE_PING
-};
-
-enum {
-   GUESTRPCPKT_FIELD_TYPE = 1,
-   GUESTRPCPKT_FIELD_PAYLOAD
-};
 
 #endif /* _TCLODEFS_H_ */
 
