@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2008-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2008 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -24,14 +24,8 @@
  *
  *    Public functions from the VMTools shared library, and other definitions.
  *
- * @defgroup vmtools_utils Utility Functions
+ * @addtogroup vmtools_utils
  * @{
- *
- * @brief A collection of useful functions.
- *
- * This module contains functions for loading configuration data and extensions
- * to the glib API that are useful when writing applications.
- *
  */
 
 #define  VMTOOLS_GUEST_SERVICE   "vmsvc"
@@ -95,15 +89,17 @@
 #  define VMTOOLS_RELEASE_FILENAME_LOCAL(path)   g_free(path)
 #endif
 
-/** Convenience macro around VMTools_WrapArray. */
-#define VMTOOLS_WRAP_ARRAY(a) VMTools_WrapArray((a), sizeof *(a), G_N_ELEMENTS(a))
-
-
 G_BEGIN_DECLS
 
 void
 vm_free(void *ptr);
 
+void
+VMTools_ConfigLogging(const gchar *defaultDomain,
+                      GKeyFile *cfg,
+                      gboolean force,
+                      gboolean reset);
+
 gboolean
 VMTools_LoadConfig(const gchar *path,
                    GKeyFileFlags flags,
@@ -115,12 +111,6 @@ VMTools_WriteConfig(const gchar *path,
                     GKeyFile *config,
                     GError **err);
 
-gboolean
-VMTools_ChangeLogFilePath(const gchar *delimiter,
-                          const gchar *appendString,
-                          const gchar *domain,
-                          GKeyFile *conf);
-
 #if defined(G_PLATFORM_WIN32)
 
 gboolean
@@ -137,35 +127,8 @@ typedef gboolean (*SignalSourceCb)(const siginfo_t *, gpointer);
 GSource *
 VMTools_NewSignalSource(int signum);
 
-gchar *
-VMTools_GetLibdir(void);
-
 #endif
 
-GSource *
-VMTools_CreateTimer(gint timeout);
-
-void
-VMTools_SetGuestSDKMode(void);
-
-void
-VMTools_AcquireLogStateLock(void);
-
-void
-VMTools_ReleaseLogStateLock(void);
-
-void
-VMTools_StopLogging(void);
-
-void
-VMTools_RestartLogging(void);
-
-void
-VMTools_SuspendLogIO(void);
-
-void
-VMTools_ResumeLogIO(void);
-
 GArray *
 VMTools_WrapArray(gconstpointer data,
                   guint elemSize,
