@@ -75,12 +75,14 @@
 #include "vm_product.h"
 #include "vm_atomic.h"
 #include "unicode/ucnv.h"
+#include "unicode/udata.h"
 #include "unicode/putil.h"
 #include "file.h"
 #include "util.h"
 #include "codeset.h"
 #include "codesetOld.h"
 #include "str.h"
+#include "win32util.h"
 
 /*
  * Macros
@@ -101,9 +103,9 @@
 
 #define ICU_DATA_FILE "icudt38l.dat"
 #ifdef _WIN32
-#define ICU_DATA_FILE_DIR "%TCROOT%/noarch/icu-data-3.8-1"
+#define ICU_DATA_FILE_DIR "%TCROOT%/noarch/icu-data-3.8-2"
 #else
-#define ICU_DATA_FILE_DIR "/build/toolchain/noarch/icu-data-3.8-1"
+#define ICU_DATA_FILE_DIR "/build/toolchain/noarch/icu-data-3.8-2"
 #endif
 
 #ifdef _WIN32
@@ -121,13 +123,6 @@
 
 static Bool dontUseIcu = TRUE;
 
-#ifdef _WIN32
-static Bool initedIcu = FALSE;
-static Atomic_Ptr sCriticalSection;
-#else // Posix
-DEBUG_ONLY(static Bool initedIcu = FALSE;)
-#endif
-
 
 /*
  * Functions
@@ -186,74 +181,7 @@ CodeSetGetModulePath(HANDLE hModule) // IN
 }
 
 
-/*
- *----------------------------------------------------------------------------
- *
- * CodeSetEnterCriticalSection --
- *
- *      Initialize critical section atomically, and enter that critical section.
- *
- * Returns:
- *      None.
- *
- * Side effects:
- *      None.
- *
- *----------------------------------------------------------------------------
- */
-
-void
-CodeSetEnterCriticalSection(void)
-{
-   CRITICAL_SECTION *cs = Atomic_ReadPtr(&sCriticalSection);
-
-   // Initalize critical section atomically.
-   if (cs == NULL) {
-      CRITICAL_SECTION *newcs = Util_SafeMalloc(sizeof *newcs);
-      InitializeCriticalSection(newcs);
-
-      Atomic_Init();
-      cs = Atomic_ReadIfEqualWritePtr(&sCriticalSection, NULL, newcs);
-
-      if (cs == NULL) {
-	 cs = newcs;
-      } else {
-         DeleteCriticalSection(newcs);
-	 free(newcs);
-      }
-   }
-
-   ASSERT(cs);
-   EnterCriticalSection(cs);
-}
-
-
-/*
- *----------------------------------------------------------------------------
- *
- * CodeSetLeaveCriticalSection --
- *
- *      Leave critical section.
- *
- * Returns:
- *      None.
- *
- * Side effects:
- *      None.
- *
- *----------------------------------------------------------------------------
- */
-
-void
-CodeSetLeaveCriticalSection(void)
-{
-   CRITICAL_SECTION *cs = Atomic_ReadPtr(&sCriticalSection);
-
-   ASSERT(cs);
-   LeaveCriticalSection(cs);
-}
-
-#elif vmx86_devel // _WIN32
+#elif vmx86_devel && !defined(TEST_CUSTOM_ICU_DATA_FILE) // _WIN32
 
 /*
  *-----------------------------------------------------------------------------
@@ -451,29 +379,18 @@ CodeSet_Init(const char *icuDataDir) // IN: ICU data file location in Current co
    DWORD attribs;
    utf16_t *modPath = NULL;
    utf16_t *lastSlash;
+   utf16_t *wpath;
+   HANDLE hFile = INVALID_HANDLE_VALUE;
+   HANDLE hMapping = NULL;
+   void *memMappedData = NULL;
 #else
    struct stat finfo;
 #endif
    char *path = NULL;
    Bool ret = FALSE;
 
-#ifdef _WIN32
-   CodeSetEnterCriticalSection();
-#endif
-
    DynBuf_Init(&dbpath);
 
-#ifdef _WIN32
-   if (initedIcu) {
-      // Nothing to be initialized.
-      ret = TRUE;
-      goto exit;
-   }
-#else // Posix
-   DEBUG_ONLY(ASSERT(!initedIcu);)
-   DEBUG_ONLY(initedIcu = TRUE;)
-#endif
-
 #ifdef USE_ICU
    /*
     * We're using system ICU, which finds its own data. So nothing to
@@ -495,7 +412,7 @@ CodeSet_Init(const char *icuDataDir) // IN: ICU data file location in Current co
 
 #ifdef _WIN32 // {
 
-#if vmx86_devel
+#if vmx86_devel && !defined(TEST_CUSTOM_ICU_DATA_FILE)
    /*
     * Devel builds use toolchain directory first.
     */
@@ -550,9 +467,15 @@ CodeSet_Init(const char *icuDataDir) // IN: ICU data file location in Current co
       path = (char *) DynBuf_Detach(&dbpath);
    } else {
       /*
-       * Data file must be in current module directory.
+       * Data file must be in the directory of the current module
+       * (i.e. the module that contains CodeSet_Init()).
        */
-      modPath = CodeSetGetModulePath(NULL);
+      HMODULE hModule = W32Util_GetModuleByAddress((void *) CodeSet_Init);
+      if (!hModule) {
+         goto exit;
+      }
+
+      modPath = CodeSetGetModulePath(hModule);
       if (!modPath) {
          goto exit;
       }
@@ -575,35 +498,31 @@ CodeSet_Init(const char *icuDataDir) // IN: ICU data file location in Current co
       }
 
       /*
-       * Check for file existence.
+       * Since u_setDataDirectory can't handle UTF-16, we would have to
+       * now convert this path to local encoding. But that fails when
+       * the module is in a path containing characters not in the
+       * local encoding (see 282524). So we'll memory-map the file
+       * instead and call udata_setCommonData() below.
        */
-      attribs = GetFileAttributesW((LPCWSTR) DynBuf_Get(&dbpath));
-
-      if ((INVALID_FILE_ATTRIBUTES == attribs) ||
-          (attribs & FILE_ATTRIBUTE_DIRECTORY)) {
+      wpath = (utf16_t *) DynBuf_Get(&dbpath);
+      hFile = CreateFileW(wpath, GENERIC_READ, 0, NULL, OPEN_EXISTING, 0,
+                          NULL);
+      if (INVALID_HANDLE_VALUE == hFile) {
          goto exit;
       }
-
-      /*
-       * Convert path to local encoding using system APIs (old codeset).
-       */
-      if (!CodeSetOld_Utf16leToCurrent(DynBuf_Get(&dbpath),
-                                       DynBuf_GetSize(&dbpath),
-                                       &path, NULL)) {
-
-         /*
-          * The unicode path is not compatible in the current encoding.
-          */
-         path = CodeSet_GetAltPathName(DynBuf_Get(&dbpath));
-         if (!path) {
-            goto exit;
-         }
+      hMapping = CreateFileMapping(hFile, NULL, PAGE_READONLY, 0, 0, NULL);
+      if (NULL == hMapping) {
+         goto exit;
+      }
+      memMappedData = MapViewOfFile(hMapping, FILE_MAP_READ, 0, 0, 0);
+      if (NULL == memMappedData) {
+         goto exit;
       }
    }
 
 #else // } _WIN32 {
 
-#if vmx86_devel
+#if vmx86_devel && !defined(TEST_CUSTOM_ICU_DATA_FILE)
    {
       char *modPath;
       char *lastSlash;
@@ -672,14 +591,32 @@ CodeSet_Init(const char *icuDataDir) // IN: ICU data file location in Current co
 
 #endif // } _WIN32
 
-#if vmx86_devel
+#if vmx86_devel && !defined(TEST_CUSTOM_ICU_DATA_FILE)
 found:
 #endif
 
-   /*
-    * Tell ICU to use this directory.
-    */
-   u_setDataDirectory(path);
+#ifdef _WIN32
+   if (memMappedData) {
+      /*
+       * Tell ICU to use this mapped data.
+       */
+      UErrorCode uerr = U_ZERO_ERROR;
+      ASSERT(memMappedData);
+
+      udata_setCommonData(memMappedData, &uerr);
+      if (uerr != U_ZERO_ERROR) {
+         UnmapViewOfFile(memMappedData);
+         goto exit;
+      }
+   } else {
+#endif
+      /*
+       * Tell ICU to use this directory.
+       */
+      u_setDataDirectory(path);
+#ifdef _WIN32
+   }
+#endif
 
    dontUseIcu = FALSE;
    ret = TRUE;
@@ -702,15 +639,16 @@ found:
 
 #ifdef _WIN32
    free(modPath);
+   if (hMapping) {
+      CloseHandle(hMapping);
+   }
+   if (hFile != INVALID_HANDLE_VALUE) {
+      CloseHandle(hFile);
+   }
 #endif
    free(path);
    DynBuf_Destroy(&dbpath);
 
-#ifdef _WIN32
-   initedIcu = ret;
-   CodeSetLeaveCriticalSection();
-#endif
-
    return ret;
 }
 
