@@ -26,9 +26,15 @@
 #include "vmware.h"
 #include <string.h>
 
+#if defined(__i386__) || defined(__x86_64__)
 #include "cpuid_info.h"
+#endif
 #include "hostinfo.h"
+#include "hostinfoInt.h"
+#include "str.h"
 #include "util.h"
+#include "str.h"
+#include "dynbuf.h"
 
 #define LOGLEVEL_MODULE hostinfo
 #include "loglevel_user.h"
@@ -36,6 +42,16 @@
 #define LGPFX "HOSTINFO:"
 
 
+/*
+ * HostinfoOSData caches its returned value.
+ */
+
+volatile Bool HostinfoOSNameCacheValid = FALSE;
+char HostinfoCachedOSName[MAX_OS_NAME_LEN];
+char HostinfoCachedOSFullName[MAX_OS_FULLNAME_LEN];
+
+
+#if defined(__i386__) || defined(__x86_64__)
 /*
  *----------------------------------------------------------------------
  *
@@ -98,6 +114,112 @@ HostInfoGetAMDCPUCount(CPUIDSummary *cpuid,       // IN
 }
 
 
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * HostInfoGetCpuidStrSection --
+ *
+ *       Append a section (either low or high) of CPUID as a string in DynBuf.
+ *       E.g.
+ *          00000000:00000005756E65476C65746E49656E69-
+ *          00000001:00000F4A000208000000649DBFEBFBFF-
+ *       or
+ *          80000000:80000008000000000000000000000000-
+ *          80000001:00000000000000000000000120100000-
+ *          80000008:00003024000000000000000000000000-
+ *
+ *       The returned eax of args[0] is used to determine the upper bound for
+ *       the following input arguments. And the input args should be in ascending
+ *       order.
+ *
+ * Results:
+ *       None. The string will be appended in buf.
+ *
+ * Side effect:
+ *       None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+static void
+HostInfoGetCpuidStrSection(const uint32 args[],    // IN: input eax arguments
+                           const size_t args_size, // IN: size of the argument array
+                           DynBuf *buf)            // IN/OUT: result string in DynBuf
+{
+   static const char format[] = "%08X:%08X%08X%08X%08X-";
+   CPUIDRegs reg;
+   uint32 max_arg;
+   char temp[64];
+   int i;
+
+   __GET_CPUID(args[0], &reg);
+   max_arg = reg.eax;
+   if (max_arg < args[0]) {
+      Warning(LGPFX" No CPUID information available. Based = %08X.\n", args[0]);
+      return;
+   }
+   DynBuf_Append(buf, temp,
+      Str_Sprintf(temp, sizeof temp, format, args[0], reg.eax, reg.ebx, reg.ecx, reg.edx));
+
+   for (i = 1; i < args_size && args[i] <= max_arg; i++) {
+      ASSERT(args[i] > args[i - 1]); // Ascending order.
+      __GET_CPUID(args[i], &reg);
+
+      DynBuf_Append(buf, temp,
+         Str_Sprintf(temp, sizeof temp, format, args[i], reg.eax, reg.ebx, reg.ecx, reg.edx));
+   }
+}
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * Hostinfo_GetCpuidStr --
+ *
+ *       Get the basic and extended CPUID as a string. E.g.
+ *          00000000:00000005756E65476C65746E49656E69-
+ *          00000001:00000F4A000208000000649DBFEBFBFF-
+ *          80000000:80000008000000000000000000000000-
+ *          80000001:00000000000000000000000120100000-
+ *          80000008:00003024000000000000000000000000
+ *
+ *       If the extended CPUID is not available, only returns the basic CPUID.
+ *
+ * Results:
+ *       The CPUID string if the processor supports the CPUID instruction and this
+ *       is a processor we recognize. It should never fail, since it would at least
+ *       return leaf 0. Caller needs to free the returned string.
+ *
+ * Side effect:
+ *       None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+char *
+Hostinfo_GetCpuidStr(void)
+{
+   static const uint32 basic_args[] = {0x0, 0x1, 0xa};
+   static const uint32 extended_args[] = {0x80000000, 0x80000001, 0x80000008};
+   DynBuf buf;
+   char *result;
+
+   DynBuf_Init(&buf);
+
+   HostInfoGetCpuidStrSection(basic_args, ARRAYSIZE(basic_args), &buf);
+   HostInfoGetCpuidStrSection(extended_args, ARRAYSIZE(extended_args), &buf);
+
+   // Trim buffer and set NULL character to replace last '-'.
+   DynBuf_Trim(&buf);
+   result = (char*)DynBuf_Get(&buf);
+   ASSERT(result && result[0]); // We should at least get result from eax = 0x0.
+   result[DynBuf_GetSize(&buf) - 1] = '\0';
+
+   return DynBuf_Detach(&buf);
+}
+#endif // defined(__i386__) || defined(__x86_64__)
+
+
 /*
  *-----------------------------------------------------------------------------
  *
@@ -120,6 +242,7 @@ HostInfoGetAMDCPUCount(CPUIDSummary *cpuid,       // IN
 Bool
 Hostinfo_GetCpuid(HostinfoCpuIdInfo *info) // OUT
 {
+#if defined(__i386__) || defined(__x86_64__)
    CPUIDSummary cpuid;
    CPUIDRegs id0;
    uint32 numCoresPerPCPU, numThreadsPerCore;
@@ -212,7 +335,7 @@ Hostinfo_GetCpuid(HostinfoCpuIdInfo *info) // OUT
       Log(LGPFX" hyperthreading disabled, setting number of threads per core "
                "to 1.\n");
       numThreadsPerCore = 1;
-   } 
+   }
 #endif
 
    info->numPhysCPUs = info->numLogCPUs / (numCoresPerPCPU *
@@ -250,6 +373,55 @@ Hostinfo_GetCpuid(HostinfoCpuIdInfo *info) // OUT
    info->features = cpuid.id1.edxFeatures;
 
    return TRUE;
+#else // defined(__i386__) || defined(__x86_64__)
+   return FALSE;
+#endif // defined(__i386__) || defined(__x86_64__)
+}
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * Hostinfo_GetOSName --
+ *
+ *      Query the operating system and build a pair of strings to identify it.
+ *      The two strings are osName and osNameFull.  Short osName strings are
+ *      the same as you'd see in a VM's .vmx file.
+ *
+ *      The long names are a bit more descriptive:
+ *         Windows: <OS NAME> <SERVICE PACK> (BUILD <BUILD_NUMBER>)
+ *         example: Windows XP Professional Service Pack 2 (Build 2600)
+ *
+ *         Linux:   <OS NAME> <OS RELEASE> <SPECIFIC_DISTRO_INFO>
+ *         example: Linux 2.4.18-3 Red Hat Linux release 7.3 (Valhalla)
+ *
+ * Return value:
+ *      Returns TRUE on success and FALSE on failure.
+ *      Returns the guest's full OS name (osFullName)
+ *      Returns the guest's OS name in the same format as .vmx file (osName)
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+Bool
+Hostinfo_GetOSName(uint32 outBufFullLen,  // IN: length of osFullName buffer
+                   uint32 outBufLen,      // IN: length of osName buffer
+                   char *osFullName,      // OUT: Full OS name
+                   char *osName)          // OUT: OS name
+{
+   Bool retval;
+
+   retval = HostinfoOSNameCacheValid ? TRUE : HostinfoOSData();
+
+   if (retval) {
+       Str_Strcpy(osFullName, HostinfoCachedOSFullName, outBufFullLen);
+       Str_Strcpy(osName, HostinfoCachedOSName, outBufLen);
+   }
+
+   return retval;
 }
 
 
@@ -270,11 +442,12 @@ Hostinfo_GetCpuid(HostinfoCpuIdInfo *info) // OUT
  *----------------------------------------------------------------------
  */
 
-char * 
+char *
 Hostinfo_HypervisorCPUIDSig(void)
 {
+   uint32 *name = NULL;
+#if defined(__i386__) || defined(__x86_64__)
    CPUIDRegs regs;
-   uint32 *name;
 
    __GET_CPUID(1, &regs);
    if (!(regs.ecx & CPUID_FEATURE_COMMON_ID1ECX_HYPERVISOR)) {
@@ -298,6 +471,7 @@ Hostinfo_HypervisorCPUIDSig(void)
    name[1] = regs.ecx;
    name[2] = regs.edx;
    name[3] = 0;
+#endif // defined(__i386__) || defined(__x86_64__)
 
    return (char *)name;
 }
@@ -339,7 +513,7 @@ Hostinfo_TouchXen(void)
    CPUIDRegs regs;
    uint32 name[4];
 
-   /* 
+   /*
     * PV mode: ud2a "xen" cpuid (faults on native hardware).
     * (Only Linux can run PV, so skip others here).
     * Since PV cannot trap CPUID, this is a Xen hook.
@@ -366,7 +540,7 @@ Hostinfo_TouchXen(void)
    /* Passed checks.  But native and anything non-Xen would #UD before here. */
    NOT_TESTED();
    Log("Xen detected but hypervisor unrecognized (Xen variant?)\n");
-   Log("CPUID 0x4000 0000: eax=%x ebx=%x ecx=%x edx=%x\n", 
+   Log("CPUID 0x4000 0000: eax=%x ebx=%x ecx=%x edx=%x\n",
        regs.eax, regs.ebx, regs.ecx, regs.edx);
 #endif
 
