@@ -85,6 +85,7 @@
 #include "vmware.h"
 #include "hostType.h"
 #include "hostinfo.h"
+#include "hostinfoInt.h"
 #include "safetime.h"
 #include "vm_version.h"
 #include "str.h"
@@ -97,11 +98,15 @@
 #include "vmstdio.h"
 #include "su.h"
 #include "vm_atomic.h"
+
+#if defined(__i386__) || defined(__x86_64__)
 #include "x86cpuid.h"
-#include "syncMutex.h"
+#endif
+
 #include "unicode.h"
 #include "guest_os.h"
 #include "dynbuf.h"
+#include "strutil.h"
 
 #if defined(VMX86_SERVER)
 #include "uwvmkAPI.h"
@@ -315,7 +320,7 @@ Hostinfo_OSVersion(int i)
  *----------------------------------------------------------------------
  */
 
-void 
+void
 Hostinfo_GetTimeOfDay(VmTimeType *time)
 {
    struct timeval tv;
@@ -504,6 +509,8 @@ HostinfoGetOSShortName(char *distro,         // IN: full distro name
       Str_Strcpy(distroShort, STR_OS_BLACKCAT, distroShortSize);
    } else if (strstr(distroLower, "cobalt")) {
       Str_Strcpy(distroShort, STR_OS_COBALT, distroShortSize);
+   } else if (StrUtil_StartsWith(distroLower, "centos")) {
+      Str_Strcpy(distroShort, STR_OS_CENTOS, distroShortSize);
    } else if (strstr(distroLower, "conectiva")) {
       Str_Strcpy(distroShort, STR_OS_CONECTIVA, distroShortSize);
    } else if (strstr(distroLower, "debian")) {
@@ -512,6 +519,15 @@ HostinfoGetOSShortName(char *distro,         // IN: full distro name
       } else if (strstr(distroLower, "5.0")) {
          Str_Strcpy(distroShort, STR_OS_DEBIAN_5, distroShortSize);
       }
+   } else if (StrUtil_StartsWith(distroLower, "enterprise linux")) {
+      /*
+       * [root@localhost ~]# lsb_release -sd
+       * "Enterprise Linux Enterprise Linux Server release 5.4 (Carthage)"
+       *
+       * Not sure why they didn't brand their releases as "Oracle Enterprise
+       * Linux".  Oh well.
+       */
+      Str_Strcpy(distroShort, STR_OS_ORACLE, distroShortSize);
    } else if (strstr(distroLower, "fedora")) {
       Str_Strcpy(distroShort, STR_OS_FEDORA, distroShortSize);
    } else if (strstr(distroLower, "gentoo")) {
@@ -595,6 +611,11 @@ HostinfoReadDistroFile(char *filename,  // IN: distro version file name
       goto out;
    }
 
+   if (st.st_size == 0) {
+      Warning("%s: Cannot work with empty file.\n", __FUNCTION__);
+      goto out;
+   }
+
    buf_sz = st.st_size;
    if (buf_sz >= distroSize) {
       Warning("%s: input buffer too small\n", __FUNCTION__);
@@ -615,7 +636,7 @@ HostinfoReadDistroFile(char *filename,  // IN: distro version file name
       goto out;
    }
 
-   distroOrig[buf_sz] = '\0';
+   distroOrig[buf_sz - 1] = '\0';
 
    /*
     * For the case where we do have a release file in the LSB format,
@@ -719,7 +740,8 @@ HostinfoGetCmdOutput(const char *cmd)  // IN:
          break;
       }
 
-      DynBuf_Append(&db, line, size);
+      /* size does -not- include the NUL terminator. */
+      DynBuf_Append(&db, line, size + 1);
       free(line);
    }
 
@@ -739,40 +761,35 @@ HostinfoGetCmdOutput(const char *cmd)  // IN:
 /*
  *-----------------------------------------------------------------------------
  *
- * Hostinfo_GetOSName --
+ * HostinfoOSData --
  *
- *      Return OS version information. First retrieve OS information using
- *      uname, then look in /etc/xxx-release file to get the distro info.
- *      osFullName will be:
- *      <OS NAME> <OS RELEASE> <SPECIFIC_DISTRO_INFO>
- *      An example of such string would be:
- *      Linux 2.4.18-3 Red Hat Linux release 7.3 (Valhalla)
+ *      Determine the OS short (.vmx format) and long names.
  *
- *      osName contains an os name in the same format that is used
- *      in .vmx file.
+ *      First retrieve OS information using uname, then look in
+ *      /etc/xxx-release file to get the distro info.
  *
  * Return value:
  *      Returns TRUE on success and FALSE on failure.
- *      Returns the guest's full OS name (osNameFull)
- *      Returns the guest's OS name in the same format as .vmx file (osName)
  *
  * Side effects:
- *      None
+ *      Cache values are set when returning TRUE.
  *
  *-----------------------------------------------------------------------------
  */
 
 Bool
-Hostinfo_GetOSName(uint32 outBufFullLen,  // IN: length of osNameFull buffer
-                   uint32 outBufLen,      // IN: length of osName buffer
-                   char *osNameFull,      // OUT: Full OS name
-                   char *osName)          // OUT: OS name (.vmx file format)
+HostinfoOSData(void)
 {
    struct utsname buf;
    unsigned int lastCharPos;
    const char *lsbCmd = "lsb_release -sd 2>/dev/null";
    char *lsbOutput = NULL;
 
+   char osName[MAX_OS_NAME_LEN];
+   char osNameFull[MAX_OS_FULLNAME_LEN];
+
+   static Atomic_uint32 mutex = {0};
+
    /*
     * Use uname to get complete OS information.
     */
@@ -784,16 +801,14 @@ Hostinfo_GetOSName(uint32 outBufFullLen,  // IN: length of osNameFull buffer
    }
 
 
-   if (strlen(buf.sysname) + strlen(buf.release) + 3 > outBufFullLen) {
+   if (strlen(buf.sysname) + strlen(buf.release) + 3 > sizeof osNameFull) {
       Warning("%s: Error: buffer too small\n", __FUNCTION__);
 
       return FALSE;
    }
 
-   Str_Strcpy(osName, STR_OS_EMPTY, outBufLen);
-   Str_Strcpy(osNameFull, buf.sysname, outBufFullLen);
-   Str_Strcat(osNameFull, STR_OS_EMPTY, outBufFullLen);
-   Str_Strcat(osNameFull, buf.release, outBufFullLen);
+   Str_Strcpy(osName, STR_OS_EMPTY, sizeof osName);
+   Str_Sprintf(osNameFull, sizeof osNameFull, "%s %s", buf.sysname, buf.release);
 
    /*
     * Check to see if this is Linux
@@ -811,10 +826,10 @@ Hostinfo_GetOSName(uint32 outBufFullLen,  // IN: length of osNameFull buffer
        * later we find more detailed information this will get overwritten.
        */
 
-      if (strstr(buf.release, "2.4")) {
+      if (StrUtil_StartsWith(buf.release, "2.4.")) {
          Str_Strcpy(distro, STR_OS_OTHER_24_FULL, distroSize);
          Str_Strcpy(distroShort, STR_OS_OTHER_24, distroSize);
-      } else if (strstr(buf.release, "2.6")) {
+      } else if (StrUtil_StartsWith(buf.release, "2.6.")) {
          Str_Strcpy(distro, STR_OS_OTHER_26_FULL, distroSize);
          Str_Strcpy(distroShort, STR_OS_OTHER_26, distroSize);
       } else {
@@ -854,7 +869,7 @@ Hostinfo_GetOSName(uint32 outBufFullLen,  // IN: length of osNameFull buffer
          char *lsbStart = lsbOutput;
          char *quoteEnd = NULL;
 
-         if (lsbStart[1] == '"') {
+         if (lsbStart[0] == '"') {
             lsbStart++;
             quoteEnd = strchr(lsbStart, '"');
             if (quoteEnd) {
@@ -867,22 +882,22 @@ Hostinfo_GetOSName(uint32 outBufFullLen,  // IN: length of osNameFull buffer
 
       HostinfoGetOSShortName(distro, distroShort, distroSize);
 
-      if (strlen(distro) + strlen(osNameFull) + 2 > outBufFullLen) {
+      if (strlen(distro) + strlen(osNameFull) + 2 > sizeof osNameFull) {
          Warning("%s: Error: buffer too small\n", __FUNCTION__);
 
          return FALSE;
       }
 
-      Str_Strcat(osNameFull, " ", outBufFullLen);
-      Str_Strcat(osNameFull, distro, outBufFullLen);
+      Str_Strcat(osNameFull, " ", sizeof osNameFull);
+      Str_Strcat(osNameFull, distro, sizeof osNameFull);
 
-      if (strlen(distroShort) + 1 > outBufLen) {
+      if (strlen(distroShort) + 1 > sizeof osName) {
          Warning("%s: Error: buffer too small\n", __FUNCTION__);
 
          return FALSE;
       }
 
-      Str_Strcpy(osName, distroShort, outBufLen);
+      Str_Strcpy(osName, distroShort, sizeof osName);
    } else if (strstr(osNameFull, "FreeBSD")) {
       size_t nameLen = sizeof STR_OS_FREEBSD - 1;
       size_t releaseLen = 0;
@@ -899,13 +914,13 @@ Hostinfo_GetOSName(uint32 outBufFullLen,  // IN: length of osNameFull buffer
          releaseLen = dashPtr - buf.release;
       }
 
-      if (nameLen + releaseLen + 1 > outBufLen) {
+      if (nameLen + releaseLen + 1 > sizeof osName) {
          Warning("%s: Error: buffer too small\n", __FUNCTION__);
 
          return FALSE;
       }
 
-      Str_Strcpy(osName, STR_OS_FREEBSD, outBufLen);
+      Str_Strcpy(osName, STR_OS_FREEBSD, sizeof osName);
    } else if (strstr(osNameFull, "SunOS")) {
       size_t nameLen = sizeof STR_OS_SOLARIS - 1;
       size_t releaseLen = 0;
@@ -921,22 +936,22 @@ Hostinfo_GetOSName(uint32 outBufFullLen,  // IN: length of osNameFull buffer
          releaseLen = strlen(solarisRelease);
       }
 
-      if (nameLen + releaseLen + 1 > outBufLen) {
+      if (nameLen + releaseLen + 1 > sizeof osName) {
          Warning("%s: Error: buffer too small\n", __FUNCTION__);
 
          return FALSE;
       }
 
-      Str_Snprintf(osName, outBufLen, "%s%s", STR_OS_SOLARIS, solarisRelease);
+      Str_Snprintf(osName, sizeof osName, "%s%s", STR_OS_SOLARIS, solarisRelease);
    }
 
    if (Hostinfo_GetSystemBitness() == 64) {
-      if (strlen(osName) + sizeof STR_OS_64BIT_SUFFIX > outBufLen) {
+      if (strlen(osName) + sizeof STR_OS_64BIT_SUFFIX > sizeof osName) {
          Warning("%s: Error: buffer too small\n", __FUNCTION__);
 
          return FALSE;
       }
-      Str_Strcat(osName, STR_OS_64BIT_SUFFIX, outBufLen);
+      Str_Strcat(osName, STR_OS_64BIT_SUFFIX, sizeof osName);
    }
 
    /*
@@ -948,6 +963,22 @@ Hostinfo_GetOSName(uint32 outBufFullLen,  // IN: length of osNameFull buffer
       osNameFull[lastCharPos] = '\0';
    }
 
+   /*
+    * Serialize access. Collisions should be rare - plus the value will
+    * get cached and this won't get called anymore.
+    */
+
+   while (Atomic_ReadWrite(&mutex, 1)); // Spinlock.
+
+   if (!HostinfoOSNameCacheValid) {
+      Str_Strcpy(HostinfoCachedOSName, osName, sizeof HostinfoCachedOSName);
+      Str_Strcpy(HostinfoCachedOSFullName, osNameFull,
+                 sizeof HostinfoCachedOSFullName);
+      HostinfoOSNameCacheValid = TRUE;
+   }
+
+   Atomic_Write(&mutex, 0);  // unlock
+
    return TRUE;
 }
 
@@ -980,7 +1011,7 @@ HostinfoReadProc(const char *str)  // IN:
    uint32 count;
 
    ASSERT(!strcmp("logical", str) || !strcmp("cores", str) ||
-          !strcmp("packages", str)); 
+          !strcmp("packages", str));
 
    ASSERT(!HostType_OSIsVMK()); // Don't use /proc/vmware
 
@@ -1006,7 +1037,7 @@ HostinfoReadProc(const char *str)  // IN:
    return -1;
 }
 
- 
+
 /*
  *----------------------------------------------------------------------
  *
@@ -1161,7 +1192,7 @@ Hostinfo_NumCPUs(void)
       char *line;
 
       f = Posix_Fopen("/proc/cpuinfo", "r");
-      if (f == NULL) { 
+      if (f == NULL) {
 	 return -1;
       }
 
@@ -1360,7 +1391,7 @@ HostinfoGetLoadAverage(float *avg0,  // IN/OUT:
 
    return TRUE;
 #else
-   /* 
+   /*
     * Not implemented. This function is currently only used in the vmx, so
     * getloadavg is always available to us. If the linux tools ever need this,
     * we can go back to having a look at the output of /proc/loadavg, but
@@ -1589,12 +1620,12 @@ Hostinfo_LogMemUsage(void)
  *
  *  Hostinfo_TouchBackDoor --
  *
- *      Access the backdoor. This is used to determine if we are 
+ *      Access the backdoor. This is used to determine if we are
  *      running in a VM or on a physical host. On a physical host
  *      this should generate a GP which we catch and thereby determine
  *      that we are not in a VM. However some OSes do not handle the
  *      GP correctly and the process continues running returning garbage.
- *      In this case we check the EBX register which should be 
+ *      In this case we check the EBX register which should be
  *      BDOOR_MAGIC if the IN was handled in a VM. Based on this we
  *      return either TRUE or FALSE.
  *
@@ -1603,7 +1634,7 @@ Hostinfo_LogMemUsage(void)
  *      if not.
  *
  * Side effects:
- *	Exception if not in a VM. 
+ *	Exception if not in a VM.
  *
  *----------------------------------------------------------------------
  */
@@ -1617,7 +1648,7 @@ Hostinfo_TouchBackDoor(void)
     * it.
     */
 
-#if !defined(__APPLE__)
+#if !defined(__APPLE__) && (defined(__i386__) || defined(__x86_64__))
    uint32 eax;
    uint32 ebx;
    uint32 ecx;
@@ -1649,6 +1680,101 @@ Hostinfo_TouchBackDoor(void)
 }
 
 
+/*
+ *----------------------------------------------------------------------
+ *
+ *  Hostinfo_TouchVirtualPC --
+ *
+ *      Access MS Virtual PC's backdoor. This is used to determine if 
+ *      we are running in a MS Virtual PC or on a physical host.  Works
+ *      the same as Hostinfo_TouchBackDoor, except the entry to MS VPC
+ *      is an invalid opcode instead or writing to a port.  Since
+ *      MS VPC is 32-bit only, the 64-bit path returns FALSE.
+ *      See: http://www.codeproject.com/KB/system/VmDetect.aspx
+ *
+ * Results:
+ *      TRUE if we succesfully accessed MS Virtual PC, FALSE or 
+ *      segfault if not.
+ *
+ * Side effects:
+ *      Exception if not in a VM.
+ *
+ *----------------------------------------------------------------------
+ */
+
+Bool
+Hostinfo_TouchVirtualPC(void)
+{
+#if defined vm_x86_64
+   return FALSE;
+#else
+
+   uint32 ebxval;
+
+   __asm__ __volatile__ (
+#  if defined __PIC__        // %ebx is reserved by the compiler.
+     "xchgl %%ebx, %1" "\n\t"
+     ".long 0x0B073F0F" "\n\t"
+     "xchgl %%ebx, %1"
+     : "=&rm" (ebxval)
+     : "a" (1),
+       "0" (0)
+#  else
+     ".long 0x0B073F0F"
+     : "=b" (ebxval)
+     : "a" (1),
+       "b" (0)
+#  endif
+  );
+  return !ebxval; // %%ebx is zero if inside Virtual PC
+#endif
+}
+
+
+/*
+ *----------------------------------------------------------------------
+ *
+ *  Hostinfo_NestingSupported --
+ *
+ *      Access the backdoor with a nesting control query. This is used
+ *      to determine if we are running inside a VM that supports nesting.
+ *      This function should only be called after determining that the
+ *	backdoor is present with Hostinfo_TouchBackdoor().
+ *
+ * Results:
+ *      TRUE if the outer VM supports nesting.
+ *	FALSE otherwise.
+ *
+ * Side effects:
+ *	Exception if not in a VM, so don't do that!
+ *
+ *----------------------------------------------------------------------
+ */
+
+Bool
+Hostinfo_NestingSupported(void)
+{
+#if defined(__i386__) || defined(__x86_64__)
+   uint32 cmd = NESTING_CONTROL_QUERY << 16 | BDOOR_CMD_NESTING_CONTROL;
+   uint32 result;
+
+   __asm__ __volatile__(
+      "inl %%dx, %%eax"
+      : "=a" (result)
+      :	"0"  (BDOOR_MAGIC),
+        "c"  (cmd),
+        "d"  (BDOOR_PORT)
+   );
+
+   if (result >= NESTING_CONTROL_QUERY && result != ~0U) {
+      return TRUE;
+   }
+#endif
+
+   return FALSE;
+}
+
+
 /*
  *----------------------------------------------------------------------
  *
@@ -2141,13 +2267,13 @@ HostinfoGetCpuInfo(int nCpu,    // IN:
 
    f = Posix_Fopen("/proc/cpuinfo", "r");
 
-   if (f == NULL) { 
+   if (f == NULL) {
       Warning(LGPFX" %s: Unable to open /proc/cpuinfo\n", __FUNCTION__);
 
       return NULL;
    }
-      
-   while (cpu <= nCpu && 
+
+   while (cpu <= nCpu &&
           StdIO_ReadNextLine(f, &line, 0, NULL) == StdIO_Success) {
       char *s;
       char *e;
@@ -2161,20 +2287,20 @@ HostinfoGetCpuInfo(int nCpu,    // IN:
          for (; s < e && isspace(*s); s++);
          for (; s < e && isspace(e[-1]); e--);
          *e = 0;
-         
+
          /* Free previous value */
          free(value);
          value = strdup(s);
          ASSERT_MEM_ALLOC(value);
-         
+
          cpu++;
       }
       free(line);
-   }     
+   }
 
    fclose(f);
 
-   return value; 
+   return value;
 }
 #endif
 
@@ -2184,7 +2310,7 @@ HostinfoGetCpuInfo(int nCpu,    // IN:
  *
  * Hostinfo_GetRatedCpuMhz --
  *
- *      Get the rated CPU speed of a given processor. 
+ *      Get the rated CPU speed of a given processor.
  *      Return value is in MHz.
  *
  * Results:
@@ -2227,11 +2353,11 @@ Hostinfo_GetRatedCpuMhz(int32 cpuNumber,  // IN:
 #else
    float fMhz = 0;
    char *readVal = HostinfoGetCpuInfo(cpuNumber, "cpu MHz");
-   
+
    if (readVal == NULL) {
       return FALSE;
    }
-   
+
    if (sscanf(readVal, "%f", &fMhz) == 1) {
       *mHz = (unsigned int)(fMhz + 0.5);
    }
@@ -2297,7 +2423,7 @@ Hostinfo_GetCpuDescription(uint32 cpuNumber)  // IN:
 
       /* VMKernel treats mName as an in/out parameter so terminate it. */
       mName[0] = '\0';
-      if (VMKernel_GetCPUModelName(mName, cpuNumber,
+      if (VMKernel_GetCPUModelName(cpuNumber, mName,
                                    sizeof(mName)) == VMK_OK) {
 	 mName[sizeof(mName) - 1] = '\0';
 
@@ -3143,13 +3269,9 @@ exit:
  *
  *	Retrieve the full path to the executable. Not supported under VMvisor.
  *
- *      Note: If your process is running with elevated privileges
- *      (setuid/setgid), treat the path returned by this function as
- *      untrusted (for example, do not pass it to exec or open).
- *
- *      This function returns a path that is under the control of the
- *      user.  An attacker could manipulate the path returned by this
- *      function to elevate privileges.
+ *      The value can be controlled by the invoking user, so the calling code
+ *      should perform extra checks if it is going to use the value to
+ *      open/exec content in a security-sensitive context.
  *
  * Results:
  *      On success: The allocated, NUL-terminated file path.
