@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2007-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2007 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -41,9 +41,7 @@
 #include "util.h"
 #include "log.h"
 #include "str.h"
-#include "err.h"
 #include "vm_product.h"
-#include "vm_atomic.h"
 
 #define LOGLEVEL_MODULE main
 #include "loglevel_user.h"
@@ -248,8 +246,6 @@ ObtainHardwareID(uint64 *hardwareID) // OUT:
 #elif defined(__APPLE__)	// MacOS X
 #include <sys/socket.h>
 #include <ifaddrs.h>
-#include <net/if_dl.h>
-#include <net/ethernet.h>
 
 
 /*
@@ -329,7 +325,7 @@ ObtainHardwareID(uint64 *hardwareID)  // OUT:
       int saveErrno = errno;
 
       Warning("%s getifaddrs failure: %s.\n", __FUNCTION__,
-              Err_Errno2String(saveErrno));
+              strerror(saveErrno));
 
       return saveErrno;
    }
@@ -339,7 +335,22 @@ ObtainHardwareID(uint64 *hardwareID)  // OUT:
       p = CheckEthernet(ifp, i);
 
       if (p != NULL) {
-         memcpy(hardwareID, LLADDR((struct sockaddr_dl *)p->ifa_addr), ETHER_ADDR_LEN);
+         union bytes {
+            uint64 data;
+            char   bytes[8];
+         } x;
+
+         x.bytes[0] = p->ifa_addr->sa_data[9]  & 0xFF;	//XXX: hack!
+         x.bytes[1] = p->ifa_addr->sa_data[10] & 0xFF;	//XXX: hack!
+         x.bytes[2] = p->ifa_addr->sa_data[11] & 0xFF;	//XXX: hack!
+         x.bytes[3] = p->ifa_addr->sa_data[12] & 0xFF;	//XXX: hack!
+         x.bytes[4] = p->ifa_addr->sa_data[13] & 0xFF;	//XXX: hack!
+         x.bytes[5] = p->ifa_addr->sa_data[14] & 0xFF;	//XXX: hack!
+         x.bytes[6] = '\0';
+         x.bytes[7] = '\0';
+
+         *hardwareID = x.data;
+
          break;
       }
    }
@@ -348,14 +359,11 @@ ObtainHardwareID(uint64 *hardwareID)  // OUT:
 
    return 0;
 }
-#elif defined(linux) || defined __ANDROID__
+#elif defined(linux)		// Linux
 #include <unistd.h>
 #include <sys/ioctl.h>
 #include <net/if.h>
 #include <sys/time.h>
-#if defined __ANDROID__
-#include <sys/socket.h>  // For SOCK_DGRAM etc.
-#endif
 
 
 /*
@@ -567,20 +575,17 @@ void
 Hostinfo_MachineID(uint32 *hostNameHash,    // OUT:
                    uint64 *hostHardwareID)  // OUT:
 {
-   static Atomic_Ptr cachedHardwareID;
-   static Atomic_Ptr cachedHostNameHash;
-   uint64 *tmpHardwareID;
-   uint32 *tmpNameHash;
+   static Bool fetchValues = TRUE;
+   static uint64 cachedHardwareID;
+   static uint32 cachedHostNameHash;
 
    ASSERT(hostNameHash);
    ASSERT(hostHardwareID);
 
-   tmpNameHash = Atomic_ReadPtr(&cachedHostNameHash);
-   if (!tmpNameHash) {
+   if (fetchValues) {
+      int  erc;
       char *hostName;
 
-      tmpNameHash = Util_SafeMalloc(sizeof *tmpNameHash);
-
       // 4 bytes (32 bits) of host name information
       hostName = (char *) Hostinfo_HostName();
 
@@ -588,40 +593,24 @@ Hostinfo_MachineID(uint32 *hostNameHash,    // OUT:
          Warning("%s Hostinfo_HostName failure; providing default.\n",
                 __FUNCTION__);
 
-         *tmpNameHash = 0;
+         cachedHostNameHash = 0;
       } else {
-         *tmpNameHash = HostNameHash((unsigned char *) hostName);
+         cachedHostNameHash = HostNameHash((unsigned char *) hostName);
          free(hostName);
       }
 
-      if (Atomic_ReadIfEqualWritePtr(&cachedHostNameHash, NULL, 
-                                     tmpNameHash)) {
-         free(tmpNameHash);
-         tmpNameHash = Atomic_ReadPtr(&cachedHostNameHash);
-      }
-   }
-   *hostNameHash = *tmpNameHash;
-
-   tmpHardwareID = Atomic_ReadPtr(&cachedHardwareID);
-   if (!tmpHardwareID) {
-      int  erc;
-
-      tmpHardwareID = Util_SafeMalloc(sizeof *tmpHardwareID);
-
       // 8 bytes (64 bits) of hardware information
-      erc = ObtainHardwareID(tmpHardwareID);
+      erc = ObtainHardwareID(&cachedHardwareID);
       if (erc != 0) {
          Warning("%s ObtainHardwareID failure (%s); providing default.\n",
-                 __FUNCTION__, Err_Errno2String(erc));
+                 __FUNCTION__, strerror(erc));
 
-         *tmpHardwareID = 0;
+         cachedHardwareID = 0;
       }
 
-      if (Atomic_ReadIfEqualWritePtr(&cachedHardwareID, NULL, 
-                                     tmpHardwareID)) {
-         free(tmpHardwareID);
-         tmpHardwareID = Atomic_ReadPtr(&cachedHardwareID);
-      }
+      fetchValues = FALSE;
    }
-   *hostHardwareID = *tmpHardwareID;
+
+   *hostNameHash = cachedHostNameHash;
+   *hostHardwareID = cachedHardwareID;
 }
