@@ -39,7 +39,7 @@ Msg_Append(const char *fmt,
    Str_Vsnprintf(buf, sizeof buf, fmt, args);
    va_end(args);
 
-   Warning("Msg_Append: %s\n", buf);
+   Warning("%s [STUB]: %s\n", __FUNCTION__, buf);
 }
 
 
@@ -64,7 +64,7 @@ Msg_Question(Msg_String const *buttons,
    Str_Vsnprintf(buf, sizeof buf, fmt, args);
    va_end(args);
 
-   Warning("Msg_Question: %s\n", buf);
+   Warning("%s [STUB]: %s\n", __FUNCTION__, buf);
 
    return (unsigned int) defaultAnswer;
 }
