@@ -42,9 +42,6 @@
 #include <sys/time.h>
 #include <sys/times.h>
 #include <netdb.h>
-#if !defined(__APPLE__)
-#include <sys/timex.h>
-#endif
 #ifdef sun
 # include <sys/sockio.h>
 #endif
@@ -77,18 +74,6 @@
 #define INET_ADDRSTRLEN 16
 #endif
 
-/*
- * The interval between two ticks (in usecs) can only be altered by 10%,
- * and the default value is 10000. So the values 900000L and 1000000L
- * divided by USER_HZ, which is 100.
- */
-#ifdef __linux__
-#   define USER_HZ               100			/* from asm/param.h  */
-#   define TICK_INCR_NOMINAL    (1000000L / USER_HZ)	/* nominal tick increment */
-#   define TICK_INCR_MAX        (1100000L / USER_HZ)	/* maximum tick increment */
-#   define TICK_INCR_MIN        (900000L / USER_HZ)	/* minimum tick increment */
-#endif
-
 
 /*
  * Data types
@@ -136,7 +121,7 @@ static int SNEForEachCallback(const char *key, void *value, void *clientData);
  *          497 days. This function can detect the wrapping and still return
  *          a correct, monotonic, 64 bit wide value if it is called at least
  *          once every 497 days.
- *      
+ *
  * Result:
  *    The value on success
  *    -1 on failure (never happens in this implementation)
@@ -153,7 +138,7 @@ System_Uptime(void)
    /*
     * Dummy variable b/c times(NULL) segfaults on FreeBSD 3.2 --greg
     */
-   struct tms tp; 
+   struct tms tp;
 
 #if !defined (VM_X86_64)
    static uint64 base = 0;
@@ -178,305 +163,6 @@ System_Uptime(void)
 }
 
 
-/*
- *----------------------------------------------------------------------
- *
- * System_GetCurrentTime --
- *
- *      Get the time in seconds & microseconds since XXX from
- *      the guest OS.
- *
- * Results:
- *      TRUE/FALSE: success/failure
- *
- * Side effects:
- *	None.
- *
- *----------------------------------------------------------------------
- */
-
-Bool
-System_GetCurrentTime(int64 *secs,  // OUT
-                      int64 *usecs) // OUT
-{
-   struct timeval tv;
-
-   ASSERT(secs);
-   ASSERT(usecs);
-   
-   if (gettimeofday(&tv, NULL) < 0) {
-      return FALSE;
-   }
-
-   *secs = tv.tv_sec;
-   *usecs = tv.tv_usec;
-
-   return TRUE;
-}
-
-
-/*
- *----------------------------------------------------------------------
- *
- * System_EnableTimeSlew --
- *
- *      Slew the clock so that the time difference is covered within
- *      the timeSyncPeriod. timeSyncPeriod is the interval of the time
- *      sync loop and we intend to catch up delta us.
- *
- *      timeSyncPeriod is ignored on FreeBSD and Solaris.
- *
- * Results:
- *      TRUE/FALSE: success/failure
- *
- * Side effects:
- *      This changes the tick frequency and hence needs to be reset
- *      after the time sync is achieved.
- *
- *----------------------------------------------------------------------
- */
-
-Bool
-System_EnableTimeSlew(int64 delta,            // IN: Time difference in us
-                      int64 timeSyncPeriod)   // IN: Time interval in us
-{
-#if defined(__FreeBSD__) || defined(sun)
-
-   struct timeval tx;
-   struct timeval oldTx;
-   int error;
-
-   tx.tv_sec = delta / 1000000L;
-   tx.tv_usec = delta % 1000000L;
-
-   error = adjtime(&tx, &oldTx);
-   if (error) {
-      Log("%s: adjtime failed\n", __FUNCTION__);
-      return FALSE;
-   }
-   Log("%s: time slew start.\n", __FUNCTION__);
-   return TRUE;
-
-#elif defined(__linux__) /* For Linux. */
-
-   struct timex tx;
-   int error;
-   int64 tick;
-
-   ASSERT(timeSyncPeriod > 0);
-
-   /*
-    * Set the tick so that delta time is corrected in timeSyncPeriod period.
-    * tick is the number of microseconds added per clock tick. We adjust this
-    * so that we get the desired delta + the timeSyncPeriod in timeSyncPeriod
-    * interval.
-    */
-   tx.modes = ADJ_TICK;
-   tick = (timeSyncPeriod + delta) /
-          ((timeSyncPeriod / 1000000) * USER_HZ);
-   if (tick > TICK_INCR_MAX) {
-      tick = TICK_INCR_MAX;
-   } else if (tick < TICK_INCR_MIN) {
-      tick = TICK_INCR_MIN;
-   }
-   tx.tick = tick;
-
-   error = adjtimex(&tx);
-   if (error == -1) {
-      Log("%s: adjtimex failed: %d %s\n", __FUNCTION__, error, strerror(errno));
-         return FALSE;
-   }
-   Log("%s: time slew start: %ld\n", __FUNCTION__, tx.tick);
-   return TRUE;
-
-#else /* Apple */
-
-   return FALSE;
-
-#endif
-}
-
-
-/*
- *----------------------------------------------------------------------
- *
- * System_DisableTimeSlew --
- *
- *      Disable time slewing, setting the tick frequency to default.
- *
- * Results:
- *      TRUE/FALSE: success/failure
- *
- * Side effects:
- *      If failed to disable the tick frequency, system time will
- *      not reflect the actual time - will be behind.
- *
- *----------------------------------------------------------------------
- */
-
-Bool
-System_DisableTimeSlew(void)
-{
-#if defined(__FreeBSD__) || defined(sun)
-
-   struct timeval tx = {0};
-   int error;
-
-   error = adjtime(&tx, NULL);
-   if (error) {
-      Log("%s: adjtime failed\n", __FUNCTION__);
-      return FALSE;
-   }
-   return TRUE;
-
-#elif defined(__linux__) /* For Linux. */
-
-   struct timex tx;
-   int error;
-
-   tx.modes = ADJ_TICK;
-   tx.tick = TICK_INCR_NOMINAL;
-
-   error = adjtimex(&tx);
-   if (error == -1) {
-      Log("%s: adjtimex failed: %d %s\n", __FUNCTION__, error,
-            strerror(errno));
-      return FALSE;
-   }
-   Log("%s: time slew end - %d\n", __FUNCTION__, error);
-   return TRUE;
-
-#else /* Apple */
-   return TRUE;
-
-#endif
-}
-
-
-/*
- *----------------------------------------------------------------------
- *
- * System_IsTimeSlewEnabled --
- *
- *      Returns TRUE if time slewing has been enabled.
- *
- * Results:
- *      TRUE/FALSE: enabled/disabled
- *
- * Side effects:
- *      None.
- *
- *----------------------------------------------------------------------
- */
-
-Bool
-System_IsTimeSlewEnabled(void)
-{
-#if defined(__FreeBSD__) || defined(sun)
-
-   struct timeval oldTx;
-   int error;
-
-   /* 
-    * Solaris needs first argument non-NULL and zero
-    * to get the old timeval value.
-    */
-#if defined(sun)
-   struct timeval tx = {0};
-   error = adjtime(&tx, &oldTx);
-#else
-   error = adjtime(NULL, &oldTx);
-#endif
-   if (error) {
-      Log("%s: adjtime failed: %s.\n", __FUNCTION__, strerror(errno));
-      return FALSE;
-   }
-   return ((oldTx.tv_sec || oldTx.tv_usec) ? TRUE : FALSE);
-
-#elif defined(__linux__) /* For Linux. */
-
-   struct timex tx = {0};
-   int error;
-
-   error = adjtimex(&tx);
-   if (error == -1) {
-      Log("%s: adjtimex failed: %d %s\n", __FUNCTION__, error,
-            strerror(errno));
-      return FALSE;
-   }
-   return ((tx.tick == TICK_INCR_NOMINAL) ? FALSE : TRUE);
-
-#else /* Apple */
-
-   return FALSE;
-
-#endif
-}
-
-
-/*
- *----------------------------------------------------------------------
- *
- * System_AddToCurrentTime --
- *
- *      Adjust the current system time by adding the given number of
- *      seconds & milliseconds.
- *
- * Results:
- *      TRUE/FALSE: success/failure
- *
- * Side effects:
- *      This function disables any time slewing to correctly set the guest
- *      time.
- *
- *----------------------------------------------------------------------
- */
-
-Bool
-System_AddToCurrentTime(int64 deltaSecs,  // IN
-                        int64 deltaUsecs) // IN
-{
-   struct timeval tv;
-   int64 newTime;
-   int64 secs;
-   int64 usecs;
-   
-   if (!System_GetCurrentTime(&secs, &usecs)) {
-      return FALSE;
-   }
-   
-   if (System_IsTimeSlewEnabled()) {
-      System_DisableTimeSlew();
-   }
-
-   newTime = (secs + deltaSecs) * 1000000L + (usecs + deltaUsecs);
-   ASSERT(newTime > 0);
-   
-   /*
-    * timeval.tv_sec is a 32-bit signed integer. So, Linux will treat
-    * newTime as a time before the epoch if newTime is a time 68 years 
-    * after the epoch (beacuse of overflow). 
-    *
-    * If it is a 64-bit linux, everything should be fine. 
-    */
-   if (sizeof tv.tv_sec < 8 && newTime / 1000000L > MAX_INT32) {
-      Log("System_AddToCurrentTime() overflow: deltaSecs=%"FMT64"d, secs=%"FMT64"d\n",
-          deltaSecs, secs);
-
-      return FALSE;
-   }
- 
-   tv.tv_sec = newTime / 1000000L;
-   tv.tv_usec = newTime % 1000000L;
-
-   if (settimeofday(&tv, NULL) < 0) {
-      return FALSE;
-   }
-   
-   return TRUE;
-}
-
-
 /*
  *-----------------------------------------------------------------------------
  *
@@ -527,7 +213,7 @@ System_GetTimeAsString(void)
    do {
       char *newBuf;
       bufSize *= 2;
-      
+
       newBuf = realloc(buf, bufSize);
       if (newBuf == NULL) {
          goto out;
@@ -562,7 +248,7 @@ System_GetTimeAsString(void)
  *
  * Results:
  *    TRUE if this is an ACPI system.
- *    FALSE if this is not an ACPI system.   
+ *    FALSE if this is not an ACPI system.
  *
  * Side effects:
  *	None.
@@ -581,14 +267,14 @@ System_IsACPI(void)
 
 /*
  *-----------------------------------------------------------------------------
- *  
- * System_Shutdown -- 
+ *
+ * System_Shutdown --
  *
  *   Initiate system shutdown.
- * 
- * Return value: 
+ *
+ * Return value:
  *    None.
- * 
+ *
  * Side effects:
  *    None.
  *
@@ -624,17 +310,17 @@ System_Shutdown(Bool reboot)  // IN: "reboot or shutdown" flag
 
 /*
  *-----------------------------------------------------------------------------
- *  
- * System_IsUserAdmin -- 
+ *
+ * System_IsUserAdmin --
  *
  *    On Windows this functions checks if the calling user has membership in
  *    the Administrators group (for NT platforms). On POSIX machines, we simply
  *    check if the user's effective UID is root.
- * 
- * Return value: 
+ *
+ * Return value:
  *    TRUE if the user has an effective UID of root.
  *    FALSE if not.
- * 
+ *
  * Side effects:
  *    None.
  *
@@ -668,7 +354,7 @@ System_GetEnv(Bool global,           // IN
               const char *valueName) // IN: UTF-8
 {
    char *result;
-   
+
 #if defined(sun)
    result = NULL;
 #else
@@ -720,7 +406,7 @@ System_SetEnv(Bool global,      // IN
  *
  * System_UnsetEnv --
  *
- *    Unset environment variable. 
+ *    Unset environment variable.
  *
  * Results:
  *    0 if success, -1 otherwise.
@@ -748,7 +434,7 @@ System_UnsetEnv(const char *valueName) // IN: UTF-8
  *
  * System_SetLDPath --
  *
- *    Set LD_LIBRARY_PATH. If native is TRUE, use VMWARE_LD_LIBRARY_PATH 
+ *    Set LD_LIBRARY_PATH. If native is TRUE, use VMWARE_LD_LIBRARY_PATH
  *    as the value (and ignore the path argument, which should be set to
  *    NULL in this case). If native is FALSE, use the passed in path (and
  *    if that path is NULL, unsetenv the value).
@@ -758,7 +444,7 @@ System_UnsetEnv(const char *valueName) // IN: UTF-8
  *    responsible for calling free() on this pointer.
  *
  * Side effects:
- *    Manipulates the value of LD_LIBRARY_PATH variable. 
+ *    Manipulates the value of LD_LIBRARY_PATH variable.
  *
  *----------------------------------------------------------------------
  */
@@ -812,7 +498,7 @@ System_SetLDPath(const char *path,      // IN: UTF-8
       free(p);
    } else if (path) {
       /*
-       * Set LD_LIBRARY_PATH to the specified value. 
+       * Set LD_LIBRARY_PATH to the specified value.
        */
       System_SetEnv(TRUE, "LD_LIBRARY_PATH", (char *) path);
    } else {
@@ -840,7 +526,7 @@ System_SetLDPath(const char *path,      // IN: UTF-8
  *      whether the value was set in the native environment.  Based on this:
  *        VMWARE_FOO="1foo"               -> FOO="foo"
  *        VMWARE_FOO="1"                  -> FOO=""
- *        VMWARE_FOO="0 VMWARE_UNDEFINED" -> FOO is unset in the native environment
+ *        VMWARE_FOO="0"                  -> FOO is unset in the native environment
  *
  *      Variables without the VMWARE_ prefix are just copied over to the new
  *      environment.  Note, of course, that VMWARE_-prefixed variables take
@@ -977,7 +663,7 @@ SNEBuildHash(const char **compatEnviron)
           * XXX Should we move this marker to a separate header?
           */
          char *realKey = &key[prefixLength];
-         char *realValue = (strcmp(value, "0 VMWARE_UNDEFINED") == 0)
+         char *realValue = (value[0] == '0')
                            ? NULL
                            : Util_SafeStrdup(&value[1]);
          HashTable_ReplaceOrInsert(environTable, realKey, realValue);
