@@ -263,6 +263,13 @@ Unity_Init(GuestApp_Dict *conf,                                    // IN
            int *blockedWnd,                                        // IN
            DesktopSwitchCallbackManager *desktopSwitchCallbackMgr) // IN
 {
+   /*
+    * If no preferred color is in the config file then use a light gray tone,
+    * the value is stored as xBGR.
+    */
+   int desktopColor =  /* red */ 0xdc |
+                       /* green */ 0xdc << 8 |
+                       /* blue */ 0xdc << 16;
    Debug("Unity_Init\n");
 
    /*
@@ -312,6 +319,8 @@ Unity_Init(GuestApp_Dict *conf,                                    // IN
    unity.forceEnable = GuestApp_GetDictEntryBool(conf, "unity.forceEnable");
    unity.isEnabled = FALSE;
 
+   GuestApp_GetDictEntryInt(conf, "unity.desktop.backgroundColor", &desktopColor);
+   UnityPlatformSetConfigDesktopColor(unity.up, desktopColor);
    unity.virtDesktopArray.desktopCount = 0;
 }
 
@@ -901,6 +910,12 @@ UnityTcloSetDesktopWorkArea(char const **result,  // IN
                           FALSE);
          goto out;
       }
+
+      if (workAreas[i].x < 0 || workAreas[i].y < 0 ||
+          workAreas[i].width <= 0 || workAreas[i].height <= 0) {
+         RpcIn_SetRetVals(result, resultLen, "Invalid argument", FALSE);
+         goto out;
+      }
    }
 
    if (!UnityPlatformSetDesktopWorkAreas(unity.up, workAreas, count)) {
