@@ -54,6 +54,9 @@ typedef struct _UnityPlatform UnityPlatform;
  * Implemented by unityPlatform[Win32|X11|Cocoa (ha!)].c
  */
 
+#ifdef __cplusplus
+extern "C" {
+#endif // __cplusplus
 Bool UnityPlatformIsSupported(void);
 UnityPlatform *UnityPlatformInit(UnityWindowTracker *tracker,
                                  UnityUpdateChannel *updateChannel,
@@ -128,10 +131,16 @@ void UnityPlatformSetActiveDnDDetWnd(UnityPlatform *up, UnityDnD *detWnd);
 
 void UnityPlatformDoUpdate(UnityPlatform *up, Bool incremental);
 
+void UnityPlatformSetConfigDesktopColor(UnityPlatform *up, int desktopColor);
+
 /* Functions implemented in unity.c for use by the platform-specific code. */
 void UnityGetUpdateCommon(int flags, DynBuf *buf);
 Bool UnityUpdateChannelInit(UnityUpdateChannel *updateChannel);
 void UnityUpdateChannelCleanup(UnityUpdateChannel *updateChannel);
 Bool UnitySendUpdates(UnityUpdateChannel *updateChannel);
 
+#ifdef __cplusplus
+};
+#endif // __cplusplus
+
 #endif
