@@ -26,8 +26,8 @@
  * Compile-Time Options
  */
 
-#define	OS_DISABLE_UNLOAD	(0)
-#define	OS_DEBUG		(1)
+#define	OS_DISABLE_UNLOAD   0
+#define	OS_DEBUG            1
 
 /*
  * Includes
@@ -54,10 +54,7 @@
 #include <machine/stdarg.h>
 
 #include "os.h"
-
-/*
- * Constants
- */
+#include "vmballoon.h"
 
 /*
  * Types
@@ -128,7 +125,7 @@ static void vmmemctl_deinit_sysctl(void);
 void *
 OS_Malloc(size_t size) // IN
 {
-   return(malloc(size, M_VMMEMCTL, M_NOWAIT));
+   return malloc(size, M_VMMEMCTL, M_NOWAIT);
 }
 
 
@@ -252,39 +249,84 @@ OS_Snprintf(char *buf,          // OUT
    return result;
 }
 
+
 /*
- * System-Dependent Operations
+ *-----------------------------------------------------------------------------
+ *
+ * OS_Identity --
+ *
+ *      Returns an identifier for the guest OS family.
+ *
+ * Results:
+ *      The identifier
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
  */
 
-const char *
+BalloonGuest
 OS_Identity(void)
 {
-   return("bsd");
+   return BALLOON_GUEST_BSD;
 }
 
+
 /*
- * Predict the maximum achievable balloon size.
+ *-----------------------------------------------------------------------------
  *
- * Currently we just return the total memory pages.
+ * OS_ReservedPageGetLimit --
+ *
+ *      Predict the maximum achievable balloon size.
+ *
+ * Results:
+ *      Total memory pages.
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
  */
-unsigned int
-OS_PredictMaxReservedPages(void)
-{
-   return(cnt.v_page_count);
-}
 
 unsigned long
-OS_AddrToPPN(unsigned long addr)
+OS_ReservedPageGetLimit(void)
 {
-   return (((vm_page_t)addr)->phys_addr) >> PAGE_SHIFT;
+   return cnt.v_page_count;
 }
 
-static void os_pmap_alloc(os_pmap *p)
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * OS_ReservedPageGetPPN --
+ *
+ *      Convert a page handle (of a physical page previously reserved with
+ *      OS_ReservedPageAlloc()) to a ppn.
+ *
+ * Results:
+ *      The ppn.
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+unsigned long
+OS_ReservedPageGetPPN(PageHandle handle) // IN: A valid page handle
+{
+   return (((vm_page_t)handle)->phys_addr) >> PAGE_SHIFT;
+}
+
+
+static void
+os_pmap_alloc(os_pmap *p) // IN
 {
    /* number of pages (div. 8) */
    p->size = (cnt.v_page_count + 7) / 8;
 
-   /* 
+   /*
     * expand to nearest word boundary 
     * XXX: bitmap can be greater than total number of pages in system 
     */
@@ -294,17 +336,21 @@ static void os_pmap_alloc(os_pmap *p)
    p->bitmap = (unsigned long *)kmem_alloc(kernel_map, p->size);
 }
 
-static void os_pmap_free(os_pmap *p)
+
+static void
+os_pmap_free(os_pmap *p) // IN
 {
    kmem_free(kernel_map, (vm_offset_t)p->bitmap, p->size);
    p->size = 0;
    p->bitmap = NULL;
 }
 
-static void os_pmap_init(os_pmap *p)
+
+static void
+os_pmap_init(os_pmap *p) // IN
 {
    /* alloc bitmap for pages in system */
-   os_pmap_alloc(p); 
+   os_pmap_alloc(p);
    if (!p->bitmap) {
       p->size = 0;
       p->bitmap = NULL;
@@ -316,7 +362,9 @@ static void os_pmap_init(os_pmap *p)
    p->hint = 0;
 }
 
-static vm_pindex_t os_pmap_getindex(os_pmap *p)
+
+static vm_pindex_t
+os_pmap_getindex(os_pmap *p) // IN
 {
    int i;
    unsigned long bitidx, wordidx;
@@ -348,14 +396,19 @@ static vm_pindex_t os_pmap_getindex(os_pmap *p)
    return (vm_pindex_t)-1;
 }
 
-static void os_pmap_putindex(os_pmap *p, vm_pindex_t pindex)
+
+static void
+os_pmap_putindex(os_pmap *p,         // IN
+                 vm_pindex_t pindex) // IN
 {
    /* unset bit */
-   p->bitmap[pindex / (8*sizeof(unsigned long))] &= 
+   p->bitmap[pindex / (8*sizeof(unsigned long))] &=
                              ~(1<<(pindex % (8*sizeof(unsigned long))));
 }
 
-static void os_kmem_free(vm_page_t page)
+
+static void
+os_kmem_free(vm_page_t page) // IN
 {
    os_state *state = &global_state;
    os_pmap *pmap = &state->pmap;
@@ -368,7 +421,9 @@ static void os_kmem_free(vm_page_t page)
    vm_page_free(page);
 }
 
-static vm_page_t os_kmem_alloc(int alloc_normal_failed)
+
+static vm_page_t
+os_kmem_alloc(int alloc_normal_failed) // IN
 {
    vm_page_t page;
    vm_pindex_t pindex;
@@ -401,30 +456,79 @@ static vm_page_t os_kmem_alloc(int alloc_normal_failed)
    return page;
 }
 
-static void os_balloonobject_delete(void)
+
+static void
+os_balloonobject_delete(void)
 {
    vm_object_deallocate(global_state.vmobject);
 }
 
-static void os_balloonobject_create(void)
+
+static void
+os_balloonobject_create(void)
 {
    global_state.vmobject = vm_object_allocate(OBJT_DEFAULT,
                   OFF_TO_IDX(VM_MAX_KERNEL_ADDRESS - VM_MIN_KERNEL_ADDRESS));
 }
 
-unsigned long
-OS_AllocReservedPage(int canSleep)
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * OS_ReservedPageAlloc --
+ *
+ *      Reserve a physical page for the exclusive use of this driver.
+ *
+ * Results:
+ *      On success: A valid page handle that can be passed to OS_ReservedPageGetPPN()
+ *                  or OS_ReservedPageFree().
+ *      On failure: PAGE_HANDLE_INVALID
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+PageHandle
+OS_ReservedPageAlloc(int canSleep) // IN
 {
-   return (unsigned long)os_kmem_alloc(canSleep);
+   vm_page_t page;
+
+   page = os_kmem_alloc(canSleep);
+   if (page == NULL) {
+      return PAGE_HANDLE_INVALID;
+   }
+
+   return (PageHandle)page;
 }
 
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * OS_ReservedPageFree --
+ *
+ *      Unreserve a physical page previously reserved with OS_ReservedPageAlloc().
+ *
+ * Results:
+ *      None.
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
 void
-OS_FreeReservedPage(unsigned long page)
+OS_ReservedPageFree(PageHandle handle) // IN: A valid page handle
 {
-   os_kmem_free((vm_page_t)page);
+   os_kmem_free((vm_page_t)handle);
 }
 
-static void os_timer_internal(void *data)
+
+static void
+os_timer_internal(void *data) // IN
 {
    os_timer *t = (os_timer *) data;
 
@@ -435,32 +539,61 @@ static void os_timer_internal(void *data)
    }
 }
 
-void
-OS_TimerInit(OSTimerHandler *handler, // IN
-             void *clientData,        // IN
-             int period)              // IN
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * OS_TimerStart --
+ *
+ *      Setup the timer callback function, then start it.
+ *
+ * Results:
+ *      Always TRUE, cannot fail.
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+Bool
+OS_TimerStart(OSTimerHandler *handler, // IN
+              void *clientData)        // IN
 {
    os_timer *t = &global_state.timer;
 
+   /* setup the timer structure */
    callout_handle_init(&t->callout_handle);
    t->handler = handler;
    t->data = clientData;
-   t->period = period;
-   t->stop = 0;
-}
-
-void
-OS_TimerStart(void)
-{
-   os_timer *t = &global_state.timer;
+   t->period = hz;
 
    /* clear termination flag */
    t->stop = 0;
 
    /* scheduler timer handler */
    t->callout_handle = timeout(os_timer_internal, t, t->period);
+
+   return TRUE;
 }
 
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * OS_TimerStop --
+ *
+ *      Stop the timer.
+ *
+ * Results:
+ *      None
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
 void
 OS_TimerStop(void)
 {
@@ -473,12 +606,6 @@ OS_TimerStop(void)
    untimeout(os_timer_internal, t, t->callout_handle);
 }
 
-unsigned int
-OS_TimerHz(void)
-{
-   return hz;
-}
-
 
 /*
  *-----------------------------------------------------------------------------
@@ -502,10 +629,28 @@ OS_Yield(void)
    /* Do nothing. */
 }
 
-void
-OS_Init(const char *name,
-        const char *name_verbose,
-        OSStatusHandler *handler)
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * OS_Init --
+ *
+ *      Called at driver startup, initializes the balloon state and structures.
+ *
+ * Results:
+ *      On success: TRUE
+ *      On failure: FALSE
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+Bool
+OS_Init(const char *name,         // IN
+        const char *nameVerbose,  // IN
+        OSStatusHandler *handler) // IN
 {
    os_state *state = &global_state;
    os_pmap *pmap = &state->pmap;
@@ -513,7 +658,7 @@ OS_Init(const char *name,
 
    /* initialize only once */
    if (initialized++) {
-      return;
+      return FALSE;
    }
 
    /* zero global state */
@@ -525,7 +670,7 @@ OS_Init(const char *name,
    /* initialize status state */
    state->status.handler = handler;
    state->status.name = name;
-   state->status.name_verbose = name_verbose;
+   state->status.name_verbose = nameVerbose;
 
    os_pmap_init(pmap);
    os_balloonobject_create();
@@ -534,8 +679,26 @@ OS_Init(const char *name,
 
    /* log device load */
    printf("%s initialized\n", state->status.name_verbose);
+   return TRUE;
 }
 
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * OS_Cleanup --
+ *
+ *      Called when the driver is terminating, cleanup initialized structures.
+ *
+ * Results:
+ *      None
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
 void
 OS_Cleanup(void)
 {
@@ -552,28 +715,32 @@ OS_Cleanup(void)
    printf("%s unloaded\n", status->name_verbose);
 }
 
+
 /*
  * Module Load/Unload Operations
  */
 
-extern int  init_module(void);
-extern void cleanup_module(void);
 
-static int vmmemctl_load(module_t mod, int cmd, void *arg)
+static int
+vmmemctl_load(module_t mod, // IN: Unused
+              int cmd,      // IN
+              void *arg)    // IN: Unused
 {
    int err = 0;
 
    switch (cmd) {
    case MOD_LOAD:
-      (void) init_module();
+      if (Balloon_ModuleInit() != BALLOON_SUCCESS) {
+         err = EAGAIN;
+      }
       break;
 
     case MOD_UNLOAD:
        if (OS_DISABLE_UNLOAD) {
-          /* prevent moudle unload */
+          /* prevent module unload */
           err = EBUSY;
        } else {
-          cleanup_module();
+          Balloon_ModuleCleanup();
        }
        break;
 
@@ -582,7 +749,7 @@ static int vmmemctl_load(module_t mod, int cmd, void *arg)
       break;
    }
 
-   return(err);
+   return err;
 }
 
 /* All these interfaces got added in 4.x, so we support 5.0 and above with them */
