@@ -35,9 +35,5 @@
 #define current_fsgid() (current->fsgid)
 #endif
 
-#if !defined(cap_set_full)
-/* cap_set_full was removed in kernel version 3.0-rc4. */
-#define cap_set_full(_c) do { (_c) = CAP_FULL_SET; } while (0)
-#endif
 
 #endif /* __COMPAT_CRED_H__ */
