@@ -20,7 +20,7 @@
 #define _VMCI_DEF_H_
 
 #define INCLUDE_ALLOW_USERLEVEL
-#define INCLUDE_ALLOW_VMMEXT
+
 #define INCLUDE_ALLOW_MODULE
 #define INCLUDE_ALLOW_VMMON
 #define INCLUDE_ALLOW_VMCORE
@@ -320,7 +320,7 @@ typedef struct VMCIDsRequestHeader {
    int32       msgid;
    VMCIHandle  handle;
    int32       nameLen;
-   int8        name[1];   
+   char        name[1];
 } VMCIDsRequestHeader;
 
 
