@@ -151,6 +151,7 @@ typedef int (*VMCIEventReleaseCB)(void *clientData);
 #else
   typedef unsigned long VMCILockRank;
 
+  #define VMCI_LOCK_RANK_HIGHER_BH      0x8000
   #define VMCI_LOCK_RANK_HIGH_BH        0x4000
   #define VMCI_LOCK_RANK_MIDDLE_BH      0x2000
   #define VMCI_LOCK_RANK_LOW_BH         0x1000
@@ -187,7 +188,10 @@ typedef void * VMCIBuffer;
 
 typedef struct VMCIHost {
 #if defined(VMKERNEL)
-   World_ID vmmWorldID;
+   World_ID vmmWorldID[2];   /*
+                              * First one is the active one and the second
+                              * one is shadow world during FSR.
+                              */
 #elif defined(linux)
    wait_queue_head_t  waitQueue;
 #elif defined(__APPLE__)
@@ -222,6 +226,10 @@ Bool VMCIHost_WaitForCallLocked(VMCIHost *hostContext,
                                 Bool useBH);
 #ifdef VMKERNEL
 int VMCIHost_ContextToHostVmID(VMCIHost *hostContext, VMCIHostVmID *hostVmID);
+void VMCIHost_SetActiveHnd(VMCIHost *hostContext, uintptr_t eventHnd);
+Bool VMCIHost_RemoveHnd(VMCIHost *hostContext, uintptr_t eventHnd);
+Bool VMCIHost_IsActiveHnd(VMCIHost *hostContext, uintptr_t eventHnd);
+uint32 VMCIHost_NumHnds(VMCIHost *hostContext);
 #endif
 
 void *VMCI_AllocKernelMem(size_t size, int flags);
@@ -258,6 +266,16 @@ Bool VMCI_WaitOnEventInterruptible(VMCIEvent *event,
 int VMCI_CopyFromUser(void *dst, VA64 src, size_t len);
 #endif
 
+#if defined(_WIN32)
+void VMCI_InitHelperQueue(void);
+void VMCI_ExitHelperQueue(void);
+#endif // _WIN32
+
+typedef void (VMCIWorkFn)(void *data);
+Bool VMCI_CanScheduleDelayedWork(void);
+int VMCI_ScheduleDelayedWork(VMCIWorkFn  *workFn,
+                             void *data);
+
 int VMCIMutex_Init(VMCIMutex *mutex);
 void VMCIMutex_Destroy(VMCIMutex *mutex);
 void VMCIMutex_Acquire(VMCIMutex *mutex);
@@ -289,15 +307,25 @@ int VMCI_PopulatePPNList(uint8 *callBuf, const PPNSet *ppnSet);
 struct PageStoreAttachInfo;
 struct VMCIQueue;
 
-int VMCIHost_GetUserMemory(struct PageStoreAttachInfo *attach);
-void VMCIHost_ReleaseUserMemory(struct PageStoreAttachInfo *attach);
-int VMCIHost_FinishAttach(struct PageStoreAttachInfo *attach,
-                          struct VMCIQueue *produceQ,
-			  struct VMCIQueue *detachQ);
-void VMCIHost_DetachMappings(struct PageStoreAttachInfo *attach,
-                             struct VMCIQueue *produceQ,
-                             struct VMCIQueue *detachQ);
-#endif
+int VMCIHost_GetUserMemory(struct PageStoreAttachInfo *attach,
+                           struct VMCIQueue *produceQ,
+                           struct VMCIQueue *detachQ);
+void VMCIHost_ReleaseUserMemory(struct PageStoreAttachInfo *attach,
+                                struct VMCIQueue *produceQ,
+                                struct VMCIQueue *detachQ);
+
+#ifdef _WIN32
+/*
+ * Special routine used on the Windows platform to save a queue when
+ * its backing memory goes away.
+ */
+
+void VMCIHost_SaveProduceQ(struct PageStoreAttachInfo *attach,
+                           struct VMCIQueue *produceQ,
+                           struct VMCIQueue *detachQ,
+                           const uint64 produceQSize);
+#endif // _WIN32
+#endif // !VMX86_TOOLS && !VMKERNEL
 
 
 #endif // _VMCI_KERNEL_IF_H_
