@@ -16,7 +16,7 @@
  *
  *********************************************************/
 
-/* 
+/*
  * vmciEvent.h --
  *
  *      Event code for the vmci guest driver
@@ -33,7 +33,11 @@
 
 #include "vmci_defs.h"
 #include "vmci_call_defs.h"
+#ifdef VMX86_TOOLS
 #include "vmciGuestKernelAPI.h"
+#else
+#include "vmciHostKernelAPI.h"
+#endif
 
 void VMCIEvent_Init(void);
 void VMCIEvent_Exit(void);
@@ -42,14 +46,12 @@ int  VMCIEvent_Dispatch(VMCIDatagram *msg);
 Bool VMCIEvent_CheckHostCapabilities(void);
 #endif
 
-
 /*
- * Non-public VMCI Event API for guest kernel.
+ * Non-public VMCI Event API for the kernel.
  */
 
-int VMCIEventSubscribe(VMCI_Event event, VMCI_EventCB callback,
+int VMCIEventSubscribe(VMCI_Event event, uint32 flags, VMCI_EventCB callback,
                         void *callbackData, VMCIId *subID);
 int VMCIEventUnsubscribe(VMCIId subID);
 
-
 #endif //__VMCI_EVENT_H__
