@@ -34,6 +34,7 @@
 #include "compat_ioport.h"
 #include "compat_interrupt.h"
 #include "compat_page.h"
+#include "compat_mutex.h"
 #include "vm_basic_types.h"
 #include "vm_device_version.h"
 #include "kernelStubs.h"
@@ -53,7 +54,7 @@
 #define VMCI_DEVICE_MINOR_NUM 0
 
 typedef struct vmci_device {
-   struct semaphore lock;
+   compat_mutex_t lock;
 
    unsigned int ioaddr;
    unsigned int ioaddr_size;
@@ -148,7 +149,7 @@ vmci_init(void)
    printk("VMCI: Major device number is: %d\n", device_major_nr);
 
    /* Initialize device data. */
-   init_MUTEX(&vmci_dev.lock);
+   compat_mutex_init(&vmci_dev.lock);
    spin_lock_init(&vmci_dev.dev_spinlock);
    vmci_dev.enabled = FALSE;
 
@@ -269,7 +270,7 @@ vmci_probe_device(struct pci_dev *pdev,           // IN: vmci PCI device
    outl(VMCI_CAPS_DATAGRAM, ioaddr + VMCI_CAPS_ADDR);
 
    /* Device struct initialization. */
-   down(&vmci_dev.lock);
+   compat_mutex_lock(&vmci_dev.lock);
    if (vmci_dev.enabled) {
       printk(KERN_ERR "VMCI device already enabled.\n");
       goto unlock;
@@ -312,7 +313,7 @@ vmci_probe_device(struct pci_dev *pdev,           // IN: vmci PCI device
 
    printk(KERN_INFO "Registered vmci device.\n");
 
-   up(&vmci_dev.lock);
+   compat_mutex_unlock(&vmci_dev.lock);
 
    /* Enable specific interrupt bits. */
    outl(VMCI_IMR_DATAGRAM, vmci_dev.ioaddr + VMCI_IMR_ADDR);
@@ -328,7 +329,7 @@ vmci_probe_device(struct pci_dev *pdev,           // IN: vmci PCI device
    VMCIEvent_Exit();
    VMCIProcess_Exit();
  unlock:
-   up(&vmci_dev.lock);
+   compat_mutex_unlock(&vmci_dev.lock);
  release:
    release_region(ioaddr, ioaddr_size);
  pci_disable:
@@ -368,7 +369,7 @@ vmci_remove_device(struct pci_dev* pdev)
    //VMCIDatagram_Exit();
    VMCIProcess_Exit();
 
-   down(&dev->lock);
+   compat_mutex_lock(&dev->lock);
    printk(KERN_INFO "Resetting vmci device\n");
    outl(VMCI_CONTROL_RESET, vmci_dev.ioaddr + VMCI_CONTROL_ADDR);
    free_irq(dev->irq, dev);
@@ -376,7 +377,7 @@ vmci_remove_device(struct pci_dev* pdev)
    dev->enabled = FALSE;
 
    printk(KERN_INFO "Unregistered vmci device.\n");
-   up(&dev->lock);
+   compat_mutex_unlock(&dev->lock);
 
    compat_pci_disable_device(pdev);
 }
@@ -411,7 +412,7 @@ vmci_open(struct inode *inode,  // IN
       return -ENODEV;
    }
 
-   down(&vmci_dev.lock);
+   compat_mutex_lock(&vmci_dev.lock);
    if (!vmci_dev.enabled) {
       printk(KERN_INFO "Received open on uninitialized vmci device.\n");
       errcode = -ENODEV;
@@ -429,12 +430,12 @@ vmci_open(struct inode *inode,  // IN
    devHndl->objType = VMCIOBJ_NOT_SET;
    file->private_data = devHndl;
 
-   up(&vmci_dev.lock);
+   compat_mutex_unlock(&vmci_dev.lock);
 
    return 0;
 
  unlock:
-   up(&vmci_dev.lock);
+   compat_mutex_unlock(&vmci_dev.lock);
    return errcode;
 }
 
@@ -527,7 +528,7 @@ vmci_ioctl(struct inode *inode,  // IN
    }
 
    case IOCTL_VMCI_CREATE_DATAGRAM_PROCESS: {
-      VMCIDatagramCreateInfo createInfo;
+      VMCIDatagramCreateProcessInfo createInfo;
       VMCIDatagramProcess *dgmProc;
 
       if (devHndl->objType != VMCIOBJ_NOT_SET) {
@@ -795,9 +796,9 @@ VMCI_DeviceEnabled(void)
 {
    Bool retval;
 
-   down(&vmci_dev.lock);
+   compat_mutex_lock(&vmci_dev.lock);
    retval = vmci_dev.enabled;
-   up(&vmci_dev.lock);
+   compat_mutex_unlock(&vmci_dev.lock);
 
    return retval;
 }
