@@ -27,8 +27,7 @@
 
 #include <linux/errno.h>
 #include <linux/pagemap.h>
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 0) && \
-    LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 27)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 27)
 #include <linux/namei.h>
 #endif
 
@@ -51,26 +50,6 @@
 #include "fsutil.h"
 #include "vm_assert.h"
 
-/*
- * The inode_operations structure changed in 2.5.18:
- * before:
- * . 'getattr' was defined but unused
- * . 'revalidate' was defined and used
- * after:
- * 1) 'getattr' changed and became used
- * 2) 'revalidate' was removed
- *
- * Note: Mandrake backported 1) but not 2) starting with 2.4.8-26mdk
- *
- *   --hpreg
- */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 18)
-#   define HGFS_GETATTR_ONLY 1
-#else
-#   undef HGFS_GETATTR_ONLY
-#endif
-
-
 /* Private functions. */
 static int HgfsDelete(struct inode *dir,
                       struct dentry *dentry,
@@ -93,7 +72,6 @@ static int HgfsPackSymlinkCreateRequest(struct dentry *dentry,
                                         HgfsReq *req);
 
 /* HGFS inode operations. */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 75)
 static int HgfsCreate(struct inode *dir,
                       struct dentry *dentry,
                       int mode,
@@ -101,13 +79,6 @@ static int HgfsCreate(struct inode *dir,
 static struct dentry *HgfsLookup(struct inode *dir,
                                  struct dentry *dentry,
                                  struct nameidata *nd);
-#else
-static int HgfsCreate(struct inode *dir,
-                      struct dentry *dentry,
-                      int mode);
-static struct dentry *HgfsLookup(struct inode *dir,
-                                 struct dentry *dentry);
-#endif
 static int HgfsMkdir(struct inode *dir,
                      struct dentry *dentry,
                      int mode);
@@ -122,8 +93,7 @@ static int HgfsRename(struct inode *oldDir,
 static int HgfsSymlink(struct inode *dir,
                        struct dentry *dentry,
                        const char *symname);
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 0) && \
-    LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 27)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 27)
 static int HgfsPermission(struct inode *inode,
                           int mask,
                           struct nameidata *nameidata);
@@ -131,11 +101,9 @@ static int HgfsPermission(struct inode *inode,
 static int HgfsPermission(struct inode *inode,
                           int mask);
 #endif
-#ifdef HGFS_GETATTR_ONLY
 static int HgfsGetattr(struct vfsmount *mnt,
                        struct dentry *dentry,
                        struct kstat *stat);
-#endif
 
 #define HGFS_CREATE_DIR_MASK (HGFS_CREATE_DIR_VALID_FILE_NAME | \
                               HGFS_CREATE_DIR_VALID_SPECIAL_PERMS | \
@@ -159,13 +127,8 @@ struct inode_operations HgfsDirInodeOperations = {
    .permission  = HgfsPermission,
    .setattr     = HgfsSetattr,
 
-#ifdef HGFS_GETATTR_ONLY
    /* Optional */
    .getattr     = HgfsGetattr,
-#else
-   /* Optional */
-   .revalidate  = HgfsRevalidate,
-#endif
 };
 
 /* HGFS inode operations structure for files. */
@@ -173,13 +136,8 @@ struct inode_operations HgfsFileInodeOperations = {
    .permission  = HgfsPermission,
    .setattr     = HgfsSetattr,
 
-#ifdef HGFS_GETATTR_ONLY
    /* Optional */
    .getattr     = HgfsGetattr,
-#else
-   /* Optional */
-   .revalidate  = HgfsRevalidate,
-#endif
 };
 
 /*
@@ -986,18 +944,11 @@ HgfsTruncatePages(struct inode *inode, // IN: Inode whose page to truncate
  *----------------------------------------------------------------------
  */
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 75)
 static int
 HgfsCreate(struct inode *dir,     // IN: Parent dir to create in
            struct dentry *dentry, // IN: Dentry containing name to create
            int mode,              // IN: Mode of file to be created
 	   struct nameidata *nd)  // IN: Intent, vfsmount, ...
-#else
-static int
-HgfsCreate(struct inode *dir,     // IN: Parent dir to create in
-           struct dentry *dentry, // IN: Dentry containing name to create
-           int mode)              // IN: Mode of file to be created
-#endif
 {
    HgfsAttrInfo attr;
    int result;
@@ -1067,16 +1018,10 @@ HgfsCreate(struct inode *dir,     // IN: Parent dir to create in
  *----------------------------------------------------------------------
  */
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 75)
 static struct dentry *
 HgfsLookup(struct inode *dir,      // IN: Inode of parent directory
            struct dentry *dentry,  // IN: Dentry containing name to look up
-	   struct nameidata *nd)   // IN: Intent, vfsmount, ...
-#else
-static struct dentry *
-HgfsLookup(struct inode *dir,      // IN: Inode of parent directory
-           struct dentry *dentry)  // IN: Dentry containing name to look up
-#endif
+           struct nameidata *nd)   // IN: Intent, vfsmount, ...
 {
    HgfsAttrInfo attr;
    struct inode *inode;
@@ -1363,6 +1308,27 @@ HgfsRename(struct inode *oldDir,      // IN: Inode of original directory
       goto out;
    }
 
+   if (oldDentry->d_inode && newDentry->d_inode) {
+      HgfsInodeInfo *oldIinfo;
+      HgfsInodeInfo *newIinfo;
+      /*
+       * Don't do rename if the source and target are identical (from the
+       * viewpoint of the host). It is possible that multiple guest inodes
+       * point to the same host inode under the case that both one folder
+       * and its subfolder are mapped as hgfs sharese. Please also see the
+       * comments at fsutil.c/HgfsIget.
+       */
+      oldIinfo = INODE_GET_II_P(oldDentry->d_inode);
+      newIinfo = INODE_GET_II_P(newDentry->d_inode);
+      if (oldIinfo->hostFileId !=0 && newIinfo->hostFileId != 0 &&
+          oldIinfo->hostFileId == newIinfo->hostFileId) {
+         LOG(4, ("VMware hgfs: %s: source and target are the same file.\n",
+                 __func__));
+         result = -EEXIST;
+         goto out;
+      }
+   }
+
    req = HgfsGetNewRequest();
    if (!req) {
       LOG(4, (KERN_DEBUG "VMware hgfs: HgfsRename: out of memory while "
@@ -1751,7 +1717,6 @@ out:
  *----------------------------------------------------------------------------
  */
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 0)
 static int
 HgfsAccessInt(struct dentry *dentry, // IN: dentry to check access for
               int mask)              // IN: access mode requested.
@@ -1791,7 +1756,6 @@ HgfsAccessInt(struct dentry *dentry, // IN: dentry to check access for
    }
    return ret;
 }
-#endif
 
 
 /*
@@ -1811,41 +1775,33 @@ HgfsAccessInt(struct dentry *dentry, // IN: dentry to check access for
  *----------------------------------------------------------------------
  */
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 0) && \
-    LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 27)
 static int
-HgfsPermission(struct inode *inode, int mask, struct nameidata *nd)
-#else
-static int
-HgfsPermission(struct inode *inode, int mask)
+HgfsPermission(struct inode *inode,
+               int mask
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 27)
+               , struct nameidata *nd
 #endif
+               )
 {
    LOG(8, ("VMware hgfs: %s: inode->mode: %8x mask: %8x\n", __func__,
            inode->i_mode, mask));
    /*
     * For sys_access, we go to the host for permission checking;
     * otherwise return 0.
-    *
-    * XXX When the kernel version is less than 2.6.0, we didn't have a good way
-    * to tell whether this is for sys_access. Simply returning 0 is not what we
-    * want. Need to fix it.
     */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 0)
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 27)
    if (nd != NULL && (nd->flags & LOOKUP_ACCESS)) { /* For sys_access. */
 #else
    if (mask & MAY_ACCESS) { /* For sys_access. */
 #endif
-      struct dentry *dentry;
-      dentry = list_entry(inode->i_dentry.next, struct dentry, d_alias);
+      struct dentry *dentry = list_entry(inode->i_dentry.next,
+                                         struct dentry, d_alias);
       return HgfsAccessInt(dentry, mask & (MAY_READ | MAY_WRITE | MAY_EXEC));
    }
-#endif
    return 0;
 }
 
 
-#ifdef HGFS_GETATTR_ONLY
 /*
  *-----------------------------------------------------------------------------
  *
@@ -1885,7 +1841,6 @@ HgfsGetattr(struct vfsmount *mnt,  // Unused
 
    return 0;
 }
-#endif
 
 /*
  * Public function implementations.
@@ -1946,9 +1901,9 @@ HgfsSetattr(struct dentry *dentry,  // IN: File to set attributes of
 
    /*
     * Flush all dirty pages prior to sending the request if we're going to
-    * modify the file size.
+    * modify the file size or change the last write time.
     */
-   if (iattr->ia_valid & ATTR_SIZE) {
+   if (iattr->ia_valid & ATTR_SIZE || iattr->ia_valid & ATTR_MTIME) {
       compat_filemap_write_and_wait(dentry->d_inode->i_mapping);
    }
 
