@@ -31,9 +31,8 @@
 #include "compat_page-flags.h"
 #include "compat_fs.h"
 #include "compat_kernel.h"
-#ifdef HGFS_ENABLE_WRITEBACK
+#include "compat_pagemap.h"
 #include <linux/writeback.h>
-#endif
 
 #include "cpName.h"
 #include "hgfsProto.h"
@@ -62,16 +61,46 @@ static int HgfsDoWritepage(HgfsHandle handle,
                            struct page *page,
                            unsigned pageFrom,
                            unsigned pageTo);
+static void HgfsDoWriteBegin(struct page *page,
+                             unsigned pageFrom,
+                             unsigned pageTo);
+static int HgfsDoWriteEnd(struct file *file,
+                          struct page *page,
+                          unsigned pageFrom,
+                          unsigned pageTo,
+                          loff_t writeTo,
+                          unsigned copied);
 
 /* HGFS address space operations. */
 static int HgfsReadpage(struct file *file,
                         struct page *page);
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 52)
 static int HgfsWritepage(struct page *page,
                          struct writeback_control *wbc);
+
+/*
+ * Write aop interface has changed in 2.6.28. Specifically,
+ * the page locking semantics and requirement to handle
+ * short writes. We already handle short writes, so no major
+ * changes needed. write_begin is expected to return a locked
+ * page and write_end is expected to unlock the page and drop
+ * the reference before returning.
+ */
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 28)
+static int HgfsWriteBegin(struct file *file,
+                          struct address_space *mapping,
+                          loff_t pos,
+                          unsigned len,
+                          unsigned flags,
+                          struct page **page,
+                          void **clientData);
+static int HgfsWriteEnd(struct file *file,
+                        struct address_space *mapping,
+                        loff_t pos,
+                        unsigned len,
+                        unsigned copied,
+                        struct page *page,
+                        void *clientData);
 #else
-static int HgfsWritepage(struct page *page);
-#endif
 static int HgfsPrepareWrite(struct file *file,
                             struct page *page,
                             unsigned pageFrom,
@@ -80,16 +109,20 @@ static int HgfsCommitWrite(struct file *file,
                            struct page *page,
                            unsigned pageFrom,
                            unsigned pageTo);
+#endif
 
 /* HGFS address space operations structure. */
 struct address_space_operations HgfsAddressSpaceOperations = {
    .readpage      = HgfsReadpage,
    .writepage     = HgfsWritepage,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 28)
+   .write_begin   = HgfsWriteBegin,
+   .write_end     = HgfsWriteEnd,
+#else
    .prepare_write = HgfsPrepareWrite,
    .commit_write  = HgfsCommitWrite,
-#ifdef HGFS_ENABLE_WRITEBACK
-   .set_page_dirty = __set_page_dirty_nobuffers,
 #endif
+   .set_page_dirty = __set_page_dirty_nobuffers,
 };
 
 
@@ -143,7 +176,7 @@ HgfsDoRead(HgfsHandle handle,  // IN:  Handle for this file
    }
 
  retry:
-   opUsed = atomic_read(&hgfsVersionRead);
+   opUsed = hgfsVersionRead;
    if (opUsed == HGFS_OP_READ_V3) {
       HgfsRequest *header;
       HgfsRequestReadV3 *request;
@@ -215,7 +248,7 @@ HgfsDoRead(HgfsHandle handle,  // IN:  Handle for this file
          if (opUsed == HGFS_OP_READ_V3) {
             LOG(4, (KERN_DEBUG "VMware hgfs: HgfsDoRead: Version 3 not "
                     "supported. Falling back to version 1.\n"));
-            atomic_set(&hgfsVersionRead, HGFS_OP_READ);
+            hgfsVersionRead = HGFS_OP_READ;
             goto retry;
          }
 	 break;
@@ -288,7 +321,7 @@ HgfsDoWrite(HgfsHandle handle,       // IN: Handle for this file
    }
 
  retry:
-   opUsed = atomic_read(&hgfsVersionWrite);
+   opUsed = hgfsVersionWrite;
    if (opUsed == HGFS_OP_WRITE_V3) {
       HgfsRequest *header;
       HgfsRequestWriteV3 *request;
@@ -350,7 +383,7 @@ HgfsDoWrite(HgfsHandle handle,       // IN: Handle for this file
          if (opUsed == HGFS_OP_WRITE_V3) {
             LOG(4, (KERN_DEBUG "VMware hgfs: HgfsDoWrite: Version 3 not "
                     "supported. Falling back to version 1.\n"));
-            atomic_set(&hgfsVersionWrite, HGFS_OP_WRITE);
+            hgfsVersionWrite = HGFS_OP_WRITE;
             goto retry;
          }
          break;
@@ -605,14 +638,9 @@ HgfsReadpage(struct file *file, // IN:     File to read from
  *-----------------------------------------------------------------------------
  */
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 52)
 static int
 HgfsWritepage(struct page *page,             // IN: Page to write from
               struct writeback_control *wbc) // IN: Ignored
-#else
-static int
-HgfsWritepage(struct page *page)             // IN: Page to write from
-#endif
 {
    struct inode *inode;
    HgfsHandle handle;
@@ -695,6 +723,59 @@ HgfsWritepage(struct page *page)             // IN: Page to write from
 }
 
 
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * HgfsDoWriteBegin --
+ *
+ *      Helper function for HgfsWriteBegin / HgfsPrepareWrite.
+ *
+ *      Initialize the page if the file is to be appended.
+ *
+ * Results:
+ *      None.
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+static void
+HgfsDoWriteBegin(struct page *page,         // IN: Page to be written
+                 unsigned pageFrom,         // IN: Starting page offset
+                 unsigned pageTo)           // IN: Ending page offset
+{
+   loff_t offset;
+   loff_t currentFileSize;
+
+   ASSERT(page);
+
+   offset = (loff_t)page->index << PAGE_CACHE_SHIFT;
+   currentFileSize = compat_i_size_read(page->mapping->host);
+
+   /*
+    * If we are doing a partial write into a new page (beyond end of
+    * file), then intialize it. This allows other writes to this page
+    * to accumulate before we need to write it to the server.
+    */
+   if ((offset >= currentFileSize) ||
+       ((pageFrom == 0) && (offset + pageTo) >= currentFileSize)) {
+      void *kaddr = kmap_atomic(page, KM_USER0);
+
+      if (pageFrom) {
+         memset(kaddr, 0, pageFrom);
+      }
+      if (pageTo < PAGE_CACHE_SIZE) {
+         memset(kaddr + pageTo, 0, PAGE_CACHE_SIZE - pageTo);
+      }
+      kunmap_atomic(kaddr, KM_USER0);
+      flush_dcache_page(page);
+   }
+}
+
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 28)
 /*
  *-----------------------------------------------------------------------------
  *
@@ -719,104 +800,110 @@ HgfsPrepareWrite(struct file *file,  // IN: Ignored
                  unsigned pageFrom,  // IN: Beginning page offset
                  unsigned pageTo)    // IN: Ending page offset
 {
-#ifdef HGFS_ENABLE_WRITEBACK
-   loff_t offset = (loff_t)page->index << PAGE_CACHE_SHIFT;
-   loff_t currentFileSize = compat_i_size_read(page->mapping->host);
+   HgfsDoWriteBegin(page, pageFrom, pageTo);
 
-   /*
-    * If we are doing a partial write into a new page (beyond end of
-    * file), then intialize it. This allows other writes to this page
-    * to accumulate before we need to write it to the server.
-    */
-   if ((offset >= currentFileSize) ||
-       ((pageFrom == 0) && (offset + pageTo) >= currentFileSize)) {
-      void *kaddr = kmap_atomic(page, KM_USER0);
-
-      if (pageFrom) {
-         memset(kaddr, 0, pageFrom);
-      }
-      if (pageTo < PAGE_CACHE_SIZE) {
-         memset(kaddr + pageTo, 0, PAGE_CACHE_SIZE - pageTo);
-      }
-      kunmap_atomic(kaddr, KM_USER0);
-      flush_dcache_page(page);
-   }
-#endif
-
-   /*
-    * Prior to 2.4.10, our caller expected to call page_address(page) between
-    * the calls to prepare_write() and commit_write(). This meant filesystems
-    * had to kmap() the page in prepare_write() and kunmap() it in
-    * commit_write(). In 2.4.10, the call to page_address() was replaced with
-    * __copy_to_user(), and while its not clear to me why this is safer,
-    * nfs_prepare_write() dropped the kmap()/kunmap() calls in the same patch,
-    * so the two events must be related.
-    */
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 4, 10)
-   kmap(page);
-#endif
    return 0;
 }
 
+#else
+
 
 /*
  *-----------------------------------------------------------------------------
  *
- * HgfsCommitWrite --
+ * HgfsWriteBegin --
  *
- *    This function is the more common write path for HGFS, called from
- *    generic_file_buffered_write. It is much simpler for us than
- *    HgfsWritepage above: the caller has obtained a reference to the page
- *    and will unlock it when we're done. And we don't need to worry about
- *    properly marking the writeback bit, either. See mm/filemap.c in the
- *    kernel for details about how we are called.
+ *      Called by the generic write path to set up a write request for a page.
+ *      We're expected to do any pre-allocation and housekeeping prior to
+ *      receiving the write.
+ *
+ *      This function is expected to return a locked page.
  *
  * Results:
- *    Zero on succes, non-zero on error.
+ *      Zero on success, non-zero error otherwise.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *-----------------------------------------------------------------------------
  */
 
 static int
-HgfsCommitWrite(struct file *file, // IN: File we're writing to
-                struct page *page, // IN: Page we're writing from
-                unsigned pageFrom, // IN: Beginning page offset
-                unsigned pageTo)   // IN: Ending page offset
+HgfsWriteBegin(struct file *file,             // IN: File to be written
+               struct address_space *mapping, // IN: Mapping
+               loff_t pos,                    // IN: File position
+               unsigned len,                  // IN: Bytes to be written
+               unsigned flags,                // IN: Write flags
+               struct page **pagePtr,         // OUT: Locked page
+               void **clientData)             // OUT: Opaque to pass to write_end, unused
+{
+   pgoff_t index = pos >> PAGE_CACHE_SHIFT;
+   unsigned pageFrom = pos & (PAGE_CACHE_SHIFT - 1);
+   unsigned pageTo = pos + len;
+   struct page *page;
+
+   page = compat_grab_cache_page_write_begin(mapping, index, flags);
+   if (page == NULL) {
+      return -ENOMEM;
+   }
+   *pagePtr = page;
+
+   HgfsDoWriteBegin(page, pageFrom, pageTo);
+   return 0;
+}
+#endif
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * HgfsDoWriteEnd --
+ *
+ *      Helper function for HgfsWriteEnd.
+ *
+ *      This function updates the inode->i_size, conditionally marks the page
+ *      updated and carries out the actual write in case of partial page writes.
+ *
+ * Results:
+ *      Zero on succes, non-zero on error.
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+static int
+HgfsDoWriteEnd(struct file *file, // IN: File we're writing to
+               struct page *page, // IN: Page we're writing from
+               unsigned pageFrom, // IN: Starting page offset
+               unsigned pageTo,   // IN: Ending page offset
+               loff_t writeTo,    // IN: File position to write to
+               unsigned copied)   // IN: Number of bytes copied to the page
 {
    HgfsHandle handle;
    struct inode *inode;
    loff_t currentFileSize;
    loff_t offset;
-   loff_t writeTo;
 
    ASSERT(file);
    ASSERT(page);
    inode = page->mapping->host;
    currentFileSize = compat_i_size_read(inode);
    offset = (loff_t)page->index << PAGE_CACHE_SHIFT;
-   writeTo = offset + pageTo;
-
-   /* See coment in HgfsPrepareWrite. */
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 4, 10)
-   kunmap(page);
-#endif
 
    if (writeTo > currentFileSize) {
       compat_i_size_write(inode, writeTo);
    }
 
    /* We wrote a complete page, so it is up to date. */
-   if ((pageTo - pageFrom) == PAGE_CACHE_SIZE) {
+   if (copied == PAGE_CACHE_SIZE) {
       SetPageUptodate(page);
    }
 
-#ifdef HGFS_ENABLE_WRITEBACK
    /*
     * Check if this is a partial write to a new page, which was
-    * initialized in HgfsPrepareWrite.
+    * initialized in HgfsDoWriteBegin.
     */
    if ((offset >= currentFileSize) ||
        ((pageFrom == 0) && (writeTo >= currentFileSize))) {
@@ -831,17 +918,113 @@ HgfsCommitWrite(struct file *file, // IN: File we're writing to
       set_page_dirty(page);
       return 0;
    }
-#endif
+
    /*
     * We've recieved a partial write to page that is not uptodate, so
     * do the write now while the page is still locked.  Another
-    * alternative would be to read the page in HgfsPrepareWrite, which
+    * alternative would be to read the page in HgfsDoWriteBegin, which
     * would make it uptodate (ie a complete cached page).
     */
    handle = FILE_GET_FI_P(file)->handle;
-   LOG(6, (KERN_DEBUG "VMware hgfs: HgfsCommitWrite: writing to handle %u\n",
+   LOG(6, (KERN_DEBUG "VMware hgfs: %s: writing to handle %u\n", __func__,
            handle));
    return HgfsDoWritepage(handle, page, pageFrom, pageTo);
 }
 
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 28)
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * HgfsCommitWrite --
+ *
+ *      This function is the more common write path for HGFS, called from
+ *      generic_file_buffered_write. It is much simpler for us than
+ *      HgfsWritepage above: the caller has obtained a reference to the page
+ *      and will unlock it when we're done. And we don't need to worry about
+ *      properly marking the writeback bit, either. See mm/filemap.c in the
+ *      kernel for details about how we are called.
+ *
+ * Results:
+ *      Zero on succes, non-zero on error.
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+static int
+HgfsCommitWrite(struct file *file,    // IN: File to write
+                struct page *page,    // IN: Page to write from
+                unsigned pageFrom,    // IN: Starting page offset
+                unsigned pageTo)      // IN: Ending page offset
+{
+   loff_t offset;
+   loff_t writeTo;
+   unsigned copied;
+
+   ASSERT(page);
+   ASSERT(file);
+
+   offset = (loff_t)page->index << PAGE_CACHE_SHIFT;
+   writeTo = offset + pageTo;
+   copied = pageTo - pageFrom;
+
+   return HgfsDoWriteEnd(file, page, pageFrom, pageTo, writeTo, copied);
+}
+
+#else
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * HgfsWriteEnd --
+ *
+ *      This function is the more common write path for HGFS, called from
+ *      generic_file_buffered_write. It is much simpler for us than
+ *      HgfsWritepage above: write_begin has obtained a reference to the page
+ *      and we will unlock it when we're done. And we don't need to worry about
+ *      properly marking the writeback bit, either. See mm/filemap.c in the
+ *      kernel for details about how we are called.
+ *
+ *      This function should unlock the page and reduce the refcount.
+ *
+ * Results:
+ *      Number of bytes written or negative error
+ *
+ * Side effects:
+ *      Unlocks the page and drops the reference.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+static int
+HgfsWriteEnd(struct file *file,              // IN: File to write
+             struct address_space *mapping,  // IN: Mapping
+             loff_t pos,                     // IN: File position
+             unsigned len,                   // IN: len passed from write_begin
+             unsigned copied,                // IN: Number of actually copied bytes
+             struct page *page,              // IN: Page to write from
+             void *clientData)               // IN: From write_begin, unused.
+{
+   unsigned pageFrom = pos & (PAGE_CACHE_SIZE - 1);
+   unsigned pageTo = pageFrom + copied;
+   loff_t writeTo = pos + copied;
+   int ret;
+
+   ASSERT(file);
+   ASSERT(mapping);
+   ASSERT(page);
+
+   ret = HgfsDoWriteEnd(file, page, pageFrom, pageTo, writeTo, copied);
+   if (ret == 0) {
+      ret = copied;
+   }
+
+   compat_unlock_page(page);
+   page_cache_release(page);
+   return ret;
+}
+#endif
