@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2009-2011 VMware, Inc. All rights reserved.
+ * Copyright (C) 2009 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -74,16 +74,11 @@ VSockVmciNotifyWaitingWrite(VSockVmciSock *vsk)    // IN
 
    if (!PKT_FIELD(vsk, peerWaitingWriteDetected)) {
       PKT_FIELD(vsk, peerWaitingWriteDetected) = TRUE;
-      if (PKT_FIELD(vsk, writeNotifyWindow) < PAGE_SIZE) {
+      PKT_FIELD(vsk, writeNotifyWindow) -= PAGE_SIZE;
+      if (PKT_FIELD(vsk, writeNotifyWindow) <
+                    PKT_FIELD(vsk, writeNotifyMinWindow)) {
          PKT_FIELD(vsk, writeNotifyWindow) =
             PKT_FIELD(vsk, writeNotifyMinWindow);
-      } else {
-         PKT_FIELD(vsk, writeNotifyWindow) -= PAGE_SIZE;
-         if (PKT_FIELD(vsk, writeNotifyWindow) <
-             PKT_FIELD(vsk, writeNotifyMinWindow)) {
-            PKT_FIELD(vsk, writeNotifyWindow) =
-               PKT_FIELD(vsk, writeNotifyMinWindow);
-         }
       }
    }
    notifyLimit = vsk->consumeSize - PKT_FIELD(vsk, writeNotifyWindow);
@@ -99,7 +94,8 @@ VSockVmciNotifyWaitingWrite(VSockVmciSock *vsk)    // IN
     * as freeSpace == ConsumeSize - bufferReady.
     */
 
-   retval = vmci_qpair_consume_free_space(vsk->qpair) > notifyLimit;
+   retval = VMCIQueue_FreeSpace(vsk->consumeQ, vsk->produceQ, vsk->consumeSize) >
+            notifyLimit;
 
    if (retval) {
       /*
@@ -137,7 +133,7 @@ VSockVmciHandleRead(struct sock *sk,            // IN
                     struct sockaddr_vm *src)    // IN: unused
 {
 
-   sk->sk_write_space(sk);
+   sk->compat_sk_write_space(sk);
 }
 
 
@@ -164,7 +160,7 @@ VSockVmciHandleWrote(struct sock *sk,            // IN
                      struct sockaddr_vm *dst,    // IN: unused
                      struct sockaddr_vm *src)    // IN: unused
 {
-   sk->sk_data_ready(sk, 0);
+   sk->compat_sk_data_ready(sk, 0);
 }
 
 
@@ -283,7 +279,7 @@ VSockVmciNotifyPktSocketInit(struct sock *sk) // IN
    VSockVmciSock *vsk;
    vsk = vsock_sk(sk);
 
-   PKT_FIELD(vsk, writeNotifyWindow) = PAGE_SIZE;
+   PKT_FIELD(vsk, writeNotifyWindow) = 0;
    PKT_FIELD(vsk, writeNotifyMinWindow) = PAGE_SIZE;
    PKT_FIELD(vsk, peerWaitingWrite) = FALSE;
    PKT_FIELD(vsk, peerWaitingWriteDetected) = FALSE;
@@ -312,10 +308,11 @@ VSockVmciNotifyPktSocketDestruct(struct sock *sk) // IN
    VSockVmciSock *vsk;
    vsk = vsock_sk(sk);
 
-   PKT_FIELD(vsk, writeNotifyWindow) = PAGE_SIZE;
+   PKT_FIELD(vsk, writeNotifyWindow) = 0;
    PKT_FIELD(vsk, writeNotifyMinWindow) = PAGE_SIZE;
    PKT_FIELD(vsk, peerWaitingWrite) = FALSE;
    PKT_FIELD(vsk, peerWaitingWriteDetected) = FALSE;
+   return;
 }
 
 
@@ -339,7 +336,7 @@ VSockVmciNotifyPktSocketDestruct(struct sock *sk) // IN
 
 static int32
 VSockVmciNotifyPktPollIn(struct sock *sk,    // IN
-                         size_t target,      // IN
+                         int target,         // IN
                          Bool *dataReadyNow) // IN
 {
    VSockVmciSock *vsk;
@@ -356,7 +353,7 @@ VSockVmciNotifyPktPollIn(struct sock *sk,    // IN
        * We can't read right now because there is nothing in the queue.
        * Ask for notifications when there is something to read.
        */
-      if (sk->sk_state == SS_CONNECTED) {
+      if (sk->compat_sk_state == SS_CONNECTED) {
          VSockVmciBlockUpdateWriteWindow(sk);
       }
       *dataReadyNow = FALSE;
@@ -386,7 +383,7 @@ VSockVmciNotifyPktPollIn(struct sock *sk,    // IN
 
 static int32
 VSockVmciNotifyPktPollOut(struct sock *sk,     // IN
-                          size_t target,       // IN
+                          int target,          // IN
                           Bool *spaceAvailNow) // IN
 {
    int64 produceQFreeSpace;
@@ -432,7 +429,7 @@ VSockVmciNotifyPktPollOut(struct sock *sk,     // IN
 
 static int32
 VSockVmciNotifyPktRecvInit(struct sock *sk,               // IN
-                           size_t target,                 // IN
+                           int target,                    // IN
                            VSockVmciRecvNotifyData *data) // IN
 {
    VSockVmciSock *vsk;
@@ -492,14 +489,16 @@ VSockVmciNotifyPktRecvInit(struct sock *sk,               // IN
 
 static int32
 VSockVmciNotifyPktRecvPreBlock(struct sock *sk,               // IN
-                               size_t target,                 // IN
+                               int target,                    // IN
                                VSockVmciRecvNotifyData *data) // IN
 {
+   VSockVmciSock *vsk;
    int err;
 
    ASSERT(sk);
    ASSERT(data);
 
+   vsk = vsock_sk(sk);
    err = 0;
 
    VSockVmciBlockUpdateWriteWindow(sk);
@@ -534,7 +533,7 @@ VSockVmciNotifyPktRecvPreBlock(struct sock *sk,               // IN
 
 static int32
 VSockVmciNotifyPktRecvPostDequeue(struct sock *sk,               // IN
-                                  size_t target,                 // IN
+                                  int target,                    // IN
                                   ssize_t copied,                // IN
                                   Bool dataRead,                 // IN
                                   VSockVmciRecvNotifyData *data) // IN
@@ -553,7 +552,9 @@ VSockVmciNotifyPktRecvPostDequeue(struct sock *sk,               // IN
    if (dataRead) {
       Atomic_MFence();
 
-      freeSpace = vmci_qpair_consume_free_space(vsk->qpair);
+      freeSpace = VMCIQueue_FreeSpace(vsk->consumeQ,
+                                      vsk->produceQ,
+                                      vsk->consumeSize);
       wasFull = freeSpace == copied;
 
       if (wasFull) {
@@ -566,7 +567,7 @@ VSockVmciNotifyPktRecvPostDequeue(struct sock *sk,               // IN
       }
 
       /* See the comment in VSockVmciNotifyPktSendPostEnqueue */
-      sk->sk_data_ready(sk, 0);
+      sk->compat_sk_data_ready(sk, 0);
    }
 
    return err;
@@ -637,7 +638,9 @@ VSockVmciNotifyPktSendPostEnqueue(struct sock *sk,               // IN
 
    Atomic_MFence();
 
-   wasEmpty = (vmci_qpair_produce_buf_ready(vsk->qpair) == written);
+   wasEmpty = (VMCIQueue_BufReady(vsk->produceQ,
+                                  vsk->consumeQ,
+                                  vsk->produceSize) == written);
    if (wasEmpty) {
       while (!(vsk->peerShutdown & RCV_SHUTDOWN) &&
              !sentWrote &&
@@ -733,9 +736,6 @@ VSockVmciNotifyPktProcessRequest(struct sock *sk) // IN
    vsk = vsock_sk(sk);
 
    PKT_FIELD(vsk, writeNotifyWindow) = vsk->consumeSize;
-   if (vsk->consumeSize < PKT_FIELD(vsk, writeNotifyMinWindow)) {
-      PKT_FIELD(vsk, writeNotifyMinWindow) = vsk->consumeSize;
-   }
 }
 
 
@@ -765,9 +765,6 @@ VSockVmciNotifyPktProcessNegotiate(struct sock *sk) // IN
    vsk = vsock_sk(sk);
 
    PKT_FIELD(vsk, writeNotifyWindow) = vsk->consumeSize;
-   if (vsk->consumeSize < PKT_FIELD(vsk, writeNotifyMinWindow)) {
-      PKT_FIELD(vsk, writeNotifyMinWindow) = vsk->consumeSize;
-   }
 }
 
 
