@@ -221,7 +221,7 @@ Bool
 VSockAddr_Bound(struct sockaddr_vm *addr) // IN: socket address to check
 {
    ASSERT(addr);
-   return addr->svm_cid != VMADDR_CID_ANY && addr->svm_port != VMADDR_PORT_ANY;
+   return addr->svm_port != VMADDR_PORT_ANY;
 }
 
 
@@ -280,6 +280,39 @@ VSockAddr_EqualsAddr(struct sockaddr_vm *addr,  // IN
 }
 
 
+/*
+ *----------------------------------------------------------------------------
+ *
+ * VSockAddr_EqualsAddrAny --
+ *
+ *    Determine if the given addresses are equal. Will accept either an exact
+ *    match or one where the rids match and that either the cids match or
+ *    are set to VMADDR_CID_ANY.
+ *
+ * Results:
+ *    TRUE if the addresses are equal, FALSE otherwise.
+ *
+ * Side effects:
+ *    None.
+ *
+ *----------------------------------------------------------------------------
+ */
+
+Bool
+VSockAddr_EqualsAddrAny(struct sockaddr_vm *addr,  // IN
+                        struct sockaddr_vm *other) // IN
+{
+   VSOCK_ADDR_NOFAMILY_ASSERT(addr);
+   VSOCK_ADDR_NOFAMILY_ASSERT(other);
+   if (addr->svm_cid == VMADDR_CID_ANY ||
+       other->svm_cid == VMADDR_CID_ANY ||
+       addr->svm_cid == other->svm_cid) {
+      return (addr->svm_port == other->svm_port);
+   }
+   return FALSE;
+}
+
+
 /*
  *----------------------------------------------------------------------------
  *
@@ -351,10 +384,10 @@ exit:
 /*
  *----------------------------------------------------------------------------
  *
- * VSockAddr_SocketContext --
+ * VSockAddr_SocketContextStream --
  *
  *      Determines whether the provided context id represents a context that
- *      contains socket endpoints.
+ *      contains a stream socket endpoints.
  *
  * Results:
  *      TRUE if the context does have socket endpoints, FALSE otherwise.
@@ -366,7 +399,7 @@ exit:
  */
 
 Bool
-VSockAddr_SocketContext(uint32 cid)  // IN
+VSockAddr_SocketContextStream(uint32 cid)  // IN
 {
    uint32 i;
    VMCIId nonSocketContexts[] = {
@@ -384,3 +417,34 @@ VSockAddr_SocketContext(uint32 cid)  // IN
 
    return TRUE;
 }
+
+
+/*
+ *----------------------------------------------------------------------------
+ *
+ * VSockAddr_SocketContextDgram --
+ *
+ *      Determines whether the provided <context id, resource id> represent
+ *      a protected datagram endpoint.
+ *
+ * Results:
+ *      TRUE if the context does have socket endpoints, FALSE otherwise.
+ *
+ * Side effects:
+ *      None.
+ *
+ *----------------------------------------------------------------------------
+ */
+
+Bool
+VSockAddr_SocketContextDgram(uint32 cid,  // IN
+                             uint32 rid)  // IN
+{
+   if (cid == VMCI_HYPERVISOR_CONTEXT_ID) {
+      if (rid != VMCI_VSOCK_VMX_LOOKUP) {
+         return FALSE;
+      }
+   }
+
+   return TRUE;
+}
