@@ -46,18 +46,17 @@
 #include "guestInfoInt.h"
 #include "guest_msg_def.h" // For GUESTMSG_MAX_IN_SIZE
 #include "netutil.h"
-#include "rpcChannel.h"
 #include "rpcvmx.h"
 #include "procMgr.h"
 #include "str.h"
 #include "strutil.h"
 #include "system.h"
 #include "util.h"
-#include "vmtools.h"
-#include "vmtoolsApp.h"
 #include "xdrutil.h"
 #include "vmsupport.h"
 #include "vmware/guestrpc/tclodefs.h"
+#include "vmware/tools/plugin.h"
+#include "vmware/tools/utils.h"
 
 #if !defined(__APPLE__)
 #include "embed_version.h"
@@ -112,7 +111,6 @@ static Bool vmResumed;
 static Bool GuestInfoUpdateVmdb(ToolsAppCtx *ctx, GuestInfoType infoType, void *info);
 static Bool SetGuestInfo(ToolsAppCtx *ctx, GuestInfoType key,
                          const char *value, char delimiter);
-static Bool NicInfoChanged(NicInfoV3 *nicInfo);
 static Bool DiskInfoChanged(PGuestDiskInfo diskInfo);
 static void GuestInfoClearCache(void);
 static GuestNicList *NicInfoV3ToV2(const NicInfoV3 *infoV3);
@@ -127,7 +125,7 @@ static void TweakGatherLoop(ToolsAppCtx *ctx);
  * @return TRUE on success.
  */
 
-static Bool
+static gboolean
 GuestInfoVMSupport(RpcInData *data)
 {
 #if defined(_WIN32)
@@ -395,11 +393,7 @@ GuestInfoGather(gpointer data)
          if (!GuestInfoUpdateVmdb(ctx, INFO_DISK_FREE_SPACE, &diskInfo)) {
             g_warning("Failed to update VMDB\n.");
          }
-      }
-      /* Free memory allocated in GuestInfoGetDiskInfo. */
-      if (diskInfo.partitionList != NULL) {
-         vm_free(diskInfo.partitionList);
-         diskInfo.partitionList = NULL;
+         GuestInfo_FreeDiskInfo(&diskInfo);
       }
    }
 
@@ -412,20 +406,19 @@ GuestInfoGather(gpointer data)
    /* Get NIC information. */
    if (!GuestInfo_GetNicInfo(&nicInfo)) {
       g_warning("Failed to get nic info.\n");
-   } else if (NicInfoChanged(nicInfo)) {
-      if (GuestInfoUpdateVmdb(ctx, INFO_IPADDRESS, nicInfo)) {
-         /*
-          * Update the cache. Release the memory previously used by the cache,
-          * and copy the new information into the cache.
-          */
-         GuestInfo_FreeNicInfo(gInfoCache.nicInfo);
-         gInfoCache.nicInfo = nicInfo;
-      } else {
-         g_warning("Failed to update VMDB.\n");
-      }
-   } else {
+   } else if (GuestInfo_IsEqual_NicInfoV3(nicInfo, gInfoCache.nicInfo)) {
       g_debug("Nic info not changed.\n");
       GuestInfo_FreeNicInfo(nicInfo);
+   } else if (GuestInfoUpdateVmdb(ctx, INFO_IPADDRESS, nicInfo)) {
+      /*
+       * Since the update succeeded, free the old cached object, and assign
+       * ours to the cache.
+       */
+      GuestInfo_FreeNicInfo(gInfoCache.nicInfo);
+      gInfoCache.nicInfo = nicInfo;
+   } else {
+      g_warning("Failed to update VMDB.\n");
+      GuestInfo_FreeNicInfo(nicInfo);
    }
 
    /* Send the uptime to VMX so that it can detect soft resets. */
@@ -646,7 +639,13 @@ nicinfo_fsm:
                                         &replyLen);
                DynXdr_Destroy(&xdrs, TRUE);
 
+               /*
+                * Do not free/destroy contents of `message`.  The v3 nicInfo
+                * passed to us belongs to our caller.  Instead, we'll only
+                * destroy our local V2 converted data.
+                */
                if (nicList) {
+                  VMX_XDR_FREE(xdr_GuestNicList, nicList);
                   free(nicList);
                   nicList = NULL;
                }
@@ -752,8 +751,7 @@ nicinfo_fsm:
          char *reply;
          size_t replyLen;
          Bool status;
-         PGuestDiskInfo pdi = (PGuestDiskInfo)info;
-         int j = 0;
+         GuestDiskInfo *pdi = info;
 
          if (!DiskInfoChanged(pdi)) {
             g_debug("Disk info not changed.\n");
@@ -797,34 +795,25 @@ nicinfo_fsm:
 
          g_debug("sizeof request is %d\n", requestSize);
          status = RpcChannel_Send(ctx->rpc, request, requestSize, &reply, &replyLen);
+         if (status) {
+            status = (*reply == '\0');
+         }
 
-         if (!status || (strncmp(reply, "", 1) != 0)) {
+         vm_free(request);
+         vm_free(reply);
+
+         if (!status) {
             g_warning("Failed to update disk information.\n");
-            vm_free(request);
-            vm_free(reply);
             return FALSE;
          }
 
          g_debug("Updated disk info information\n");
-         vm_free(reply);
-         vm_free(request);
 
-         /* Free any memory previously allocated in the cache. */
-         if (gInfoCache.diskInfo.partitionList != NULL) {
-            vm_free(gInfoCache.diskInfo.partitionList);
-            gInfoCache.diskInfo.partitionList = NULL;
-         }
-         gInfoCache.diskInfo.numEntries = pdi->numEntries;
-         gInfoCache.diskInfo.partitionList = calloc(pdi->numEntries,
-                                                         sizeof(PartitionEntry));
-         if (gInfoCache.diskInfo.partitionList == NULL) {
-            g_warning("Could not allocate memory for the disk info cache.\n");
+         if (!GuestInfo_CopyDiskInfo(&gInfoCache.diskInfo, pdi)) {
+            g_warning("Could not cache the disk info data.\n");
             return FALSE;
          }
 
-         for (j = 0; j < pdi->numEntries; j++) {
-            gInfoCache.diskInfo.partitionList[j] = pdi->partitionList[j];
-         }
          break;
       }
    default:
@@ -887,7 +876,7 @@ SetGuestInfo(ToolsAppCtx *ctx,   // IN: application context
    }
 
    /* The reply indicates whether the key,value pair was updated in VMDB. */
-   status = (strncmp(reply, "", 1) == 0);
+   status = (*reply == '\0');
    vm_free(reply);
    return status;
 }
@@ -927,106 +916,6 @@ GuestInfoFindMacAddress(NicInfoV3 *nicInfo,     // IN/OUT
 }
 
 
-/*
- *----------------------------------------------------------------------
- *
- * NicInfoChanged --
- *
- *      Checks whether Nic information just obtained is different from
- *      the information last sent to VMDB.
- *
- * Results:
- *
- *      TRUE if the NIC info has changed, FALSE otherwise
- *
- * Side effects:
- *
- *	None.
- *
- *----------------------------------------------------------------------
- */
-
-Bool
-NicInfoChanged(NicInfoV3 *nicInfo)  // IN
-{
-   u_int i;
-   NicInfoV3 *cachedNicInfo = gInfoCache.nicInfo;
-
-   if (!cachedNicInfo) {
-      return TRUE;
-   }
-
-   /*
-    * XXX Add routing, DNS, WINS comparisons.
-    */
-
-   if (cachedNicInfo->nics.nics_len != nicInfo->nics.nics_len) {
-      g_debug("Number of nics has changed\n");
-      return TRUE;
-   }
-
-   for (i = 0; i < cachedNicInfo->nics.nics_len; i++) {
-      u_int j;
-      GuestNicV3 *cachedNic = &cachedNicInfo->nics.nics_val[i];
-      GuestNicV3 *matchedNic;
-
-      /* Find the corresponding nic in the new nic info. */
-      matchedNic = GuestInfoFindMacAddress(nicInfo, cachedNic->macAddress);
-
-      if (NULL == matchedNic) {
-         /* This mac address has been deleted. */
-         return TRUE;
-      }
-
-      if (matchedNic->ips.ips_len != cachedNic->ips.ips_len) {
-         g_debug("Count of ip addresses for mac %d\n",
-                 matchedNic->ips.ips_len);
-         return TRUE;
-      }
-
-      /* Which IP addresses have been modified for this NIC? */
-      for (j = 0; j < cachedNic->ips.ips_len; j++) {
-         TypedIpAddress *cachedIp = &cachedNic->ips.ips_val[j].ipAddressAddr;
-         Bool foundIP = FALSE;
-         ssize_t cmpsz =
-            cachedIp->ipAddressAddrType == IAT_IPV4 ? 4 :
-            cachedIp->ipAddressAddrType == IAT_IPV6 ? 16 :
-            -1;
-         u_int k;
-
-         /* XXX */
-         ASSERT(cmpsz != -1);
-
-         for (k = 0; k < matchedNic->ips.ips_len; k++) {
-            TypedIpAddress *matchedIp =
-               &matchedNic->ips.ips_val[k].ipAddressAddr;
-            if (cachedIp->ipAddressAddrType == matchedIp->ipAddressAddrType &&
-                memcmp(cachedIp->ipAddressAddr.InetAddress_val,
-                       matchedIp->ipAddressAddr.InetAddress_val,
-                       cmpsz) == 0) {
-               foundIP = TRUE;
-               break;
-            }
-         }
-
-         if (FALSE == foundIP) {
-            /* This ip address couldn't be found and has been modified. */
-#if 0
-            g_debug("MAC address %s, ipaddress %s deleted\n",
-                    cachedNic->macAddress,
-                    cachedIp->ipAddress);
-#endif
-            return TRUE;
-         }
-
-      }
-
-   }
-
-   return FALSE;
-}
-
-
 /*
  *----------------------------------------------------------------------
  *
@@ -1122,6 +1011,8 @@ GuestInfoClearCache(void)
       gInfoCache.value[i][0] = 0;
    }
 
+   GuestInfo_FreeDiskInfo(&gInfoCache.diskInfo);
+
    GuestInfo_FreeNicInfo(gInfoCache.nicInfo);
    gInfoCache.nicInfo = NULL;
 }
@@ -1285,40 +1176,41 @@ ToolsOnLoad(ToolsAppCtx *ctx)
       NULL
    };
 
-   RpcChannelCallback rpcs[] = {
-      { RPC_VMSUPPORT_START, GuestInfoVMSupport, &regData, NULL, NULL, 0 }
-   };
-   ToolsPluginSignalCb sigs[] = {
-      { TOOLS_CORE_SIG_CAPABILITIES, GuestInfoServerSendUptime, NULL },
-      { TOOLS_CORE_SIG_CONF_RELOAD, GuestInfoServerConfReload, NULL },
-      { TOOLS_CORE_SIG_RESET, GuestInfoServerReset, NULL },
-      { TOOLS_CORE_SIG_SET_OPTION, GuestInfoServerSetOption, NULL },
-      { TOOLS_CORE_SIG_SHUTDOWN, GuestInfoServerShutdown, NULL }
-   };
-   ToolsAppReg regs[] = {
-      { TOOLS_APP_GUESTRPC, VMTools_WrapArray(rpcs, sizeof *rpcs, ARRAYSIZE(rpcs)) },
-      { TOOLS_APP_SIGNALS, VMTools_WrapArray(sigs, sizeof *sigs, ARRAYSIZE(sigs)) }
-   };
-
    /*
     * This plugin is useless without an RpcChannel.  If we don't have one,
     * just bail.
     */
-   if (ctx->rpc == NULL) {
-      return NULL;
+   if (ctx->rpc != NULL) {
+      RpcChannelCallback rpcs[] = {
+         { RPC_VMSUPPORT_START, GuestInfoVMSupport, &regData, NULL, NULL, 0 }
+      };
+      ToolsPluginSignalCb sigs[] = {
+         { TOOLS_CORE_SIG_CAPABILITIES, GuestInfoServerSendUptime, NULL },
+         { TOOLS_CORE_SIG_CONF_RELOAD, GuestInfoServerConfReload, NULL },
+         { TOOLS_CORE_SIG_RESET, GuestInfoServerReset, NULL },
+         { TOOLS_CORE_SIG_SET_OPTION, GuestInfoServerSetOption, NULL },
+         { TOOLS_CORE_SIG_SHUTDOWN, GuestInfoServerShutdown, NULL }
+      };
+      ToolsAppReg regs[] = {
+         { TOOLS_APP_GUESTRPC, VMTools_WrapArray(rpcs, sizeof *rpcs, ARRAYSIZE(rpcs)) },
+         { TOOLS_APP_SIGNALS, VMTools_WrapArray(sigs, sizeof *sigs, ARRAYSIZE(sigs)) }
+      };
+
+      regData.regs = VMTools_WrapArray(regs, sizeof *regs, ARRAYSIZE(regs));
+
+      memset(&gInfoCache, 0, sizeof gInfoCache);
+      GuestInfo_InitDiskInfo(&gInfoCache.diskInfo);
+      vmResumed = FALSE;
+
+      /*
+       * Set up the GuestInfoGather loop.
+       */
+      TweakGatherLoop(ctx);
+
+      return &regData;
    }
 
-   regData.regs = VMTools_WrapArray(regs, sizeof *regs, ARRAYSIZE(regs));
-
-   memset(&gInfoCache, 0, sizeof gInfoCache);
-   vmResumed = FALSE;
-
-   /*
-    * Set up the GuestInfoGather loop.
-    */
-   TweakGatherLoop(ctx);
-
-   return &regData;
+   return NULL;
 }
 
 
