@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2010-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2010 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -63,15 +63,13 @@ TimeSync_DisableTimeSlew(void)
 
 /*
  ******************************************************************************
- * TimeSync_Slew --                                                     */ /**
+ * TimeSync_EnableTimeSlew --                                           */ /**
  *
  * Slew the clock, correcting 'delta' microseconds.  timeSyncPeriod is
- * ignored by this implementation.  Report the amount of the previous
- * correction that has not been applied.
+ * ignored by this implementation.
  *
- * @param[in]  delta              Correction to apply in us.
- * @param[in]  timeSyncPeriod     Time interval in us.
- * @param[out] remaining          Amount of previous correction not applied.
+ * @param[in] delta              Time difference in us.
+ * @param[in] timeSyncPeriod     Time interval in us.
  *
  * @return TRUE on success.
  *
@@ -79,9 +77,8 @@ TimeSync_DisableTimeSlew(void)
  */
 
 Bool
-TimeSync_Slew(int64 delta,
-              int64 timeSyncPeriod,
-              int64 *remaining)
+TimeSync_EnableTimeSlew(int64 delta,
+                        int64 timeSyncPeriod)
 {
    struct timeval tx;
    struct timeval oldTx;
@@ -95,8 +92,5 @@ TimeSync_Slew(int64 delta,
       return FALSE;
    }
    g_debug("time slew start.\n");
-
-   *remaining = (int64)oldTx.tv_sec * US_PER_SEC + (int64)oldTx.tv_usec;
-
    return TRUE;
 }
