@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2009-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2009 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -37,21 +37,11 @@ Bool
 TimeSync_AddToCurrentTime(int64 delta);
 
 Bool
-TimeSync_Slew(int64 delta,
-              int64 timeSyncPeriod,
-              int64 *remaining);
+TimeSync_EnableTimeSlew(int64 delta,
+                        int64 timeSyncPeriod);
 
 Bool
 TimeSync_DisableTimeSlew(void);
 
-Bool
-TimeSync_PLLUpdate(int64 offset);
-
-Bool
-TimeSync_PLLSetFrequency(int64 ppmCorrection);
-
-Bool
-TimeSync_PLLSupported(void);
-
 #endif /* _TIMESYNC_INT_H_ */
 
