@@ -57,7 +57,7 @@
 
 #if defined(VMTOOLS_USE_GLIB)
 #  include "vixPluginInt.h"
-#  include "vmtools.h"
+#  include "vmware/tools/utils.h"
 #else
 #  include "debug.h"
 #  include "eventManager.h"
@@ -123,19 +123,17 @@ static char *ToolsDaemonTcloGetQuotedString(const char *args,
 static char * ToolsDaemonTcloGetEncodedQuotedString(const char *args,
                                                     const char **endOfArg);
 
-Bool ToolsDaemonTcloReceiveVixCommand(RpcInData *data);
+RpcInRet ToolsDaemonTcloReceiveVixCommand(RpcInData *data);
 
-#if !defined(N_PLAT_NLM)
-Bool ToolsDaemonHgfsImpersonated(RpcInData *data);
-#endif
+RpcInRet ToolsDaemonHgfsImpersonated(RpcInData *data);
 
 #if defined(linux) || defined(_WIN32)
-Bool ToolsDaemonTcloSyncDriverFreeze(RpcInData *data);
+RpcInRet ToolsDaemonTcloSyncDriverFreeze(RpcInData *data);
 
-Bool ToolsDaemonTcloSyncDriverThaw(RpcInData *data);
+RpcInRet ToolsDaemonTcloSyncDriverThaw(RpcInData *data);
 #endif
 
-Bool ToolsDaemonTcloMountHGFS(RpcInData *data);
+RpcInRet ToolsDaemonTcloMountHGFS(RpcInData *data);
 
 void ToolsDaemonTcloReportProgramCompleted(const char *requestName,
                                            VixError err,
@@ -171,7 +169,7 @@ static Bool thisProcessRunsAsRoot = FALSE;
  *-----------------------------------------------------------------------------
  */
 
-Bool
+RpcInRet
 FoundryToolsDaemonRunProgram(RpcInData *data) // IN
 {
    VixError err = VIX_OK;
@@ -285,7 +283,7 @@ abort:
  *-----------------------------------------------------------------------------
  */
 
-Bool
+RpcInRet
 FoundryToolsDaemonGetToolsProperties(RpcInData *data) // IN
 {
    VixError err = VIX_OK;
@@ -372,7 +370,7 @@ abort:
  *-----------------------------------------------------------------------------
  */
 
-Bool
+RpcInRet
 ToolsDaemonTcloCheckUserAccount(RpcInData *data) // IN
 {
    VixError err = VIX_OK;
@@ -699,7 +697,7 @@ ToolsDaemonTcloGetEncodedQuotedString(const char *args,      // IN
  *-----------------------------------------------------------------------------
  */
 
-Bool
+RpcInRet
 ToolsDaemonTcloOpenUrl(RpcInData *data) // IN
 {
    static char resultBuffer[DEFAULT_RESULT_MSG_MAX_LENGTH];
@@ -778,108 +776,6 @@ abort:
    return TRUE;
 }
 
-
-/*
- *-----------------------------------------------------------------------------
- *
- * ToolsDaemonTcloSetPrinter --
- *
- *    Set the printer on the guest.
- *
- * Return value:
- *    TRUE on success
- *    FALSE on failure
- *
- * Side effects:
- *    None
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-ToolsDaemonTcloSetPrinter(RpcInData *data) // IN
-{
-   static char resultBuffer[DEFAULT_RESULT_MSG_MAX_LENGTH];
-#if defined(_WIN32)
-   VixError err = VIX_OK;
-   char *printerName = NULL;
-   char *defaultString = NULL;
-   int defaultInt;
-   DWORD sysError = ERROR_SUCCESS;
-   Debug(">ToolsDaemonTcloSetPrinter\n");
-
-   /*
-    * Parse the arguments
-    */
-   printerName = ToolsDaemonTcloGetQuotedString(data->args, &data->args);
-   defaultString = ToolsDaemonTcloGetQuotedString(data->args, &data->args);
-
-   /*
-    * Validate the arguments.
-    */
-   if ((NULL == printerName) || (NULL == defaultString)) {
-      err = VIX_E_INVALID_ARG;
-      Debug("Failed to get string args\n");
-      goto abort;
-   }
-
-   if (!StrUtil_StrToInt(&defaultInt, defaultString)) {
-      err = VIX_E_INVALID_ARG;
-      Debug("Failed to convert int arg\n");
-      goto abort;
-   }
-
-   Debug("Setting printer to: \"%s\", %ssetting as default\n",
-         printerName, (defaultInt != 0) ? "" : "not ");
-
-   /* Actually set the printer. */
-   if (!Printer_AddConnection(printerName, &sysError)) {
-      err = VIX_E_FAIL;
-      Debug("Failed to add printer %s : %d %s\n", printerName, sysError,
-            Err_Errno2String(sysError));
-      goto abort;
-   }
-
-   /* Set this printer as the default if requested. */
-   if (defaultInt != 0) {
-      if (!Win32U_SetDefaultPrinter(printerName)) {
-         /*
-          * We couldn't set this printer as default. Oh well. We'll
-          * still report success or failure based purely on whether
-          * the actual printer add succeeded or not.
-          */
-         Debug("Unable to set \"%s\" as the default printer\n",
-               printerName);
-      }
-   }
-
-abort:
-   /*
-    * All Foundry tools commands return results that start with a
-    * foundry error and a guest-OS-specific error.
-    */
-   Str_Sprintf(resultBuffer, sizeof resultBuffer, "%"FMT64"d %d", err, sysError);
-   RPCIN_SETRETVALS(data, resultBuffer, TRUE);
-
-   /*
-    * These were allocated by ToolsDaemonTcloGetQuotedString.
-    */
-   free(printerName);
-   free(defaultString);
-
-   Debug("<ToolsDaemonTcloSetPrinter\n");
-   return TRUE;
-
-#else
-   Str_Sprintf(resultBuffer,
-               sizeof resultBuffer,
-               "%d %d 0",
-               VIX_E_OP_NOT_SUPPORTED_ON_GUEST,
-               Err_Errno());
-   RPCIN_SETRETVALS(data, resultBuffer, TRUE);
-   return TRUE;
-#endif
-}
 #endif
 
 
@@ -901,7 +797,7 @@ abort:
  */
 
 #if defined(linux) || defined(_WIN32)
-Bool
+RpcInRet
 ToolsDaemonTcloSyncDriverFreeze(RpcInData *data)
 {
    static char resultBuffer[DEFAULT_RESULT_MSG_MAX_LENGTH];
@@ -1068,7 +964,7 @@ exit:
  */
 
 #if defined(linux) || defined(_WIN32)
-Bool
+RpcInRet
 ToolsDaemonTcloSyncDriverThaw(RpcInData *data) // IN
 {
    static char resultBuffer[DEFAULT_RESULT_MSG_MAX_LENGTH];
@@ -1177,6 +1073,8 @@ FoundryToolsDaemon_RegisterOpenUrl(RpcIn *in) // IN
     * the guest.
     */
    if (!FoundryToolsDaemon_RegisterOpenUrlCapability()) {
+      // Unregister Callback to avoid double registration down the line
+      RpcIn_UnregisterCallback(in, VIX_BACKDOORCOMMAND_OPEN_URL);
       return FALSE;
    }
 
@@ -1221,141 +1119,8 @@ FoundryToolsDaemon_UnregisterOpenUrl(void)
    return TRUE;
 }
 
-
-/*
- *-----------------------------------------------------------------------------
- *
- * FoundryToolsDaemon_RegisterSetPrinterCapability --
- *
- *      Register the Set Printer capability. Sometimes this needs to
- *      be done separately from the TCLO callback registration, so we
- *      provide it separately here.
- *
- * Results:
- *      TRUE on success
- *      FALSE on failure
- *
- * Side effects:
- *      None
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-FoundryToolsDaemon_RegisterSetPrinterCapability(void)
-{
-   if (!RpcOut_sendOne(NULL, NULL, "tools.capability.printer_set 1")) {
-      Debug("Unable to register printer set capability\n");
-      Debug("<FoundryToolsDaemon_RegisterSetPrinterCapability\n");
-      return FALSE;
-   }
-
-   return TRUE;
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * FoundryToolsDaemon_RegisterSetPrinter --
- *
- *      Register the Set Printer capability and TCLO handler.
- *
- * Results:
- *      TRUE on success
- *      FALSE on failure
- *
- * Side effects:
- *      None
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-FoundryToolsDaemon_RegisterSetPrinter(RpcIn *in) // IN
-{
-   /* First, try to load the printer library. */
-   if (!Printer_Init()) {
-      Debug("<FoundryToolsDaemon_RegisterSetPrinter\n");
-      Debug("Unable to load printer library.\n");
-      return FALSE;
-   }
-
-   /* Register the TCLO handler. */
-   RpcIn_RegisterCallbackEx(in,
-                            VIX_BACKDOORCOMMAND_SET_GUEST_PRINTER,
-                            ToolsDaemonTcloSetPrinter,
-                            NULL);
-   /*
-    * Inform the VMX that we support setting the guest printer; the UI
-    * and VMX need to know about this capability in advance (rather than
-    * simply trying and failing). I've put this here on the theory that
-    * it's better to have it close to the command that handles the
-    * actual request than it is to have it near the other capabilities
-    * registration code, which is in toolsDaemon.c.
-    *
-    * Eventually, Foundry might want to have a unified way of
-    * registering support for only a subset of the foundry commands in
-    * the guest.
-    */
-   if (!FoundryToolsDaemon_RegisterSetPrinterCapability()) {
-      Debug("<FoundryToolsDaemon_RegisterSetPrinter\n");
-      return FALSE;
-   }
-
-   return TRUE;
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * FoundryToolsDaemon_UnregisterSetPrinter --
- *
- *      Unregister the "Set Printer" capability.
- *
- * Results:
- *      TRUE on success
- *      FALSE on failure
- *
- * Side effects:
- *      None
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-FoundryToolsDaemon_UnregisterSetPrinter(RpcIn *in) // IN
-{
-   /*
-    * RpcIn doesn't have an unregister facility, so all we need to do
-    * here is unregister the capability.
-    */
-
-   /*
-    * Report no longer supporting setting the guest printer.
-    */
-   if (!RpcOut_sendOne(NULL, NULL, "tools.capability.printer_set 0")) {
-      Debug("<FoundryToolsDaemon_UnregisterSetPrinter\n");
-      Debug("Unable to unregister printer set capability\n");
-      return FALSE;
-   }
-
-   /* Cleanup the printer library. */
-   if (!Printer_Cleanup()) {
-      /*
-       * Failed to cleanup, but we still unregistered the command so
-       * we'll just warn and pretend we succeeded.
-       */
-      Debug("Unable to cleanup printer library\n");
-   }
-
-   return TRUE;
-}
-
 #endif
 
-
 /*
  *-----------------------------------------------------------------------------
  *
@@ -1371,7 +1136,7 @@ FoundryToolsDaemon_UnregisterSetPrinter(RpcIn *in) // IN
  *-----------------------------------------------------------------------------
  */
 
-Bool
+RpcInRet
 ToolsDaemonTcloMountHGFS(RpcInData *data) // IN
 {
    VixError err = VIX_OK;
@@ -1470,7 +1235,7 @@ ToolsDaemonTcloMountHGFS(RpcInData *data) // IN
  *-----------------------------------------------------------------------------
  */
 
-Bool
+RpcInRet
 ToolsDaemonHgfsImpersonated(RpcInData *data) // IN
 {
    VixError err;
@@ -1707,7 +1472,7 @@ ToolsDaemonTcloReportProgramCompleted(const char *requestName,    // IN
  *-----------------------------------------------------------------------------
  */
 
-Bool
+RpcInRet
 ToolsDaemonTcloReceiveVixCommand(RpcInData *data) // IN
 {
    VixError err = VIX_OK;
