@@ -23,11 +23,9 @@
  */
 
 #if defined(_WIN32)
-#  define MODULE_NAME(x)   #x ".dll"
-#elif defined(__APPLE__)
-#  define MODULE_NAME(x)   "lib" #x ".dylib"
+#  define MODULE_NAME(x)   #x "." G_MODULE_SUFFIX
 #else
-#  define MODULE_NAME(x)   "lib" #x ".so"
+#  define MODULE_NAME(x)   "lib" #x "." G_MODULE_SUFFIX
 #endif
 
 #include <stdlib.h>
@@ -38,8 +36,52 @@
 #include "system.h"
 #include "util.h"
 #include "vmcheck.h"
-#include "vmtools.h"
 #include "vmware/guestrpc/tclodefs.h"
+#include "vmware/tools/utils.h"
+
+
+/*
+ ******************************************************************************
+ * ToolsCoreCleanup --                                                  */ /**
+ *
+ * Cleans up the main loop after it has executed. After this function
+ * returns, the fields of the state object shouldn't be used anymore.
+ *
+ * @param[in]  state       Service state.
+ *
+ ******************************************************************************
+ */
+
+static void
+ToolsCoreCleanup(ToolsServiceState *state)
+{
+   ToolsCore_UnloadPlugins(state);
+   if (state->ctx.rpc != NULL) {
+      RpcChannel_Destroy(state->ctx.rpc);
+      state->ctx.rpc = NULL;
+   }
+   g_key_file_free(state->ctx.config);
+   g_main_loop_unref(state->ctx.mainLoop);
+
+#if defined(G_PLATFORM_WIN32)
+   if (state->ctx.comInitialized) {
+      CoUninitialize();
+      state->ctx.comInitialized = FALSE;
+   }
+#endif
+
+#if !defined(_WIN32)
+   if (state->ctx.envp) {
+      System_FreeNativeEnviron(state->ctx.envp);
+      state->ctx.envp = NULL;
+   }
+#endif
+
+   g_object_unref(state->ctx.serviceObj);
+   state->ctx.serviceObj = NULL;
+   state->ctx.config = NULL;
+   state->ctx.mainLoop = NULL;
+}
 
 
 /**
@@ -90,49 +132,59 @@ ToolsCoreConfFileCb(gpointer clientData)
 }
 
 
-/**
- * Cleans up the main loop after it has executed. After this function
- * returns, the fields of the state object shouldn't be used anymore.
+/*
+ ******************************************************************************
+ * ToolsCoreRunLoop --                                                  */ /**
+ *
+ * Loads and registers all plugins, and runs the service's main loop.
  *
  * @param[in]  state       Service state.
+ *
+ * @return Exit code.
+ *
+ ******************************************************************************
  */
 
-void
-ToolsCore_Cleanup(ToolsServiceState *state)
+static int
+ToolsCoreRunLoop(ToolsServiceState *state)
 {
-   ToolsCore_UnloadPlugins(state);
-   if (state->ctx.rpc != NULL) {
-      RpcChannel_Destroy(state->ctx.rpc);
-      state->ctx.rpc = NULL;
+   if (ToolsCore_GetTcloName(state) != NULL && !ToolsCore_InitRpc(state)) {
+      return 1;
    }
-   g_key_file_free(state->ctx.config);
-   g_main_loop_unref(state->ctx.mainLoop);
 
-#if defined(G_PLATFORM_WIN32)
-   if (state->ctx.comInitialized) {
-      CoUninitialize();
-      state->ctx.comInitialized = FALSE;
+   /*
+    * Start the RPC channel if it's been created. The channel may be NULL if this is
+    * not running in the context of a VM.
+    */
+   if (state->ctx.rpc && !RpcChannel_Start(state->ctx.rpc)) {
+      return 1;
    }
+
+   if (!ToolsCore_LoadPlugins(state)) {
+      return 1;
+   }
+
+   /*
+    * If not in a VM then there's no point in trying to run the loop, just exit
+    * with a '0' return status (see bug 297528 for why '0'). If we ever want
+    * to run vmtoolsd on physical hardware (or another hypervisor), we'll have
+    * to revisit this code.
+    */
+   if (!state->ctx.isVMware) {
+      return 0;
+   }
+
+   ToolsCore_RegisterPlugins(state);
+   g_timeout_add(CONF_POLL_TIME * 10, ToolsCoreConfFileCb, state);
+
+#if defined(__APPLE__)
+   ToolsCore_CFRunLoop(state);
+#else
+   g_main_loop_run(state->ctx.mainLoop);
 #endif
 
-   if (state->debugData != NULL) {
-      state->debugData->shutdown(&state->ctx, state->debugData);
-      g_module_close(state->debugLib);
-      state->debugData = NULL;
-      state->debugLib = NULL;
-   }
-
-#if !defined(_WIN32)
-   if (state->ctx.envp) {
-      System_FreeNativeEnviron(state->ctx.envp);
-      state->ctx.envp = NULL;
-   }
-#endif
-
-   g_object_unref(state->ctx.serviceObj);
-   state->ctx.serviceObj = NULL;
-   state->ctx.config = NULL;
-   state->ctx.mainLoop = NULL;
+   ToolsCoreCleanup(state);
+   return state->ctx.errorCode;
 }
 
 
@@ -208,55 +260,41 @@ ToolsCore_GetTcloName(ToolsServiceState *state)
  * detected.
  *
  * @param[in]  state       Service state.
- * @param[in]  force       Whether to force reconfiguration of the logging
- *                         subsystem.
+ * @param[in]  reset       Whether to reset the logging subsystem.
  */
 
 void
 ToolsCore_ReloadConfig(ToolsServiceState *state,
-                       gboolean force)
+                       gboolean reset)
 {
-   char *confFile;
-   gboolean loaded = TRUE;
+   gboolean first = state->ctx.config == NULL;
+   gboolean loaded;
 
-   VMTools_SetDefaultLogDomain(state->name);
+   loaded = VMTools_LoadConfig(state->configFile,
+                               G_KEY_FILE_NONE,
+                               &state->ctx.config,
+                               &state->configMtime);
 
-   confFile = g_strdup(state->configFile);
-   if (confFile == NULL) {
-      confFile = VMTools_GetToolsConfFile();
-   }
-
-   if (state->ctx.config == NULL) {
-      state->ctx.config = VMTools_LoadConfig(confFile,
-                                             G_KEY_FILE_NONE,
-                                             state->mainService);
-      state->configMtime = time(NULL);
-      if (state->ctx.config == NULL) {
-         /* Couldn't load the config file. Just create an empty dictionary. */
-         state->ctx.config = g_key_file_new();
-      }
-   } else if (VMTools_ReloadConfig(confFile,
-                                   G_KEY_FILE_NONE,
-                                   &state->ctx.config,
-                                   &state->configMtime)) {
+   if (!first && loaded) {
       g_debug("Config file reloaded.\n");
 
       /* Inform plugins of config file update. */
       g_signal_emit_by_name(state->ctx.serviceObj,
                             TOOLS_CORE_SIG_CONF_RELOAD,
                             &state->ctx);
-   } else {
-      loaded = FALSE;
    }
 
-   if (force || loaded) {
-      VMTools_ConfigLogging(state->ctx.config);
-      if (state->log) {
-         VMTools_EnableLogging(state->log);
-      }
+   if (state->ctx.config == NULL) {
+      /* Couldn't load the config file. Just create an empty dictionary. */
+      state->ctx.config = g_key_file_new();
    }
 
-   g_free(confFile);
+   if (reset || loaded) {
+      VMTools_ConfigLogging(state->name,
+                            state->ctx.config,
+                            state->log,
+                            reset);
+   }
 }
 
 
@@ -264,11 +302,9 @@ ToolsCore_ReloadConfig(ToolsServiceState *state,
  * Performs any initial setup steps for the service's main loop.
  *
  * @param[in]  state       Service state.
- *
- * @return Whether initialization was successful.
  */
 
-gboolean
+void
 ToolsCore_Setup(ToolsServiceState *state)
 {
    GMainContext *gctx;
@@ -294,40 +330,6 @@ ToolsCore_Setup(ToolsServiceState *state)
    if (state->debugPlugin != NULL) {
       ToolsCoreInitializeDebug(state);
    }
-
-   /* Initialize the RpcIn channel for the known tools services. */
-   if (ToolsCore_GetTcloName(state) != NULL &&
-       !ToolsCore_InitRpc(state)) {
-      goto error;
-   }
-
-   /*
-    * Start the RPC channel if it's been created. The channel may be NULL if this is
-    * not running in the context of a VM.
-    */
-   if (state->ctx.rpc && !RpcChannel_Start(state->ctx.rpc)) {
-      goto error;
-   }
-
-   if (!ToolsCore_LoadPlugins(state)) {
-      goto error;
-   }
-
-   ToolsCore_RegisterPlugins(state);
-   goto exit;
-
-error:
-   if (state->ctx.rpc != NULL) {
-      RpcChannel_Destroy(state->ctx.rpc);
-      state->ctx.rpc = NULL;
-   }
-   if (state->ctx.mainLoop != NULL) {
-      g_main_loop_unref(state->ctx.mainLoop);
-      state->ctx.mainLoop = NULL;
-   }
-
-exit:
-   return (state->ctx.mainLoop != NULL);
 }
 
 
@@ -342,21 +344,16 @@ exit:
 int
 ToolsCore_Run(ToolsServiceState *state)
 {
-   /*
-    * If there's no RPC channel (not in a VM) then there's no point in trying to
-    * run the loop, just exit with a '0' return status (see bug 297528 for why '0').
-    */
-   if (!state->ctx.rpc) {
-      return 0;
+   if (state->debugData != NULL) {
+      int ret = state->debugData->run(&state->ctx,
+                                      ToolsCoreRunLoop,
+                                      state,
+                                      state->debugData);
+      g_module_close(state->debugLib);
+      state->debugData = NULL;
+      state->debugLib = NULL;
+      return ret;
    }
-
-   g_timeout_add(CONF_POLL_TIME * 10, ToolsCoreConfFileCb, state);
-
-#if defined(__APPLE__)
-   ToolsCore_CFRunLoop(state);
-#else
-   g_main_loop_run(state->ctx.mainLoop);
-#endif
-   return state->ctx.errorCode;
+   return ToolsCoreRunLoop(state);
 }
 
