@@ -34,7 +34,7 @@
 #include "system.h"
 #include "unicode.h"
 #include "util.h"
-#include "vmtools.h"
+#include "vmware/tools/utils.h"
 
 #if !defined(__APPLE__)
 #include "embed_version.h"
@@ -59,7 +59,6 @@ static gboolean
 ToolsCoreSigHUPCb(const siginfo_t *info,
                   gpointer data)
 {
-   VMTools_ResetLogging(TRUE);
    ToolsCore_ReloadConfig(data, TRUE);
    return TRUE;
 }
@@ -188,9 +187,7 @@ main(int argc,
       return 0;
    }
 
-   if (!ToolsCore_Setup(&gState)) {
-      goto exit;
-   }
+   ToolsCore_Setup(&gState);
 
    src = VMTools_NewSignalSource(SIGHUP);
    VMTOOLSAPP_ATTACH_SOURCE(&gState.ctx, src,
@@ -225,8 +222,6 @@ main(int argc,
 
    ret = ToolsCore_Run(&gState);
 
-   ToolsCore_Cleanup(&gState);
-
    if (gState.pidFile != NULL) {
       g_unlink(gState.pidFile);
    }
