@@ -27,7 +27,7 @@
 #include "guestApp.h"
 #include "toolsCoreInt.h"
 #include "util.h"
-#include "vmtools.h"
+#include "vmware/tools/utils.h"
 
 
 #ifdef USE_APPLOADER
@@ -37,11 +37,11 @@ static Bool (*LoadDependencies)(char *libName, Bool useShipped);
 typedef void (*PluginDataCallback)(ToolsServiceState *state,
                                    ToolsPluginData *plugin);
 
-typedef void (*PluginAppRegCallback)(ToolsServiceState *state,
-                                     ToolsPluginData *plugin,
-                                     ToolsAppType type,
-                                     ToolsAppProviderReg *preg,
-                                     gpointer reg);
+typedef gboolean (*PluginAppRegCallback)(ToolsServiceState *state,
+                                         ToolsPluginData *plugin,
+                                         ToolsAppType type,
+                                         ToolsAppProviderReg *preg,
+                                         gpointer reg);
 
 
 /**
@@ -52,9 +52,11 @@ typedef void (*PluginAppRegCallback)(ToolsServiceState *state,
  * @param[in]  type     Application type.
  * @param[in]  preg     Provider information.
  * @param[in]  reg      Application registration.
+ *
+ * @return TRUE
  */
 
-static void
+static gboolean
 ToolsCoreDumpAppInfo(ToolsServiceState *state,
                      ToolsPluginData *plugin,
                      ToolsAppType type,
@@ -70,6 +72,7 @@ ToolsCoreDumpAppInfo(ToolsServiceState *state,
     } else {
       g_message("      App type %u (no provider).\n", type);
    }
+   return TRUE;
 }
 
 
@@ -140,25 +143,30 @@ ToolsCoreDumpSignal(ToolsAppCtx *ctx,
  * @param[in]  type     Application type.
  * @param[in]  preg     Provider information.
  * @param[in]  reg      Application registration.
+ *
+ * @return Whether to continue registering other apps.
  */
 
-static void
+static gboolean
 ToolsCoreRegisterApp(ToolsServiceState *state,
                      ToolsPluginData *plugin,
                      ToolsAppType type,
                      ToolsAppProviderReg *preg,
                      gpointer reg)
 {
-   if (preg == NULL) {
-      g_warning("Plugin %s wants to register app of type %d but no "
-                "provider was found.\n", plugin->name, type);
-      return;
+   gboolean error = TRUE;
+
+   if (type == TOOLS_APP_PROVIDER) {
+      /* We should already have registered all providers. */
+      return TRUE;
    }
 
+   ASSERT(preg != NULL);
+
    if (preg->state == TOOLS_PROVIDER_ERROR) {
       g_warning("Plugin %s wants to register app of type %d but the "
                 "provider failed to activate.\n", plugin->name, type);
-      return;
+      goto exit;
    }
 
    /*
@@ -174,13 +182,24 @@ ToolsCoreRegisterApp(ToolsServiceState *state,
                       preg->prov->name, err->message);
             preg->state = TOOLS_PROVIDER_ERROR;
             g_clear_error(&err);
-            return;
+            goto exit;
          }
       }
       preg->state = TOOLS_PROVIDER_ACTIVE;
    }
 
-   preg->prov->registerApp(&state->ctx, preg->prov, reg);
+   if (!preg->prov->registerApp(&state->ctx, preg->prov, reg)) {
+      g_warning("Failed registration of app type %d (%s) from plugin %s.",
+                type, preg->prov->name, plugin->name);
+      goto exit;
+   }
+   error = FALSE;
+
+exit:
+   if (error && plugin->errorCb != NULL) {
+      return plugin->errorCb(&state->ctx, type, reg, plugin);
+   }
+   return TRUE;
 }
 
 
@@ -192,9 +211,11 @@ ToolsCoreRegisterApp(ToolsServiceState *state,
  * @param[in]  type     Application type.
  * @param[in]  preg     Provider information.
  * @param[in]  reg      Application registration.
+ *
+ * @return TRUE
  */
 
-static void
+static gboolean
 ToolsCoreRegisterProvider(ToolsServiceState *state,
                           ToolsPluginData *plugin,
                           ToolsAppType type,
@@ -202,16 +223,26 @@ ToolsCoreRegisterProvider(ToolsServiceState *state,
                           gpointer reg)
 {
    if (type == TOOLS_APP_PROVIDER) {
+      guint k;
       ToolsAppProvider *prov = reg;
       ToolsAppProviderReg newreg = { prov, TOOLS_PROVIDER_IDLE };
 
-      /* Assert that no two providers choose the same app type. */
-      ASSERT(preg == NULL);
-
       ASSERT(prov->name != NULL);
       ASSERT(prov->registerApp != NULL);
+
+      /* Assert that no two providers choose the same app type. */
+      for (k = 0; k < state->providers->len; k++) {
+         ToolsAppProviderReg *existing = &g_array_index(state->providers,
+                                                        ToolsAppProviderReg,
+                                                        k);
+         ASSERT(prov->regType != existing->prov->regType);
+         g_return_val_if_fail(prov->regType != existing->prov->regType, TRUE);
+      }
+
       g_array_append_val(state->providers, newreg);
    }
+
+   return TRUE;
 }
 
 
@@ -251,7 +282,6 @@ ToolsCoreForEachPlugin(ToolsServiceState *state,
 
       for (j = 0; j < regs->len; j++) {
          guint k;
-         guint provIdx = -1;
          ToolsAppReg *reg = &g_array_index(regs, ToolsAppReg, j);
          ToolsAppProviderReg *preg = NULL;
 
@@ -262,14 +292,27 @@ ToolsCoreForEachPlugin(ToolsServiceState *state,
                                                       k);
             if (tmp->prov->regType == reg->type) {
                preg = tmp;
-               provIdx = k;
                break;
             }
          }
 
+         if (preg == NULL) {
+            g_message("Cannot find provider for app type %d, plugin %s may not work.\n",
+                      reg->type, plugin->data->name);
+            if (plugin->data->errorCb != NULL &&
+                !plugin->data->errorCb(&state->ctx, reg->type, NULL, plugin->data)) {
+               break;
+            }
+            continue;
+         }
+
          for (k = 0; k < reg->data->len; k++) {
             gpointer appdata = &reg->data->data[preg->prov->regSize * k];
-            appRegCb(state, plugin->data, reg->type, preg, appdata);
+            if (!appRegCb(state, plugin->data, reg->type, preg, appdata)) {
+               /* Break out of the outer loop. */
+               j = regs->len;
+               break;
+            }
          }
       }
    }
@@ -282,14 +325,17 @@ ToolsCoreForEachPlugin(ToolsServiceState *state,
  * @param[in]  ctx   The application context.
  * @param[in]  prov  Unused.
  * @param[in]  reg   The application registration data.
+ *
+ * @return TRUE.
  */
 
-static void
+static gboolean
 ToolsCoreRegisterRPC(ToolsAppCtx *ctx,
                      ToolsAppProvider *prov,
                      gpointer reg)
 {
    RpcChannel_RegisterCallback(ctx->rpc, reg);
+   return TRUE;
 }
 
 
@@ -299,18 +345,24 @@ ToolsCoreRegisterRPC(ToolsAppCtx *ctx,
  * @param[in]  ctx   The application context.
  * @param[in]  prov  Unused.
  * @param[in]  reg   The application registration data.
+ *
+ * @return TRUE if the signal exists.
  */
 
-static void
+static gboolean
 ToolsCoreRegisterSignal(ToolsAppCtx *ctx,
                         ToolsAppProvider *prov,
                         gpointer reg)
 {
    ToolsPluginSignalCb *sig = reg;
-   g_signal_connect(ctx->serviceObj,
-                    sig->signame,
-                    sig->callback,
-                    sig->clientData);
+   if (g_signal_lookup(sig->signame, G_OBJECT_TYPE(ctx->serviceObj)) != 0) {
+      g_signal_connect(ctx->serviceObj,
+                       sig->signame,
+                       sig->callback,
+                       sig->clientData);
+      return TRUE;
+   }
+   return FALSE;
 }
 
 
@@ -367,9 +419,13 @@ ToolsCoreLoadDirectory(ToolsAppCtx *ctx,
     * regardless of how the filesystem returns entries.
     */
    while ((staticEntry = g_dir_read_name(dir)) != NULL) {
-      g_ptr_array_add(plugins, g_strdup(staticEntry));
+      if (g_str_has_suffix(staticEntry, "." G_MODULE_SUFFIX)) {
+         g_ptr_array_add(plugins, g_strdup(staticEntry));
+      }
    }
 
+   g_dir_close(dir);
+
    g_ptr_array_sort(plugins, ToolsCoreStrPtrCompare);
 
    for (i = 0; i < plugins->len; i++) {
@@ -576,8 +632,8 @@ ToolsCore_RegisterPlugins(ToolsServiceState *state)
    }
 
    /*
-    * Create two "fake" app providers for the functionality provided by
-    * vmtoolsd (GuestRPC channel, glib signals).
+    * Create "fake" app providers for the functionality provided by
+    * vmtoolsd (GuestRPC channel, glib signals, custom app providers).
     */
    state->providers = g_array_new(FALSE, TRUE, sizeof (ToolsAppProviderReg));
 
@@ -605,6 +661,18 @@ ToolsCore_RegisterPlugins(ToolsServiceState *state)
    fakeReg.state = TOOLS_PROVIDER_ACTIVE;
    g_array_append_val(state->providers, fakeReg);
 
+   fakeProv = g_malloc0(sizeof *fakeProv);
+   fakeProv->regType = TOOLS_APP_PROVIDER;
+   fakeProv->regSize = sizeof (ToolsAppProvider);
+   fakeProv->name = "App Provider";
+   fakeProv->registerApp = NULL;
+   fakeProv->dumpState = NULL;
+
+   fakeReg.prov = fakeProv;
+   fakeReg.state = TOOLS_PROVIDER_ACTIVE;
+   g_array_append_val(state->providers, fakeReg);
+
+
    /*
     * First app providers need to be identified, so that we know that they're
     * available for use by plugins who need them.
@@ -666,12 +734,13 @@ ToolsCore_UnloadPlugins(ToolsServiceState *state)
                                                   ToolsAppProviderReg,
                                                   i);
 
-       if (preg->prov->shutdown != NULL) {
-          preg->prov->shutdown(&state->ctx, preg->prov);
-       }
+      if (preg->prov->shutdown != NULL) {
+         preg->prov->shutdown(&state->ctx, preg->prov);
+      }
 
       if (preg->prov->regType == TOOLS_APP_GUESTRPC ||
-          preg->prov->regType == TOOLS_APP_SIGNALS) {
+          preg->prov->regType == TOOLS_APP_SIGNALS ||
+          preg->prov->regType == TOOLS_APP_PROVIDER) {
          g_free(preg->prov);
       }
    }
