@@ -32,8 +32,8 @@
 #include "str.h"
 #include "strutil.h"
 #include "toolsCoreInt.h"
-#include "vmtools.h"
 #include "vm_tools_version.h"
+#include "vmware/tools/utils.h"
 
 
 /**
@@ -96,7 +96,7 @@ ToolsCoreCheckReset(struct RpcChannel *chan,
  * @return TRUE.
  */
 
-static Bool
+static gboolean
 ToolsCoreRpcCapReg(RpcInData *data)
 {
    char *confPath = GuestApp_GetConfPath();
@@ -163,10 +163,10 @@ ToolsCoreRpcCapReg(RpcInData *data)
  *
  * @param[in]  data     The RPC data.
  *
- * @return TRUE.
+ * @return Whether the option was successfully processed.
  */
 
-static Bool
+static gboolean
 ToolsCoreRpcSetOption(RpcInData *data)
 {
 
@@ -182,29 +182,23 @@ ToolsCoreRpcSetOption(RpcInData *data)
    index++;
    value = StrUtil_GetNextToken(&index, data->args, "");
 
-   if (option == NULL || value == NULL || strlen(value) == 0) {
-      goto exit;
+   if (option != NULL && value != NULL && strlen(value) != 0) {
+
+      g_debug("Setting option '%s' to '%s'.\n", option, value);
+      g_signal_emit_by_name(state->ctx.serviceObj,
+                            TOOLS_CORE_SIG_SET_OPTION,
+                            &state->ctx,
+                            option,
+                            value,
+                            &retVal);
    }
 
-   g_debug("Setting option '%s' to '%s'.\n", option, value);
-   g_key_file_set_string(state->ctx.config, state->ctx.name, option, value);
-
-   g_signal_emit_by_name(state->ctx.serviceObj,
-                         TOOLS_CORE_SIG_SET_OPTION,
-                         &state->ctx,
-                         option,
-                         value,
-                         &retVal);
-
-exit:
    vm_free(option);
    vm_free(value);
-   if (retVal) {
-      RPCIN_SETRETVALS(data, "", retVal);
-   } else {
-      RPCIN_SETRETVALS(data, "Unknown or invalid option", retVal);
-   }
-   return (Bool) retVal;
+
+   RPCIN_SETRETVALS(data, retVal ? "" : "Unknown or invalid option", retVal);
+
+   return retVal;
 }
 
 
@@ -250,7 +244,7 @@ ToolsCore_InitRpc(ToolsServiceState *state)
                    state->name);
          state->ctx.rpc = NULL;
       } else {
-         state->ctx.rpc = RpcChannel_NewBackdoorChannel(mainCtx);
+         state->ctx.rpc = BackdoorChannel_New();
       }
       app = ToolsCore_GetTcloName(state);
       ASSERT(app != NULL);
