@@ -35,9 +35,12 @@
 #include "toolboxGtkInt.h"
 #include "guestApp.h"
 #include "conf.h"
+#include "debug.h"
 #include "str.h"
+#include "posix.h"
 #include "procMgr.h"
 #include "file.h"
+#include "util.h"
 
 /*
  * From toolboxInt.h
@@ -51,7 +54,7 @@ GtkWidget *scriptsApply;
 /* X terminal application and option (to launch vi to edit scripts). */
 static char *termApp;
 static char *termAppOption;
-static GuestApp_Dict *confDict;
+static GKeyFile *confDict;
 static GtkWidget *scriptsUseScript;
 static GtkWidget *scriptsDefaultScript;
 static GtkWidget *scriptsCustomScript;
@@ -103,7 +106,7 @@ Scripts_Create(GtkWidget* mainWnd)
    GList *items = NULL;
    GSList *radiobtn_group = NULL;
 
-   confDict = Conf_Load();
+   confDict = Toolbox_LoadToolsConf();
 
    scriptstab = gtk_vbox_new(FALSE, 10);
    gtk_widget_show(scriptstab);
@@ -144,7 +147,7 @@ Scripts_Create(GtkWidget* mainWnd)
 #ifdef GTK2
       gtk_label_set_mnemonic_widget(GTK_LABEL(label), GTK_COMBO(scriptsCombo)->entry);
 
-      scriptsUseScript = gtk_check_button_new_with_mnemonic("_Use Script");
+      scriptsUseScript = gtk_check_button_new_with_mnemonic("Use Scr_ipt");
 #else
       scriptsUseScript = gtk_check_button_new_with_label("Use Script");
 #endif
@@ -157,13 +160,13 @@ Scripts_Create(GtkWidget* mainWnd)
                          GTK_SIGNAL_FUNC(Scripts_OnUseScriptToggled), NULL);
 
       /*
-       * Try to find an available x terminal app to launch vi.
+       * Try to find an available x terminal app to launch a text editor.
        *
-       * Options with different X terminal apps to launch vi:
-       *    xterm -e vi foo.txt
-       *    rxvt -e vi foo.txt
-       *    konsole -e vi foo.txt
-       *    gnome-terminal -x vi foo.txt
+       * Options with different X terminal apps to launch the editor:
+       *    xterm -e [app] foo.txt
+       *    rxvt -e [app] foo.txt
+       *    konsole -e [app] foo.txt
+       *    gnome-terminal -x [app] foo.txt
        */
       termApp = NULL;
       termAppOption = "-e";
@@ -341,26 +344,37 @@ void
 Scripts_OnComboChanged(gpointer entry, // IN: the entry selected
                        gpointer data)  // IN: unused
 {
-   const char *path, *defaultPath;
+   const char *defaultPath;
    const char *currentState;
+   const char *confName = NULL;
+   gchar *path;
+
    currentState = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(scriptsCombo)->entry));
    if (strcmp(currentState, SCRIPT_SUSPEND) == 0) {
-      path = GuestApp_GetDictEntry(confDict, CONFNAME_SUSPENDSCRIPT);
-      defaultPath = GuestApp_GetDictEntryDefault(confDict, CONFNAME_SUSPENDSCRIPT);
+      confName = CONFNAME_SUSPENDSCRIPT;
    } else if (strcmp(currentState, SCRIPT_RESUME) == 0) {
-      path = GuestApp_GetDictEntry(confDict, CONFNAME_RESUMESCRIPT);
-      defaultPath = GuestApp_GetDictEntryDefault(confDict, CONFNAME_RESUMESCRIPT);
+      confName = CONFNAME_RESUMESCRIPT;
    } else if (strcmp(currentState, SCRIPT_OFF) == 0) {
-      path = GuestApp_GetDictEntry(confDict, CONFNAME_POWEROFFSCRIPT);
-      defaultPath = GuestApp_GetDictEntryDefault(confDict, CONFNAME_POWEROFFSCRIPT);
+      confName = CONFNAME_POWEROFFSCRIPT;
    } else if (strcmp(currentState, SCRIPT_ON) == 0) {
-      path = GuestApp_GetDictEntry(confDict, CONFNAME_POWERONSCRIPT);
-      defaultPath = GuestApp_GetDictEntryDefault(confDict, CONFNAME_POWERONSCRIPT);
-   } else {
-      path = "";
-      defaultPath = "";
+      confName = CONFNAME_POWERONSCRIPT;
    }
 
+   if (confName != NULL) {
+      path = g_key_file_get_string(confDict, "powerops", confName, NULL);
+      defaultPath = GuestApp_GetDefaultScript(confName);
+      if (path == NULL) {
+         if (g_key_file_has_key(confDict, "powerops", confName, NULL)) {
+            path = g_strdup("");
+         } else {
+            path = g_strdup(defaultPath);
+         }
+      }
+   } else {
+      path = g_strdup("");
+      defaultPath = "";
+   }
+   
    gtk_signal_handler_block_by_func(GTK_OBJECT(scriptsUseScript),
                                     GTK_SIGNAL_FUNC(Scripts_OnUseScriptToggled),
                                     NULL);
@@ -369,7 +383,7 @@ Scripts_OnComboChanged(gpointer entry, // IN: the entry selected
                                     NULL);
    if (strcmp(path, "") == 0) {
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(scriptsUseScript), FALSE);
-      path = defaultPath;
+      path = g_strdup(defaultPath);
    } else {
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(scriptsUseScript), TRUE);
    }
@@ -394,6 +408,7 @@ Scripts_OnComboChanged(gpointer entry, // IN: the entry selected
                                       GTK_SIGNAL_FUNC(Scripts_OnUseScriptToggled),
                                       NULL);
    Scripts_UpdateEnabled();
+   g_free(path);
 }
 
 
@@ -472,8 +487,9 @@ Scripts_OnApply(gpointer btn,  // IN: unused
                 gpointer data) // IN: unused
 {
    const char *path;
+   const char *defaultPath;
    const char *currentState;
-   char *confName;
+   const char *confName = NULL;
    Bool enabledUse, enabledDef;
 
    currentState = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(scriptsCombo)->entry));
@@ -486,9 +502,11 @@ Scripts_OnApply(gpointer btn,  // IN: unused
    } else if (strcmp(currentState, SCRIPT_ON) == 0) {
       confName = CONFNAME_POWERONSCRIPT;
    } else {
-      confName = "";
+      /* Not reached? */
+      return;
    }
 
+   defaultPath = GuestApp_GetDefaultScript(confName);
    enabledUse = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(scriptsUseScript));
    enabledDef = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(scriptsDefaultScript));
 
@@ -496,15 +514,15 @@ Scripts_OnApply(gpointer btn,  // IN: unused
       path = "";
    } else {
       if (enabledDef) {
-         path = GuestApp_GetDictEntryDefault(confDict, confName);
+         path = defaultPath;
       } else {
          path = gtk_editable_get_chars(GTK_EDITABLE(scriptsPath), 0, -1);
       }
    }
 
-   GuestApp_SetDictEntry(confDict, confName, path);
+   g_key_file_set_string(confDict, "powerops", confName, path);
 
-   GuestApp_WriteDict(confDict);
+   Toolbox_SaveToolsConf(confDict);
    Scripts_UpdateEnabled();
    gtk_widget_set_sensitive(scriptsApply, FALSE);
 
@@ -539,8 +557,10 @@ void
 Scripts_OnEdit(gpointer btn,  // IN: unused
                gpointer data) // IN: unused
 {
-   const char *scriptName;
-   char *cmd;
+   char *editor;
+   char *scriptName;
+   const char *argv[5];
+   size_t idx = 0;
 
    if (!termApp) {
       ToolsMain_MsgBox("Error", "Unable to locate terminal application in "
@@ -548,20 +568,52 @@ Scripts_OnEdit(gpointer btn,  // IN: unused
       return;
    }
 
-   scriptName = gtk_entry_get_text(GTK_ENTRY(scriptsPath));
-   cmd = Str_Asprintf(NULL, "%s %s vi %s >/dev/null 2>&1",
-                      termApp, termAppOption, scriptName);
-   if (!cmd) {
-      ToolsMain_MsgBox("Error", "Failure creating command to edit script.");
-      return;
+   editor = Posix_Getenv("EDITOR");
+   if (editor == NULL || strlen(editor) == 0) {
+      Debug("EDITOR not set, defaulting to vi.\n");
+      editor = g_find_program_in_path("vi");
+      if (editor == NULL) {
+         ToolsMain_MsgBox("Error",
+                          "Cannot edit script because the an editor was not found.");
+         return;
+      } else {
+         /*
+          * Make sure "editor" is allocated with malloc(), so that the call to
+          * free() later does the right thing.
+          */
+         char *tmp = editor;
+         editor = Util_SafeStrdup(tmp);
+         g_free(tmp);
+      }
+   } else {
+      /*
+       * Strings retuned by Posix_Getenv should not be freed
+       * so we make a duplicate that can be freed so we can
+       * have a common code path below.
+       */
+      editor = Util_SafeStrdup(editor);
    }
 
-   if (!ProcMgr_ExecSync(cmd, NULL)) {
-      ToolsMain_MsgBox("Error", "Cannot edit script because the vi editor "
-                       "was not found.");
+   scriptName = Toolbox_GetScriptPath(gtk_entry_get_text(GTK_ENTRY(scriptsPath)));
+   argv[idx++] = termApp;
+   if (termAppOption != NULL && strlen(termAppOption) > 0) {
+      argv[idx++] = termAppOption;
+   }
+   argv[idx++] = editor;
+   argv[idx++] = scriptName;
+   argv[idx++] = NULL;
+
+   /* Restore the original LD_LIBRARY_PATH before invoking external apps. */
+   if (!g_spawn_sync(NULL, (gchar **) argv, (gchar **) gNativeEnviron,
+                     G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL, NULL, NULL)) {
+      gchar *msg = g_strdup_printf("Cannot edit script: failed to execute editor %s.",
+                                   editor);
+      ToolsMain_MsgBox("Error", msg);
+      g_free(msg);
    }
 
-   free(cmd);
+   g_free(scriptName);
+   free(editor);
 }
 
 
@@ -586,13 +638,15 @@ void
 Scripts_OnRun(gpointer btn,  // IN: unused
               gpointer data) // IN: unused
 {
-   const char *scriptName;
+   char *scriptName;
 
-   scriptName = gtk_entry_get_text(GTK_ENTRY(scriptsPath));
+   scriptName = Toolbox_GetScriptPath(gtk_entry_get_text(GTK_ENTRY(scriptsPath)));
    if (!ProcMgr_ExecSync(scriptName, NULL)) {
       ToolsMain_MsgBox("Error", "Failure executing script, please ensure the "
                        "file exists and is executable.");
    }
+
+   g_free(scriptName);
 }
 
 
